@@ -24,7 +24,6 @@
 
 #include <string.h>
 #include <glib.h>
-#include <gtk/gtkframe.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkmessagedialog.h>
@@ -41,47 +40,46 @@
 #include "e-util/e-categories-master-list-wombat.h"
 #include "e-util/e-sexp.h"
 #include "e-util/e-passwords.h"
-#include "select-names/e-select-names.h"
-#include "select-names/e-select-names-manager.h"
 
 #include "evolution-shell-component-utils.h"
-#include "evolution-activity-client.h"
+#include "e-activity-handler.h"
 #include "e-contact-editor.h"
-#include "e-contact-save-as.h"
 #include "addressbook-config.h"
 #include "addressbook.h"
 #include "addressbook-component.h"
 #include "addressbook/gui/search/e-addressbook-search-dialog.h"
 #include "addressbook/gui/widgets/e-addressbook-view.h"
-#include "addressbook/gui/widgets/e-addressbook-util.h"
+#include "addressbook/gui/widgets/eab-gui-util.h"
 #include "addressbook/printing/e-contact-print.h"
+#include "addressbook/util/eab-book-util.h"
 
-#include <ebook/e-book.h>
-#include <ebook/e-book-util.h>
+#include <libebook/e-book-async.h>
 #include <widgets/misc/e-search-bar.h>
 #include <widgets/misc/e-filter-bar.h>
 
 /* This is used for the addressbook status bar */
 #define EVOLUTION_CONTACTS_PROGRESS_IMAGE "evolution-contacts-mini.png"
-static GdkPixbuf *progress_icon[2] = { NULL, NULL };
+static GdkPixbuf *progress_icon = NULL;
 
 #define d(x)
 
-#define PROPERTY_FOLDER_URI          "folder_uri"
+#define PROPERTY_SOURCE_UID          "source_uid"
 
-#define PROPERTY_FOLDER_URI_IDX      1
+#define PROPERTY_SOURCE_UID_IDX      1
 
 typedef struct {
 	gint refs;
-	EAddressbookView *view;
+	EABView *view;
 	ESearchBar *search;
 	gint        ecml_changed_id;
 	GtkWidget *vbox;
 	EBook *book;
-	EvolutionActivityClient *activity;
+	guint activity_id;
 	BonoboControl *control;
 	BonoboPropertyBag *properties;
-	char *uri;
+	GConfClient *gconf_client;
+	ESourceList *source_list;
+	ESource *source;
 	char *passwd;
 	gboolean ignore_search_changes;
 	gboolean failed_to_load;
@@ -91,7 +89,7 @@ static void addressbook_view_ref (AddressbookView *);
 static void addressbook_view_unref (AddressbookView *);
 
 static void addressbook_authenticate (EBook *book, gboolean previous_failure,
-				      AddressbookSource *source, EBookCallback cb, gpointer closure);
+				      ESource *source, EBookCallback cb, gpointer closure);
 
 static void book_open_cb (EBook *book, EBookStatus status, gpointer closure);
 
@@ -100,7 +98,7 @@ save_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_save_as(view->view);
+		eab_view_save_as(view->view);
 }
 
 static void
@@ -108,7 +106,7 @@ view_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_view(view->view);
+		eab_view_view(view->view);
 }
 
 static void
@@ -117,7 +115,7 @@ search_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 	AddressbookView *view = (AddressbookView *) user_data;
 
 	if (view->view)
-		gtk_widget_show(e_addressbook_search_dialog_new(view->view));
+		gtk_widget_show(eab_search_dialog_new(view->view));
 }
 
 static void
@@ -125,7 +123,7 @@ delete_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view) {
-		e_addressbook_view_delete_selection(view->view);
+		eab_view_delete_selection(view->view);
 	}
 }
 
@@ -134,7 +132,7 @@ print_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_print(view->view);
+		eab_view_print(view->view);
 }
 
 static void
@@ -142,7 +140,7 @@ print_preview_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_print_preview(view->view);
+		eab_view_print_preview(view->view);
 }
 
 static void
@@ -150,7 +148,7 @@ stop_loading_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_stop(view->view);
+		eab_view_stop(view->view);
 }
 
 static void
@@ -158,7 +156,7 @@ cut_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_cut(view->view);
+		eab_view_cut(view->view);
 }
 
 static void
@@ -166,7 +164,7 @@ copy_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_copy(view->view);
+		eab_view_copy(view->view);
 }
 
 static void
@@ -174,7 +172,7 @@ paste_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_paste(view->view);
+		eab_view_paste(view->view);
 }
 
 static void
@@ -182,7 +180,7 @@ select_all_contacts_cb (BonoboUIComponent *uih, void *user_data, const char *pat
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_select_all (view->view);
+		eab_view_select_all (view->view);
 }
 
 static void
@@ -190,7 +188,7 @@ send_contact_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_send (view->view);
+		eab_view_send (view->view);
 }
 
 static void
@@ -198,7 +196,7 @@ send_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_send_to (view->view);
+		eab_view_send_to (view->view);
 }
 
 static void
@@ -206,7 +204,7 @@ copy_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_copy_to_folder (view->view);
+		eab_view_copy_to_folder (view->view);
 }
 
 static void
@@ -214,7 +212,7 @@ move_contact_to_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 {
 	AddressbookView *view = (AddressbookView *) user_data;
 	if (view->view)
-		e_addressbook_view_move_to_folder (view->view);
+		eab_view_move_to_folder (view->view);
 }
 
 static void
@@ -224,7 +222,7 @@ forget_passwords_cb (BonoboUIComponent *uih, void *user_data, const char *path)
 }
 
 static void
-update_command_state (EAddressbookView *eav, AddressbookView *view)
+update_command_state (EABView *eav, AddressbookView *view)
 {
 	BonoboUIComponent *uic;
 
@@ -239,78 +237,78 @@ update_command_state (EAddressbookView *eav, AddressbookView *view)
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsSaveAsVCard",
 					      "sensitive",
-					      e_addressbook_view_can_save_as (view->view) ? "1" : "0", NULL);
+					      eab_view_can_save_as (view->view) ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsView",
 					      "sensitive",
-					      e_addressbook_view_can_view (view->view) ? "1" : "0", NULL);
+					      eab_view_can_view (view->view) ? "1" : "0", NULL);
 
 		/* Print Contact */
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsPrint",
 					      "sensitive",
-					      e_addressbook_view_can_print (view->view) ? "1" : "0", NULL);
+					      eab_view_can_print (view->view) ? "1" : "0", NULL);
 
 		/* Print Contact */
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsPrintPreview",
 					      "sensitive",
-					      e_addressbook_view_can_print (view->view) ? "1" : "0", NULL);
+					      eab_view_can_print (view->view) ? "1" : "0", NULL);
 
 		/* Delete Contact */
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactDelete",
 					      "sensitive",
-					      e_addressbook_view_can_delete (view->view) ? "1" : "0", NULL);
+					      eab_view_can_delete (view->view) ? "1" : "0", NULL);
 
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsCut",
 					      "sensitive",
-					      e_addressbook_view_can_cut (view->view) ? "1" : "0", NULL);
+					      eab_view_can_cut (view->view) ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsCopy",
 					      "sensitive",
-					      e_addressbook_view_can_copy (view->view) ? "1" : "0", NULL);
+					      eab_view_can_copy (view->view) ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsPaste",
 					      "sensitive",
-					      e_addressbook_view_can_paste (view->view) ? "1" : "0", NULL);
+					      eab_view_can_paste (view->view) ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsSelectAll",
 					      "sensitive",
-					      e_addressbook_view_can_select_all (view->view) ? "1" : "0", NULL);
+					      eab_view_can_select_all (view->view) ? "1" : "0", NULL);
 
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsSendContactToOther",
 					      "sensitive",
-					      e_addressbook_view_can_send (view->view) ? "1" : "0", NULL);
+					      eab_view_can_send (view->view) ? "1" : "0", NULL);
 
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsSendMessageToContact",
 					      "sensitive",
-					      e_addressbook_view_can_send_to (view->view) ? "1" : "0", NULL);
+					      eab_view_can_send_to (view->view) ? "1" : "0", NULL);
 
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsMoveToFolder",
 					      "sensitive",
-					      e_addressbook_view_can_move_to_folder (view->view) ? "1" : "0", NULL);
+					      eab_view_can_move_to_folder (view->view) ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactsCopyToFolder",
 					      "sensitive",
-					      e_addressbook_view_can_copy_to_folder (view->view) ? "1" : "0", NULL);
+					      eab_view_can_copy_to_folder (view->view) ? "1" : "0", NULL);
 
 		/* Stop */
 		bonobo_ui_component_set_prop (uic,
 					      "/commands/ContactStop",
 					      "sensitive",
-					      e_addressbook_view_can_stop (view->view) ? "1" : "0", NULL);
+					      eab_view_can_stop (view->view) ? "1" : "0", NULL);
 	}
 
 	addressbook_view_unref (view);
 }
 
 static void
-change_view_type (AddressbookView *view, EAddressbookViewType view_type)
+change_view_type (AddressbookView *view, EABViewType view_type)
 {
 	g_object_set (view->view, "type", view_type, NULL);
 }
@@ -379,7 +377,7 @@ control_activate (BonoboControl     *control,
 			       EVOLUTION_UIDIR "/evolution-addressbook.xml",
 			       "evolution-addressbook", NULL);
 
-	e_addressbook_view_setup_menus (view->view, uic);
+	eab_view_setup_menus (view->view, uic);
 
 	e_pixmaps_update (uic, pixmaps);
 
@@ -401,25 +399,21 @@ control_activate_cb (BonoboControl *control,
 	if (activate) {
 		control_activate (control, uic, view);
 		if (activate && view->view && view->view->model)
-			e_addressbook_model_force_folder_bar_message (view->view->model);
+			eab_model_force_folder_bar_message (view->view->model);
 
 		/* if the book failed to load, we kick off another
 		   load here */
 
-		if (view->failed_to_load && view->uri) {
+		if (view->failed_to_load && view->source) {
 			EBook *book;
-			char *uri_data;
 
 			book = e_book_new ();
-			uri_data = e_book_expand_uri (view->uri);
 
-			addressbook_load_uri (book, uri_data, book_open_cb, view);
-
-			g_free(uri_data);
+			addressbook_load_source (book, view->source, book_open_cb, view);
 		}
 	} else {
 		bonobo_ui_component_unset_container (uic, NULL);
-		e_addressbook_view_discard_menus (view->view);
+		eab_view_discard_menus (view->view);
 	}
 }
 
@@ -449,8 +443,10 @@ addressbook_view_clear (AddressbookView *view)
 	g_free(view->passwd);
 	view->passwd = NULL;
 
-	g_free(view->uri);
-	view->uri = NULL;
+	if (view->source_list) {
+		g_object_unref (view->source_list);
+		view->source_list = NULL;
+	}
 
 	if (view->ecml_changed_id != 0) {
 		g_signal_handler_disconnect (get_master_list(),
@@ -482,7 +478,7 @@ book_open_cb (EBook *book, EBookStatus status, gpointer closure)
 {
 	AddressbookView *view = closure;
 
-	if (status == E_BOOK_STATUS_SUCCESS) {
+	if (status == E_BOOK_ERROR_OK) {
 		view->failed_to_load = FALSE;
 		g_object_set(view->view,
 			     "book", book,
@@ -493,44 +489,40 @@ book_open_cb (EBook *book, EBookStatus status, gpointer closure)
 		char *label_string;
 		GtkWidget *warning_dialog;
 		GtkWidget *href = NULL;
-		AddressbookSource *source = NULL;
+		gchar *uri;
 
 		view->failed_to_load = TRUE;
 
-		if (!strncmp (view->uri, "file:", 5)) {
+		uri = e_source_get_uri (view->source);
+
+		if (!strncmp (uri, "file:", 5)) {
 			label_string = 
 				_("We were unable to open this addressbook.  Please check that the\n"
 				  "path exists and that you have permission to access it.");
 		}
-		else {
-			source = addressbook_storage_get_source_by_uri (view->uri);
-
-			if (source) {
-				/* special case for ldap: contact folders so we can tell the user about openldap */
+		else if (!strncmp (uri, "ldap:", 5)) {
+			/* special case for ldap: contact folders so we can tell the user about openldap */
 #if HAVE_LDAP
-				label_string = 
-					_("We were unable to open this addressbook.  This either\n"
-					  "means you have entered an incorrect URI, or the LDAP server\n"
-					  "is unreachable.");
+			label_string = 
+				_("We were unable to open this addressbook.  This either\n"
+				  "means you have entered an incorrect URI, or the LDAP server\n"
+				  "is unreachable.");
 #else
-				label_string =
-					_("This version of Evolution does not have LDAP support\n"
-					  "compiled in to it.  If you want to use LDAP in Evolution\n"
-					  "you must compile the program from the CVS sources after\n"
-					  "retrieving OpenLDAP from the link below.\n");
-				href = gnome_href_new ("http://www.openldap.org/", "OpenLDAP at http://www.openldap.org/");
+			label_string =
+				_("This version of Evolution does not have LDAP support\n"
+				  "compiled in to it.  If you want to use LDAP in Evolution\n"
+				  "you must compile the program from the CVS sources after\n"
+				  "retrieving OpenLDAP from the link below.\n");
+			href = gnome_href_new ("http://www.openldap.org/", "OpenLDAP at http://www.openldap.org/");
 #endif
-			}
-			else {
-				/* other network folders */
-				label_string =
-					_("We were unable to open this addressbook.  This either\n"
-					  "means you have entered an incorrect URI, or the server\n"
-					  "is unreachable.");
-			}
+		} else {
+			/* other network folders */
+			label_string =
+				_("We were unable to open this addressbook.  This either\n"
+				  "means you have entered an incorrect URI, or the server\n"
+				  "is unreachable.");
 		}
 
-
         	warning_dialog = gtk_message_dialog_new (
 			 NULL /* XXX */,
 			 0,
@@ -551,6 +543,8 @@ book_open_cb (EBook *book, EBookStatus status, gpointer closure)
 					    href, FALSE, FALSE, 0);
 
 		gtk_widget_show_all (warning_dialog);
+
+		g_free (uri);
 	}
 }
 
@@ -572,9 +566,9 @@ get_prop (BonoboPropertyBag *bag,
 
 	switch (arg_id) {
 
-	case PROPERTY_FOLDER_URI_IDX:
-		if (view && view->uri)
-			BONOBO_ARG_SET_STRING (arg, view->uri);
+	case PROPERTY_SOURCE_UID_IDX:
+		if (view && view->source)
+			BONOBO_ARG_SET_STRING (arg, e_source_peek_uid (view->source));
 		else
 			BONOBO_ARG_SET_STRING (arg, "");
 		break;
@@ -586,18 +580,17 @@ get_prop (BonoboPropertyBag *bag,
 
 typedef struct {
 	EBookCallback cb;
-	char *clean_uri;
-	AddressbookSource *source;
+	ESource *source;
 	gpointer closure;
-} LoadUriData;
+} LoadSourceData;
 
 static void
-load_uri_auth_cb (EBook *book, EBookStatus status, gpointer closure)
+load_source_auth_cb (EBook *book, EBookStatus status, gpointer closure)
 {
-	LoadUriData *data = closure;
+	LoadSourceData *data = closure;
 
-	if (status != E_BOOK_STATUS_SUCCESS) {
-		if (status == E_BOOK_STATUS_CANCELLED) {
+	if (status != E_BOOK_ERROR_OK) {
+		if (status == E_BOOK_ERROR_CANCELLED) {
 			/* the user clicked cancel in the password dialog */
 			GtkWidget *dialog;
 			dialog = gtk_message_dialog_new (NULL,
@@ -607,41 +600,66 @@ load_uri_auth_cb (EBook *book, EBookStatus status, gpointer closure)
 							 _("Accessing LDAP Server anonymously"));
 			g_signal_connect (dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
 			gtk_widget_show (dialog);
-			data->cb (book, E_BOOK_STATUS_SUCCESS, data->closure);
-			g_free (data->clean_uri);
+			data->cb (book, E_BOOK_ERROR_OK, data->closure);
 			g_free (data);
 			return;
 		}
 		else {
-			e_passwords_forget_password ("Addressbook", data->clean_uri);
-			addressbook_authenticate (book, TRUE, data->source, load_uri_auth_cb, closure);
+			gchar *uri = e_source_get_uri (data->source);
+
+			e_passwords_forget_password ("Addressbook", uri);
+			addressbook_authenticate (book, TRUE, data->source, load_source_auth_cb, closure);
+
+			g_free (uri);
 			return;
 		}
 	}
 
 	data->cb (book, status, data->closure);
 
-	g_free (data->clean_uri);
+	g_object_unref (data->source);
 	g_free (data);
 }
 
+static gboolean
+get_remember_password (ESource *source)
+{
+	const gchar *value;
+
+	value = e_source_get_property (source, "remember_password");
+	if (value && !strcasecmp (value, "true"))
+		return TRUE;
+
+	return FALSE;
+}
+
 static void
-addressbook_authenticate (EBook *book, gboolean previous_failure, AddressbookSource *source,
+set_remember_password (ESource *source, gboolean value)
+{
+	e_source_set_property (source, "remember_password",
+			       value ? "true" : "false");
+}
+
+static void
+addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *source,
 			  EBookCallback cb, gpointer closure)
 {
-	LoadUriData *load_uri_data = closure;
 	const char *password = NULL;
 	char *pass_dup = NULL;
-	char *semicolon;
+	const gchar *auth;
+	const gchar *user;
+	gchar *uri = e_source_get_uri (source);
 
-	load_uri_data->clean_uri = g_strdup (e_book_get_uri (book));
+	password = e_passwords_get_password ("Addressbook", uri);
 
-	semicolon = strchr (load_uri_data->clean_uri, ';');
+	auth = e_source_get_property (source, "auth");
 
-	if (semicolon)
-		*semicolon = '\0';
-
-	password = e_passwords_get_password ("Addressbook", load_uri_data->clean_uri);
+	if (auth && !strcmp ("ldap/simple-binddn", auth))
+		user = e_source_get_property (source, "binddn");
+	else
+		user = e_source_get_property (source, "email_addr");
+	if (!user)
+		user = "";
 
 	if (!password) {
 		char *prompt;
@@ -655,91 +673,82 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, AddressbookSou
 			failed_auth = "";
 		}
 
+		prompt = g_strdup_printf (_("%sEnter password for %s (user %s)"),
+					  failed_auth, e_source_peek_name (source), user);
 
-		if (source->auth == ADDRESSBOOK_LDAP_AUTH_SIMPLE_BINDDN)
-			prompt = g_strdup_printf (_("%sEnter password for %s (user %s)"),
-						  failed_auth, source->name, source->binddn);
-		else
-			prompt = g_strdup_printf (_("%sEnter password for %s (user %s)"),
-						  failed_auth, source->name, source->email_addr);
-		remember = source->remember_passwd;
-		pass_dup = e_passwords_ask_password (prompt, "Addressbook", load_uri_data->clean_uri, prompt, TRUE,
+		remember = get_remember_password (source);
+		pass_dup = e_passwords_ask_password (prompt, "Addressbook", uri, prompt, TRUE,
 						     E_PASSWORDS_REMEMBER_FOREVER, &remember,
 						     NULL);
-		if (remember != source->remember_passwd) {
-			source->remember_passwd = remember;
-			addressbook_storage_write_sources ();
-		}
+		if (remember != get_remember_password (source))
+			set_remember_password (source, remember);
+
 		g_free (prompt);
 	}
 
 	if (password || pass_dup) {
-		char *user;
-
-		if (source->auth == ADDRESSBOOK_LDAP_AUTH_SIMPLE_BINDDN)
-			user = source->binddn;
-		else
-			user = source->email_addr;
-		if (!user)
-			user = "";
-		e_book_authenticate_user (book, user, password ? password : pass_dup,
-					  addressbook_storage_auth_type_to_string (source->auth),
-					  cb, closure);
+		e_book_async_authenticate_user (book, user, password ? password : pass_dup,
+						e_source_get_property (source, "auth"),
+						cb, closure);
 		g_free (pass_dup);
-		return;
 	}
 	else {
 		/* they hit cancel */
-		cb (book, E_BOOK_STATUS_CANCELLED, closure);
+		cb (book, E_BOOK_ERROR_CANCELLED, closure);
 	}
+
+	g_free (uri);
 }
 
 static void
-load_uri_cb (EBook *book, EBookStatus status, gpointer closure)
+load_source_cb (EBook *book, EBookStatus status, gpointer closure)
 {
-	LoadUriData *load_uri_data = closure;
+	LoadSourceData *load_source_data = closure;
 
-	if (status == E_BOOK_STATUS_SUCCESS && book != NULL) {
+	if (status == E_BOOK_ERROR_OK && book != NULL) {
+		const gchar *auth;
+
+		auth = e_source_get_property (load_source_data->source, "auth");
 
 		/* check if the addressbook needs authentication */
 
-		load_uri_data->source = addressbook_storage_get_source_by_uri (e_book_get_uri (book));
-
-		if (load_uri_data->source &&
-		    load_uri_data->source->auth != ADDRESSBOOK_LDAP_AUTH_NONE) {
-
-			addressbook_authenticate (book, FALSE, load_uri_data->source,
-						  load_uri_auth_cb, closure);
+		if (auth && strcmp (auth, "none")) {
+			addressbook_authenticate (book, FALSE, load_source_data->source,
+						  load_source_auth_cb, closure);
 
 			return;
 		}
 	}
 	
-	load_uri_data->cb (book, status, load_uri_data->closure);
-	g_free (load_uri_data);
+	load_source_data->cb (book, status, load_source_data->closure);
+	g_object_unref (load_source_data->source);
+	g_free (load_source_data);
 }
 
 void
-addressbook_load_uri (EBook *book, const char *uri,
-		      EBookCallback cb, gpointer closure)
+addressbook_load_source (EBook *book, ESource *source,
+			 EBookCallback cb, gpointer closure)
 {
-	LoadUriData *load_uri_data = g_new0 (LoadUriData, 1);
+	LoadSourceData *load_source_data = g_new0 (LoadSourceData, 1);
 
-	load_uri_data->cb = cb;
-	load_uri_data->closure = closure;
+	load_source_data->cb = cb;
+	load_source_data->closure = closure;
+	load_source_data->source = g_object_ref (source);
 
-	e_book_load_uri (book, uri, load_uri_cb, load_uri_data);
+	e_book_async_load_source (book, source, load_source_cb, load_source_data);
 }
 
 void
-addressbook_load_default_book (EBook *book, EBookCallback cb, gpointer closure)
+addressbook_load_default_book (EBookCallback cb, gpointer closure)
 {
-	LoadUriData *load_uri_data = g_new (LoadUriData, 1);
+	LoadSourceData *load_source_data = g_new (LoadSourceData, 1);
 
-	load_uri_data->cb = cb;
-	load_uri_data->closure = closure;
+	/* FIXME: We need to get the source for the default book */
 
-	e_book_load_default_book (book, load_uri_cb, load_uri_data);
+	load_source_data->cb = cb;
+	load_source_data->closure = closure;
+
+	e_book_async_get_default_addressbook (load_source_cb, load_source_data);
 }
 
 static void
@@ -750,29 +759,28 @@ set_prop (BonoboPropertyBag *bag,
 	  gpointer           user_data)
 {
 	AddressbookView *view = user_data;
+	const gchar *uid;
 
-	char *uri_data;
-	
 	switch (arg_id) {
 
-	case PROPERTY_FOLDER_URI_IDX:
-		if (view->uri) {
+	case PROPERTY_SOURCE_UID_IDX:
+		if (view->book) {
 			/* we've already had a uri set on this view, so unload it */
-			e_book_unload_uri (view->book); 
-			g_free (view->uri);
+			e_book_async_unload_uri (view->book); 
+			view->source = NULL;
 		} else {
 			view->book = e_book_new ();
 		}
 
 		view->failed_to_load = FALSE;
 
-		view->uri = g_strdup(BONOBO_ARG_GET_STRING (arg));
-		
-		uri_data = e_book_expand_uri (view->uri);
+		uid = BONOBO_ARG_GET_STRING (arg);
+		view->source = e_source_list_peek_source_by_uid (view->source_list, uid);
 
-		addressbook_load_uri (view->book, uri_data, book_open_cb, view);
-
-		g_free(uri_data);
+		if (view->source)
+			addressbook_load_source (view->book, view->source, book_open_cb, view);
+		else
+			g_warning ("Could not find source by UID '%s'!", uid);
 
 		break;
 		
@@ -799,19 +807,6 @@ static ESearchBarItem addressbook_search_option_items[] = {
 	{ NULL, -1, NULL }
 };
 
-static void
-alphabet_state_changed (EAddressbookView *eav, gunichar letter, AddressbookView *view)
-{
-	view->ignore_search_changes = TRUE;
-	if (letter == 0) {
-		e_search_bar_set_item_id (view->search, ESB_FULL_NAME);
-		e_search_bar_set_text (view->search, "");
-	} else {
-		e_search_bar_set_item_id (view->search, ESB_FULL_NAME);
-	}
-	view->ignore_search_changes = FALSE;
-}
-
 static void
 addressbook_search_activated (ESearchBar *esb, AddressbookView *view)
 {
@@ -830,7 +825,7 @@ addressbook_search_activated (ESearchBar *esb, AddressbookView *view)
 		     NULL);
 
 	if (search_type == ESB_ADVANCED) {
-		gtk_widget_show(e_addressbook_search_dialog_new(view->view));
+		gtk_widget_show(eab_search_dialog_new(view->view));
 	}
 	else {
 		if ((search_word && strlen (search_word)) || search_type == ESB_CATEGORY) {
@@ -890,66 +885,43 @@ addressbook_query_changed (ESearchBar *esb, AddressbookView *view)
 		     NULL);
 
 	if (search_type == ESB_ADVANCED) {
-		gtk_widget_show(e_addressbook_search_dialog_new(view->view));
+		gtk_widget_show(eab_search_dialog_new(view->view));
 	}
 }
 
-static GNOME_Evolution_ShellView
-retrieve_shell_view_interface_from_control (BonoboControl *control)
-{
-	Bonobo_ControlFrame control_frame;
-	GNOME_Evolution_ShellView shell_view_interface;
-	CORBA_Environment ev;
-
-	control_frame = bonobo_control_get_control_frame (control, NULL);
-
-	if (control_frame == NULL)
-		return CORBA_OBJECT_NIL;
-
-	CORBA_exception_init (&ev);
-	shell_view_interface = Bonobo_Unknown_queryInterface (control_frame,
-							       "IDL:GNOME/Evolution/ShellView:1.0",
-							       &ev);
-	CORBA_exception_free (&ev);
-
-	return shell_view_interface;
-}
-
 static void
-set_status_message (EAddressbookView *eav, const char *message, AddressbookView *view)
+set_status_message (EABView *eav, const char *message, AddressbookView *view)
 {
+	EActivityHandler *activity_handler = addressbook_component_peek_activity_handler (addressbook_component_peek ());
 
 	if (!message || !*message) {
-		if (view->activity) {
-			g_object_unref (view->activity);
-			view->activity = NULL;
+		if (view->activity_id != 0) {
+			e_activity_handler_operation_finished (activity_handler, view->activity_id);
+			view->activity_id = 0;
 		}
-	}
-	else if (!view->activity) {
-		int display;
+	} else if (view->activity_id == 0) {
 		char *clientid = g_strdup_printf ("%p", view);
 
-		if (progress_icon[0] == NULL)
-			progress_icon[0] = gdk_pixbuf_new_from_file (EVOLUTION_IMAGESDIR "/" EVOLUTION_CONTACTS_PROGRESS_IMAGE, NULL);
+		if (progress_icon == NULL)
+			progress_icon = gdk_pixbuf_new_from_file (EVOLUTION_IMAGESDIR "/" EVOLUTION_CONTACTS_PROGRESS_IMAGE, NULL);
 
-		view->activity = evolution_activity_client_new (addressbook_component_get_shell_client(), clientid,
-								progress_icon, message, TRUE, &display);
+		view->activity_id = e_activity_handler_operation_started (activity_handler, clientid,
+									  progress_icon, message, TRUE);
 
 		g_free (clientid);
-	}
-	else {
-		evolution_activity_client_update (view->activity, message, -1.0);
+	} else {
+		e_activity_handler_operation_progressing (activity_handler, view->activity_id, message, -1.0);
 	}
 
 }
 
 static void
-search_result (EAddressbookView *eav, EBookViewStatus status, AddressbookView *view)
+search_result (EABView *eav, EBookViewStatus status, AddressbookView *view)
 {
 	char *str = NULL;
 
 	switch (status) {
-	case E_BOOK_VIEW_STATUS_SUCCESS:
+	case E_BOOK_VIEW_STATUS_OK:
 		return;
 	case E_BOOK_VIEW_STATUS_SIZE_LIMIT_EXCEEDED:
 		str = _("More cards matched this query than either the server is \n"
@@ -963,14 +935,13 @@ search_result (EAddressbookView *eav, EBookViewStatus status, AddressbookView *v
 			"more specific or raise the time limit in the directory server\n"
 			"preferences for this addressbook.");
 		break;
-	case E_BOOK_VIEW_STATUS_INVALID_QUERY:
+	case E_BOOK_VIEW_ERROR_INVALID_QUERY:
 		str = _("The backend for this addressbook was unable to parse this query.");
 		break;
-	case E_BOOK_VIEW_STATUS_QUERY_REFUSED:
+	case E_BOOK_VIEW_ERROR_QUERY_REFUSED:
 		str = _("The backend for this addressbook refused to perform this query.");
 		break;
-	case E_BOOK_VIEW_STATUS_OTHER_ERROR:
-	case E_BOOK_VIEW_STATUS_UNKNOWN:
+	case E_BOOK_VIEW_ERROR_OTHER_ERROR:
 		str = _("This query did not complete successfully.");
 		break;
 	}
@@ -987,54 +958,6 @@ search_result (EAddressbookView *eav, EBookViewStatus status, AddressbookView *v
 	}
 }
 
-static void
-set_folder_bar_label (EAddressbookView *eav, const char *message, AddressbookView *view)
-{
-	CORBA_Environment ev;
-	GNOME_Evolution_ShellView shell_view_interface;
-
-	CORBA_exception_init (&ev);
-
-	shell_view_interface = retrieve_shell_view_interface_from_control (view->control);
-	if (!shell_view_interface) {
-		CORBA_exception_free (&ev);
-		return;
-	}
-
-	d(g_message("Updating via ShellView"));
-
-	if (message == NULL || message[0] == 0) {
-		GNOME_Evolution_ShellView_setFolderBarLabel (shell_view_interface,
-							     "",
-							     &ev);
-	}
-	else {
-		GNOME_Evolution_ShellView_setFolderBarLabel (shell_view_interface,
-							     message,
-							     &ev);
-	}
-
-	if (BONOBO_EX (&ev))
-		g_warning ("Exception in label update: %s",
-			   bonobo_exception_get_text (&ev));
-
-	CORBA_exception_free (&ev);
-
-	bonobo_object_release_unref (shell_view_interface, NULL);
-}
-
-/* Our global singleton config database */
-static Bonobo_ConfigDatabase config_db = NULL;
-
-Bonobo_ConfigDatabase
-addressbook_config_database (CORBA_Environment *ev)
-{
-	if (config_db == NULL)
-		config_db = bonobo_get_object ("wombat:", "Bonobo/ConfigDatabase", ev);
-
-	return config_db;
-}
-
 static int
 compare_subitems (const void *a, const void *b)
 {
@@ -1098,10 +1021,6 @@ BonoboControl *
 addressbook_new_control (void)
 {
 	AddressbookView *view;
-	GtkWidget *frame;
-
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 
 	view = g_new0 (AddressbookView, 1);
 	view->refs = 1;
@@ -1125,15 +1044,13 @@ addressbook_new_control (void)
 	g_signal_connect (view->search, "search_activated",
 			  G_CALLBACK (addressbook_search_activated), view);
 
-	view->view = E_ADDRESSBOOK_VIEW(e_addressbook_view_new());
-	gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET (view->view));
-	gtk_box_pack_start (GTK_BOX (view->vbox), frame,
+	view->view = EAB_VIEW(eab_view_new());
+	gtk_box_pack_start (GTK_BOX (view->vbox), GTK_WIDGET (view->view),
 			    TRUE, TRUE, 0);
 
 	/* create the initial view */
-	change_view_type (view, E_ADDRESSBOOK_VIEW_MINICARD);
+	change_view_type (view, EAB_VIEW_TABLE);
 
-	gtk_widget_show (frame);
 	gtk_widget_show (view->vbox);
 	gtk_widget_show (GTK_WIDGET(view->view));
 	gtk_widget_show (GTK_WIDGET(view->search));
@@ -1141,39 +1058,27 @@ addressbook_new_control (void)
 	view->properties = bonobo_property_bag_new (get_prop, set_prop, view);
 
 	bonobo_property_bag_add (view->properties,
-				 PROPERTY_FOLDER_URI, PROPERTY_FOLDER_URI_IDX,
-				 BONOBO_ARG_STRING, NULL, _("The URI that the Folder Browser will display"), 0);
+				 PROPERTY_SOURCE_UID, PROPERTY_SOURCE_UID_IDX,
+				 BONOBO_ARG_STRING, NULL,
+				 _("UID of the contacts source that the view will display"), 0);
 
 	bonobo_control_set_properties (view->control,
 				       bonobo_object_corba_objref (BONOBO_OBJECT (view->properties)),
 				       NULL);
 
-	g_signal_connect (view->view,
-			  "status_message",
-			  G_CALLBACK(set_status_message),
-			  view);
+	g_signal_connect (view->view, "status_message",
+			  G_CALLBACK(set_status_message), view);
 
-	g_signal_connect (view->view,
-			  "search_result",
-			  G_CALLBACK(search_result),
-			  view);
+	g_signal_connect (view->view, "search_result",
+			  G_CALLBACK(search_result), view);
 
-	g_signal_connect (view->view,
-			  "folder_bar_message",
-			  G_CALLBACK(set_folder_bar_label),
-			  view);
+	g_signal_connect (view->view, "command_state_change",
+			  G_CALLBACK(update_command_state), view);
 
-	g_signal_connect (view->view,
-			  "command_state_change",
-			  G_CALLBACK(update_command_state),
-			  view);
-	
-	g_signal_connect (view->view,
-			  "alphabet_state_change",
-			  G_CALLBACK(alphabet_state_changed),
-			  view);
-	
-	view->uri = NULL;
+	view->gconf_client = gconf_client_get_default ();
+	view->source_list = e_source_list_new_for_gconf (view->gconf_client,
+							 "/apps/evolution/addressbook/sources");
+	view->source = NULL;
 
 	g_signal_connect (view->control, "activate",
 			  G_CALLBACK (control_activate_cb), view);
