@@ -29,20 +29,26 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkbox.h>
 #include <gtk/gtkdialog.h>
+#include <gtk/gtkeventbox.h>
+#include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtktooltips.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-sound.h>
 #include <libgnomeui/gnome-dialog-util.h>
 #include <libgnomeui/gnome-uidefs.h>
-#include <cal-util/timeutil.h>
+#include <e-util/eggtrayicon.h>
+#include <libecal/e-cal-time-util.h>
+#include "evolution-calendar.h"
 #include "alarm.h"
 #include "alarm-notify-dialog.h"
 #include "alarm-queue.h"
 #include "config-data.h"
 #include "save.h"
+#include "util.h"
 
 
 
@@ -61,7 +67,10 @@ static GHashTable *client_alarms_hash = NULL;
 /* Structure that stores a client we are monitoring */
 typedef struct {
 	/* Monitored client */
-	CalClient *client;
+	ECal *client;
+
+	/* Number of times this client has been registered */
+	int refcount;
 
 	/* Hash table of component UID -> CompQueuedAlarms.  If an element is
 	 * present here, then it means its cqa->queued_alarms contains at least
@@ -72,7 +81,7 @@ typedef struct {
 	GHashTable *uid_alarms_hash;
 } ClientAlarms;
 
-/* Pair of a CalComponentAlarms and the mapping from queued alarm IDs to the
+/* Pair of a ECalComponentAlarms and the mapping from queued alarm IDs to the
  * actual alarm instance structures.
  */
 typedef struct {
@@ -83,7 +92,7 @@ typedef struct {
 	char *uid;
 
 	/* The actual component and its alarm instances */
-	CalComponentAlarms *alarms;
+	ECalComponentAlarms *alarms;
 
 	/* List of QueuedAlarm structures */
 	GSList *queued_alarms;
@@ -98,7 +107,7 @@ typedef struct {
 	gpointer alarm_id;
 
 	/* Instance from our parent CompQueuedAlarms->alarms->alarms list */
-	CalAlarmInstance *instance;
+	ECalComponentAlarmInstance *instance;
 
 	/* Whether this is a snoozed queued alarm or a normal one */
 	guint snooze : 1;
@@ -168,7 +177,7 @@ midnight_refresh_cb (gpointer alarm_id, time_t trigger, gpointer data)
 
 /* Looks up a client in the client alarms hash table */
 static ClientAlarms *
-lookup_client (CalClient *client)
+lookup_client (ECal *client)
 {
 	return g_hash_table_lookup (client_alarms_hash, client);
 }
@@ -218,8 +227,8 @@ remove_queued_alarm (CompQueuedAlarms *cqa, gpointer alarm_id,
 
 	if (remove_alarm) {
 		cqa->expecting_update = TRUE;
-		cal_client_discard_alarm (cqa->parent_client->client, cqa->alarms->comp,
-					  qa->instance->auid);
+		e_cal_discard_alarm (cqa->parent_client->client, cqa->alarms->comp,
+					  qa->instance->auid, NULL);
 		cqa->expecting_update = FALSE;
 	}
 
@@ -237,10 +246,10 @@ remove_queued_alarm (CompQueuedAlarms *cqa, gpointer alarm_id,
 		g_free (cqa->uid);
 		cqa->uid = NULL;
 		cqa->parent_client = NULL;
-		cal_component_alarms_free (cqa->alarms);
+		e_cal_component_alarms_free (cqa->alarms);
 		g_free (cqa);
 	} else {
-		cal_component_alarms_free (cqa->alarms);
+		e_cal_component_alarms_free (cqa->alarms);
 		cqa->alarms = NULL;
 	}
 }
@@ -250,10 +259,10 @@ static void
 alarm_trigger_cb (gpointer alarm_id, time_t trigger, gpointer data)
 {
 	CompQueuedAlarms *cqa;
-	CalComponent *comp;
+	ECalComponent *comp;
 	QueuedAlarm *qa;
-	CalComponentAlarm *alarm;
-	CalAlarmAction action;
+	ECalComponentAlarm *alarm;
+	ECalComponentAlarmAction action;
 
 	cqa = data;
 	comp = cqa->alarms->comp;
@@ -271,26 +280,26 @@ alarm_trigger_cb (gpointer alarm_id, time_t trigger, gpointer data)
 	 * occurrence.
 	 */
 
-	alarm = cal_component_get_alarm (comp, qa->instance->auid);
+	alarm = e_cal_component_get_alarm (comp, qa->instance->auid);
 	g_assert (alarm != NULL);
 
-	cal_component_alarm_get_action (alarm, &action);
-	cal_component_alarm_free (alarm);
+	e_cal_component_alarm_get_action (alarm, &action);
+	e_cal_component_alarm_free (alarm);
 
 	switch (action) {
-	case CAL_ALARM_AUDIO:
+	case E_CAL_COMPONENT_ALARM_AUDIO:
 		audio_notification (trigger, cqa, alarm_id);
 		break;
 
-	case CAL_ALARM_DISPLAY:
+	case E_CAL_COMPONENT_ALARM_DISPLAY:
 		display_notification (trigger, cqa, alarm_id, TRUE);
 		break;
 
-	case CAL_ALARM_EMAIL:
+	case E_CAL_COMPONENT_ALARM_EMAIL:
 		mail_notification (trigger, cqa, alarm_id);
 		break;
 
-	case CAL_ALARM_PROCEDURE:
+	case E_CAL_COMPONENT_ALARM_PROCEDURE:
 		procedure_notification (trigger, cqa, alarm_id);
 		break;
 
@@ -300,11 +309,11 @@ alarm_trigger_cb (gpointer alarm_id, time_t trigger, gpointer data)
 	}
 }
 
-/* Adds the alarms in a CalComponentAlarms structure to the alarms queued for a
+/* Adds the alarms in a ECalComponentAlarms structure to the alarms queued for a
  * particular client.  Also puts the triggers in the alarm timer queue.
  */
 static void
-add_component_alarms (ClientAlarms *ca, CalComponentAlarms *alarms)
+add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 {
 	const char *uid;
 	CompQueuedAlarms *cqa;
@@ -312,7 +321,7 @@ add_component_alarms (ClientAlarms *ca, CalComponentAlarms *alarms)
 
 	/* No alarms? */
 	if (alarms->alarms == NULL) {
-		cal_component_alarms_free (alarms);
+		e_cal_component_alarms_free (alarms);
 		return;
 	}
 
@@ -324,7 +333,7 @@ add_component_alarms (ClientAlarms *ca, CalComponentAlarms *alarms)
 	cqa->queued_alarms = NULL;
 
 	for (l = alarms->alarms; l; l = l->next) {
-		CalAlarmInstance *instance;
+		ECalComponentAlarmInstance *instance;
 		gpointer alarm_id;
 		QueuedAlarm *qa;
 
@@ -345,14 +354,14 @@ add_component_alarms (ClientAlarms *ca, CalComponentAlarms *alarms)
 		cqa->queued_alarms = g_slist_prepend (cqa->queued_alarms, qa);
 	}
 
-	cal_component_get_uid (alarms->comp, &uid);
+	e_cal_component_get_uid (alarms->comp, &uid);
 
 	/* If we failed to add all the alarms, then we should get rid of the cqa */
 	if (cqa->queued_alarms == NULL) {
 		g_message ("add_component_alarms(): Could not add any of the alarms "
 			   "for the component `%s'; discarding it...", uid);
 
-		cal_component_alarms_free (cqa->alarms);
+		e_cal_component_alarms_free (cqa->alarms);
 		cqa->alarms = NULL;
 
 		g_free (cqa);
@@ -371,10 +380,10 @@ load_alarms (ClientAlarms *ca, time_t start, time_t end)
 	GSList *comp_alarms;
 	GSList *l;
 
-	comp_alarms = cal_client_get_alarms_in_range (ca->client, start, end);
+	comp_alarms = e_cal_get_alarms_in_range (ca->client, start, end);
 
 	for (l = comp_alarms; l; l = l->next) {
-		CalComponentAlarms *alarms;
+		ECalComponentAlarms *alarms;
 
 		alarms = l->data;
 		add_component_alarms (ca, alarms);
@@ -419,13 +428,13 @@ load_missed_alarms (ClientAlarms *ca)
 
 /* Called when a calendar client finished loading; we load its alarms */
 static void
-cal_opened_cb (CalClient *client, CalClientOpenStatus status, gpointer data)
+cal_opened_cb (ECal *client, ECalendarStatus status, gpointer data)
 {
 	ClientAlarms *ca;
 
 	ca = data;
 
-	if (status != CAL_CLIENT_OPEN_SUCCESS)
+	if (status != E_CALENDAR_STATUS_OK)
 		return;
 
 	load_alarms_for_today (ca);
@@ -488,11 +497,11 @@ remove_comp (ClientAlarms *ca, const char *uid)
  * alarms.
  */
 static void
-obj_updated_cb (CalClient *client, const char *uid, gpointer data)
+obj_updated_cb (ECal *client, const char *uid, gpointer data)
 {
 	ClientAlarms *ca;
 	time_t now, day_end;
-	CalComponentAlarms *alarms;
+	ECalComponentAlarms *alarms;
 	gboolean found;
 	icaltimezone *zone;
 	CompQueuedAlarms *cqa;
@@ -505,7 +514,7 @@ obj_updated_cb (CalClient *client, const char *uid, gpointer data)
 
 	day_end = time_day_end_with_zone (now, zone);
 
-	found = cal_client_get_alarms_for_object (ca->client, uid, now, day_end, &alarms);
+	found = e_cal_get_alarms_for_object (ca->client, uid, now, day_end, &alarms);
 
 	if (!found) {
 		remove_comp (ca, uid);
@@ -525,7 +534,7 @@ obj_updated_cb (CalClient *client, const char *uid, gpointer data)
 
 		/* add the new alarms */
 		for (l = cqa->alarms->alarms; l; l = l->next) {
-			CalAlarmInstance *instance;
+			ECalComponentAlarmInstance *instance;
 			gpointer alarm_id;
 			QueuedAlarm *qa;
 
@@ -558,7 +567,7 @@ obj_updated_cb (CalClient *client, const char *uid, gpointer data)
  * alarms.
  */
 static void
-obj_removed_cb (CalClient *client, const char *uid, gpointer data)
+obj_removed_cb (ECal *client, const char *uid, gpointer data)
 {
 	ClientAlarms *ca;
 
@@ -602,21 +611,21 @@ create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, int snooze_mins)
 
 /* Launches a component editor for a component */
 static void
-edit_component (CalClient *client, CalComponent *comp)
+edit_component (ECal *client, ECalComponent *comp)
 {
 	const char *uid;
 	const char *uri;
 	CORBA_Environment ev;
 	GNOME_Evolution_Calendar_CompEditorFactory factory;
 
-	cal_component_get_uid (comp, &uid);
+	e_cal_component_get_uid (comp, &uid);
 
-	uri = cal_client_get_uri (client);
+	uri = e_cal_get_uri (client);
 
 	/* Get the factory */
 
 	CORBA_exception_init (&ev);
-	factory = bonobo_activation_activate_from_id ("OAFIID:GNOME_Evolution_Calendar_CompEditorFactory",
+	factory = bonobo_activation_activate_from_id ("OAFIID:GNOME_Evolution_Calendar_CompEditorFactory:" BASE_VERSION,
 						      0, NULL, &ev);
 
 	if (ev._major != CORBA_NO_EXCEPTION) {
@@ -646,32 +655,75 @@ edit_component (CalClient *client, CalComponent *comp)
 	CORBA_exception_free (&ev);
 }
 
-struct notify_dialog_closure {
+
+/* /\* Callback used from the alarm notify dialog *\/ */
+/* static void */
+/* notify_dialog_cb (AlarmNotifyResult result, int snooze_mins, gpointer data) */
+/* { */
+
+/* 	switch (result) { */
+/* 	case ALARM_NOTIFY_SNOOZE: */
+/* 		create_snooze (c->cqa, c->alarm_id, snooze_mins); */
+
+/* 		g_object_unref (c->comp); */
+/* 		g_object_unref (c->client); */
+/* 		g_free (c); */
+/* 		return; */
+
+/* 	case ALARM_NOTIFY_EDIT: */
+/* 		edit_component (c->client, c->comp); */
+/* 		break; */
+
+/* 	case ALARM_NOTIFY_CLOSE: */
+/* 		/\* Do nothing *\/ */
+/* 		break; */
+
+/* 	default: */
+/* 		g_assert_not_reached (); */
+/* 	} */
+
+/* 	if (c->cqa != NULL) */
+/* 		remove_queued_alarm (c->cqa, c->alarm_id, TRUE, TRUE); */
+/* 	g_object_unref (c->comp); */
+/* 	g_object_unref (c->client); */
+/* 	g_free (c); */
+/* } */
+
+typedef struct {
+	char *message;
+	gboolean blink_state;
+	gint blink_id;
+	time_t trigger;
 	CompQueuedAlarms *cqa;
 	gpointer alarm_id;
-	CalClient *client;
-	CalComponent *comp;
-	gpointer dialog;
-};
+	ECalComponent *comp;
+	ECal *client;
+	GtkWidget *tray_icon;
+	GtkWidget *image;
+	GtkWidget *alarm_dialog;
+} TrayIconData;
 
 static void
-on_dialog_obj_updated_cb (CalClient *client, const char *uid, gpointer data)
+on_dialog_obj_updated_cb (ECal *client, const char *uid, gpointer data)
 {
+/* commented out so gcc won't complain about the unused variable
+	struct notify_dialog_closure *c = data;
+*/
 }
 
 static void
-on_dialog_obj_removed_cb (CalClient *client, const char *uid, gpointer data)
+on_dialog_obj_removed_cb (ECal *client, const char *uid, gpointer data)
 {
 	const char *our_uid;
-	struct notify_dialog_closure *c = data;
+	TrayIconData *tray_data = data;
 
-	cal_component_get_uid (c->comp, &our_uid);
+	e_cal_component_get_uid (tray_data->comp, &our_uid);
 	g_return_if_fail (our_uid && *our_uid);
 
 	if (!strcmp (uid, our_uid)) {
-		alarm_notify_dialog_disable_buttons (c->dialog);
-		c->cqa = NULL;
-		c->alarm_id = NULL;
+		alarm_notify_dialog_disable_buttons (tray_data->alarm_dialog);
+		tray_data->cqa = NULL;
+		tray_data->alarm_id = NULL;
 	}
 }
 
@@ -679,26 +731,19 @@ on_dialog_obj_removed_cb (CalClient *client, const char *uid, gpointer data)
 static void
 notify_dialog_cb (AlarmNotifyResult result, int snooze_mins, gpointer data)
 {
-	struct notify_dialog_closure *c;
+	TrayIconData *tray_data = data;
 
-	c = data;
-
-	g_signal_handlers_disconnect_matched (c->client, G_SIGNAL_MATCH_FUNC,
-					      0, 0, NULL, on_dialog_obj_updated_cb, NULL);
-	g_signal_handlers_disconnect_matched (c->client, G_SIGNAL_MATCH_FUNC,
+	g_signal_handlers_disconnect_matched (tray_data->client, G_SIGNAL_MATCH_FUNC,
 					      0, 0, NULL, on_dialog_obj_removed_cb, NULL);
 
 	switch (result) {
 	case ALARM_NOTIFY_SNOOZE:
-		create_snooze (c->cqa, c->alarm_id, snooze_mins);
-
-		g_object_unref (c->comp);
-		g_object_unref (c->client);
-		g_free (c);
+		create_snooze (tray_data->cqa, tray_data->alarm_id, snooze_mins);
+		tray_data->cqa = NULL;
 		return;
 
 	case ALARM_NOTIFY_EDIT:
-		edit_component (c->client, c->comp);
+		edit_component (tray_data->client, tray_data->comp);
 		break;
 
 	case ALARM_NOTIFY_CLOSE:
@@ -709,11 +754,83 @@ notify_dialog_cb (AlarmNotifyResult result, int snooze_mins, gpointer data)
 		g_assert_not_reached ();
 	}
 
-	if (c->cqa != NULL)
-		remove_queued_alarm (c->cqa, c->alarm_id, TRUE, TRUE);
-	g_object_unref (c->comp);
-	g_object_unref (c->client);
-	g_free (c);
+	tray_data->alarm_dialog = NULL;
+	gtk_widget_destroy (tray_data->tray_icon);
+}
+
+static gint
+tray_icon_destroyed_cb (GtkWidget *tray, gpointer user_data)
+{
+	TrayIconData *tray_data = user_data;
+
+	if (tray_data->cqa != NULL)
+		remove_queued_alarm (tray_data->cqa, tray_data->alarm_id, TRUE, TRUE);
+
+	if (tray_data->message != NULL) {
+		g_free (tray_data->message);
+		tray_data->message = NULL;
+	}
+
+	g_source_remove (tray_data->blink_id);
+
+	g_object_unref (tray_data->comp);
+	g_object_unref (tray_data->client);
+	g_free (tray_data);
+
+	return TRUE;
+}
+
+static gint
+tray_icon_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+	TrayIconData *tray_data = user_data;
+
+	if (event->type == GDK_BUTTON_PRESS) {
+		if (event->button == 1) {
+			QueuedAlarm *qa;
+
+			if (tray_data->alarm_dialog != NULL)
+				return FALSE;
+
+			qa = lookup_queued_alarm (tray_data->cqa, tray_data->alarm_id);
+			if (qa) {
+				gtk_widget_hide (tray_data->tray_icon);
+				tray_data->alarm_dialog = alarm_notify_dialog (
+					tray_data->trigger,
+					qa->instance->occur_start,
+					qa->instance->occur_end,
+					e_cal_component_get_vtype (tray_data->comp),
+					tray_data->message,
+					notify_dialog_cb, tray_data);
+				if (tray_data->alarm_dialog) {
+					g_signal_connect (G_OBJECT (tray_data->client), "obj_removed",
+							  G_CALLBACK (on_dialog_obj_removed_cb), tray_data);
+				}
+			}
+
+			return TRUE;
+		} else if (event->button == 2) {
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
+static gboolean
+tray_icon_blink_cb (gpointer data)
+{
+	TrayIconData *tray_data = data;
+
+	/* FIXME: Use stock image equivalents when they become available */
+
+	tray_data->blink_state = tray_data->blink_state == TRUE ? FALSE : TRUE;
+	gtk_image_set_from_file (GTK_IMAGE (tray_data->image),
+				 tray_data->blink_state == TRUE ?
+				 EVOLUTION_IMAGESDIR "/appointment-reminder-excl.png" :
+				 EVOLUTION_IMAGESDIR "/appointment-reminder.png");
+
+	return TRUE;
 }
 
 /* Performs notification of a display alarm */
@@ -721,69 +838,93 @@ static void
 display_notification (time_t trigger, CompQueuedAlarms *cqa,
 		      gpointer alarm_id, gboolean use_description)
 {
-	CalComponent *comp;
-	CalComponentVType vtype;
-	CalComponentText text;
 	QueuedAlarm *qa;
+	ECalComponent *comp;
+	ECal *client;
+	ECalComponentVType vtype;
 	const char *message;
-	struct notify_dialog_closure *c;
-	gboolean use_summary;
+	ECalComponentAlarm *alarm;
+	GtkWidget *tray_icon, *image, *ebox;
+	GtkTooltips *tooltips;
+	TrayIconData *tray_data;
+	ECalComponentText text;
+	char *str, *start_str, *end_str, *alarm_str;
+	icaltimezone *current_zone;
 
 	comp = cqa->alarms->comp;
 	qa = lookup_queued_alarm (cqa, alarm_id);
 	if (!qa)
 		return;
 
-	vtype = cal_component_get_vtype (comp);
+	vtype = e_cal_component_get_vtype (comp);
 
-	/* Pick a sensible notification message.  First we try the DESCRIPTION
-	 * from the alarm, then the SUMMARY of the component.
-	 */
+	/* get a sensible description for the event */
+	alarm = e_cal_component_get_alarm (comp, qa->instance->auid);
+	g_assert (alarm != NULL);
 
-	use_summary = TRUE;
-	message = NULL;
+	e_cal_component_alarm_get_description (alarm, &text);
+	e_cal_component_alarm_free (alarm);
 
-	if (use_description) {
-		CalComponentAlarm *alarm;
-
-		alarm = cal_component_get_alarm (comp, qa->instance->auid);
-		g_assert (alarm != NULL);
-
-		cal_component_alarm_get_description (alarm, &text);
-		cal_component_alarm_free (alarm);
-
-		if (text.value) {
-			message = text.value;
-			use_summary = FALSE;
-		}
-	}
-
-	if (use_summary) {
-		cal_component_get_summary (comp, &text);
-		if (text.value)
-			message = text.value;
-		else
-			message = _("No description available.");
-	}
-
-	c = g_new (struct notify_dialog_closure, 1);
-	c->cqa = cqa;
-	c->alarm_id = alarm_id;
-	c->comp = cal_component_clone (comp);
-	c->client = c->cqa->parent_client->client;
-	g_object_ref (c->client);
-
-	if (!(c->dialog = alarm_notify_dialog (trigger,
-					       qa->instance->occur_start, qa->instance->occur_end,
-					       vtype, message,
-					       notify_dialog_cb, c)))
-		g_message ("display_notification(): Could not create the alarm notify dialog");
+	if (text.value)
+		message = text.value;
 	else {
-		g_signal_connect (c->client, "obj_updated",
-				  G_CALLBACK (on_dialog_obj_updated_cb), c);
-		g_signal_connect (c->client, "obj_removed",
-				  G_CALLBACK (on_dialog_obj_removed_cb), c);
+		e_cal_component_get_summary (comp, &text); 
+ 		if (text.value)
+ 			message = text.value;
+ 		else
+ 			message = _("No description available.");
 	}
+
+	/* create the tray icon */
+	tooltips = gtk_tooltips_new ();
+
+	/* FIXME: Use stock image equivalent when it becomes available */
+	tray_icon = egg_tray_icon_new (qa->instance->auid);
+	image = gtk_image_new_from_file (EVOLUTION_IMAGESDIR "/appointment-reminder.png");
+	ebox = gtk_event_box_new ();
+
+	gtk_widget_show (image);
+	gtk_widget_show (ebox);
+
+	current_zone = config_data_get_timezone ();
+	alarm_str = timet_to_str_with_zone (trigger, current_zone);
+	start_str = timet_to_str_with_zone (qa->instance->occur_start, current_zone);
+	end_str = timet_to_str_with_zone (qa->instance->occur_end, current_zone);
+	str = g_strdup_printf (_("Alarm on %s\n%s\nStarting at %s\nEnding at %s"),
+			       alarm_str, message, start_str, end_str);
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (tooltips), ebox, str, str);
+	g_free (start_str);
+	g_free (end_str);
+	g_free (alarm_str);
+	g_free (str);
+	
+	g_object_set_data (G_OBJECT (tray_icon), "image", image);
+	g_object_set_data (G_OBJECT (tray_icon), "available", GINT_TO_POINTER (1));
+
+	gtk_container_add (GTK_CONTAINER (ebox), image);
+	gtk_container_add (GTK_CONTAINER (tray_icon), ebox);
+
+	/* create the private structure */
+	tray_data = g_new0 (TrayIconData, 1);
+	tray_data->message = g_strdup (message);
+	tray_data->trigger = trigger;
+	tray_data->cqa = cqa;
+	tray_data->alarm_id = alarm_id;
+	tray_data->comp = e_cal_component_clone (comp);
+	tray_data->client = cqa->parent_client->client;
+	tray_data->image = image;
+	tray_data->blink_state = FALSE;
+	g_object_ref (tray_data->client);
+	tray_data->tray_icon = tray_icon;
+
+	g_signal_connect (G_OBJECT (tray_icon), "destroy",
+			  G_CALLBACK (tray_icon_destroyed_cb), tray_data);
+	g_signal_connect (G_OBJECT (ebox), "button_press_event",
+			  G_CALLBACK (tray_icon_clicked_cb), tray_data);
+
+	tray_data->blink_id = g_timeout_add (500, tray_icon_blink_cb, tray_data);
+
+	gtk_widget_show (tray_icon);
 }
 
 /* Performs notification of an audio alarm */
@@ -792,8 +933,8 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 		    gpointer alarm_id)
 {
 	QueuedAlarm *qa;
-	CalComponent *comp;
-	CalComponentAlarm *alarm;
+	ECalComponent *comp;
+	ECalComponentAlarm *alarm;
 	icalattach *attach;
 
 	comp = cqa->alarms->comp;
@@ -801,11 +942,11 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (!qa)
 		return;
 
-	alarm = cal_component_get_alarm (comp, qa->instance->auid);
+	alarm = e_cal_component_get_alarm (comp, qa->instance->auid);
 	g_assert (alarm != NULL);
 
-	cal_component_alarm_get_attach (alarm, &attach);
-	cal_component_alarm_free (alarm);
+	e_cal_component_alarm_get_attach (alarm, &attach);
+	e_cal_component_alarm_free (alarm);
 
 	if (attach && icalattach_get_is_url (attach)) {
 		const char *url;
@@ -898,9 +1039,9 @@ static void
 procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id)
 {
 	QueuedAlarm *qa;
-	CalComponent *comp;
-	CalComponentAlarm *alarm;
-	CalComponentText description;
+	ECalComponent *comp;
+	ECalComponentAlarm *alarm;
+	ECalComponentText description;
 	icalattach *attach;
 	const char *url;
 	char *cmd;
@@ -911,12 +1052,12 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	if (!qa)
 		return;
 
-	alarm = cal_component_get_alarm (comp, qa->instance->auid);
+	alarm = e_cal_component_get_alarm (comp, qa->instance->auid);
 	g_assert (alarm != NULL);
 
-	cal_component_alarm_get_attach (alarm, &attach);
-	cal_component_alarm_get_description (alarm, &description);
-	cal_component_alarm_free (alarm);
+	e_cal_component_alarm_get_attach (alarm, &attach);
+	e_cal_component_alarm_get_description (alarm, &description);
+	e_cal_component_alarm_free (alarm);
 
 	/* If the alarm has no attachment, simply display a notification dialog. */
 	if (!attach)
@@ -982,65 +1123,14 @@ alarm_queue_init (void)
 	alarm_queue_inited = TRUE;
 }
 
-/* Called from g_hash_table_foreach(); adds a component UID to a list */
-static void
-add_uid_cb (gpointer key, gpointer value, gpointer data)
-{
-	GSList **uids;
-	const char *uid;
-
-	uids = data;
-	uid = key;
-
-	*uids = g_slist_prepend (*uids, (char *) uid);
-}
-
-/* Removes all the alarms queued for a particular calendar client */
-static void
-remove_client_alarms (ClientAlarms *ca)
-{
-	GSList *uids;
-	GSList *l;
-
-	/* First we build a list of UIDs so that we can remove them one by one */
-
-	uids = NULL;
-	g_hash_table_foreach (ca->uid_alarms_hash, add_uid_cb, &uids);
-
-	for (l = uids; l; l = l->next) {
-		const char *uid;
-
-		uid = l->data;
-
-		remove_comp (ca, uid);
-	}
-
-	g_slist_free (uids);
-
-	/* The hash table should be empty now */
-
-	g_assert (g_hash_table_size (ca->uid_alarms_hash) == 0);
-}
-
 static void
 free_client_alarms_cb (gpointer key, gpointer value, gpointer user_data)
 {
+	ECal *client = key;
 	ClientAlarms *ca = value;
 
 	if (ca) {
-		remove_client_alarms (ca);
-
-		/* Clean up */
-
-		g_signal_handlers_disconnect_matched (ca->client, G_SIGNAL_MATCH_DATA,
-						      0, 0, NULL, NULL, ca);
-
 		g_object_unref (ca->client);
-		ca->client = NULL;
-
-		g_hash_table_destroy (ca->uid_alarms_hash);
-		ca->uid_alarms_hash = NULL;
-
 		g_free (ca);
 	}
 }
@@ -1086,28 +1176,31 @@ alarm_queue_done (void)
  * queueing system when it is no longer wanted.
  **/
 void
-alarm_queue_add_client (CalClient *client)
+alarm_queue_add_client (ECal *client)
 {
 	ClientAlarms *ca;
 
 	g_return_if_fail (alarm_queue_inited);
 	g_return_if_fail (client != NULL);
-	g_return_if_fail (IS_CAL_CLIENT (client));
+	g_return_if_fail (E_IS_CAL (client));
 
 	ca = lookup_client (client);
-	if (ca)
+	if (ca) {
+		ca->refcount++;
 		return;
+	}
 
 	ca = g_new (ClientAlarms, 1);
 
 	ca->client = client;
 	g_object_ref (ca->client);
 
+	ca->refcount = 1;
 	g_hash_table_insert (client_alarms_hash, client, ca);
 
 	ca->uid_alarms_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
-	if (cal_client_get_load_state (client) != CAL_CLIENT_LOAD_LOADED)
+	if (e_cal_get_load_state (client) != E_CAL_LOAD_LOADED)
 		g_signal_connect (client, "cal_opened",
 				  G_CALLBACK (cal_opened_cb),
 				  ca);
@@ -1119,12 +1212,52 @@ alarm_queue_add_client (CalClient *client)
 			  G_CALLBACK (obj_removed_cb),
 			  ca);
 
-	if (cal_client_get_load_state (client) == CAL_CLIENT_LOAD_LOADED) {
+	if (e_cal_get_load_state (client) == E_CAL_LOAD_LOADED) {
 		load_alarms_for_today (ca);
 		load_missed_alarms (ca);
 	}
 }
 
+/* Called from g_hash_table_foreach(); adds a component UID to a list */
+static void
+add_uid_cb (gpointer key, gpointer value, gpointer data)
+{
+	GSList **uids;
+	const char *uid;
+
+	uids = data;
+	uid = key;
+
+	*uids = g_slist_prepend (*uids, (char *) uid);
+}
+
+/* Removes all the alarms queued for a particular calendar client */
+static void
+remove_client_alarms (ClientAlarms *ca)
+{
+	GSList *uids;
+	GSList *l;
+
+	/* First we build a list of UIDs so that we can remove them one by one */
+
+	uids = NULL;
+	g_hash_table_foreach (ca->uid_alarms_hash, add_uid_cb, &uids);
+
+	for (l = uids; l; l = l->next) {
+		const char *uid;
+
+		uid = l->data;
+
+		remove_comp (ca, uid);
+	}
+
+	g_slist_free (uids);
+
+	/* The hash table should be empty now */
+
+	g_assert (g_hash_table_size (ca->uid_alarms_hash) == 0);
+}
+
 /**
  * alarm_queue_remove_client:
  * @client: A calendar client.
@@ -1132,17 +1265,23 @@ alarm_queue_add_client (CalClient *client)
  * Removes a calendar client from the alarm queueing system.
  **/
 void
-alarm_queue_remove_client (CalClient *client)
+alarm_queue_remove_client (ECal *client)
 {
 	ClientAlarms *ca;
 
 	g_return_if_fail (alarm_queue_inited);
 	g_return_if_fail (client != NULL);
-	g_return_if_fail (IS_CAL_CLIENT (client));
+	g_return_if_fail (E_IS_CAL (client));
 
 	ca = lookup_client (client);
 	g_return_if_fail (ca != NULL);
 
+	g_assert (ca->refcount > 0);
+	ca->refcount--;
+
+	if (ca->refcount > 0)
+		return;
+
 	remove_client_alarms (ca);
 
 	/* Clean up */
