@@ -1,8 +1,10 @@
 /* Evolution calendar - Alarm notification service main file
  *
  * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 2003 Novell, Inc.
  *
- * Author: Federico Mena-Quintero <federico@ximian.com>
+ * Authors: Federico Mena-Quintero <federico@ximian.com>
+ *          Rodrigo Moya <rodrigo@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -34,9 +36,11 @@
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-generic-factory.h>
 #include <bonobo-activation/bonobo-activation.h>
+#include <libedataserver/e-source.h>
 #include "alarm.h"
 #include "alarm-queue.h"
 #include "alarm-notify.h"
+#include "config-data.h"
 #include "save.h"
 
 
@@ -57,28 +61,15 @@ client_die_cb (GnomeClient *client)
 	bonobo_main_quit ();
 }
 
-static gint
-save_session_cb (GnomeClient *client, GnomeSaveStyle save_style, gint shutdown,
-		 GnomeInteractStyle interact_style, gint fast, gpointer user_data)
-{
-	char *args[2];
-
-	args[0] = EVOLUTION_LIBEXECDIR "/evolution-alarm-notify";
-	args[1] = NULL;
-
-	gnome_client_set_restart_command (master_client, 1, args);
-
-	return TRUE;
-}
-
 /* Sees if a session manager is present.  If so, it tells the SM how to restart
  * the daemon when the session starts.  It also sets the die callback so that
  * the daemon can terminate properly when the session ends.
  */
 static void
-init_session (void)
+set_session_parameters (char **argv)
 {
 	int flags;
+	char *args[2];
 
 	master_client = gnome_master_client ();
 	flags = gnome_client_get_flags (master_client);
@@ -90,12 +81,15 @@ init_session (void)
 	 * the session starts.  The daemon will take care of loading whatever
 	 * calendars it was told to load.
 	 */
-	gnome_client_set_restart_style (master_client, GNOME_RESTART_IF_RUNNING);
+	gnome_client_set_restart_style (master_client, GNOME_RESTART_ANYWAY);
+
+	args[0] = argv[0];
+	args[1] = NULL;
+
+	gnome_client_set_restart_command (master_client, 1, args);
 
 	g_signal_connect (G_OBJECT (master_client), "die",
 			  G_CALLBACK (client_die_cb), NULL);
-	g_signal_connect (G_OBJECT (master_client), "save_yourself",
-			  G_CALLBACK (save_session_cb), NULL);
 }
 
 /* Factory function for the alarm notify service; just creates and references a
@@ -109,15 +103,14 @@ alarm_notify_factory_fn (BonoboGenericFactory *factory, const char *component_id
 		g_assert (alarm_notify_service != NULL);
 	}
 
-	bonobo_object_ref (BONOBO_OBJECT (alarm_notify_service));
-	return BONOBO_OBJECT (alarm_notify_service);
+	return NULL;
 }
 
 /* Loads the calendars that the alarm daemon has been told to load in the past */
 static gboolean
 load_calendars (gpointer user_data)
 {
-	GPtrArray *uris;
+	GPtrArray *cals;
 	int i;
 
 	alarm_queue_init ();
@@ -128,42 +121,24 @@ load_calendars (gpointer user_data)
 		g_assert (alarm_notify_service != NULL);
 	}
 
-	uris = get_calendars_to_load ();
-	if (!uris) {
+	cals = config_data_get_calendars_to_load ();
+	if (!cals) {
 		g_message ("load_calendars(): Could not get the list of calendars to load");
 		return TRUE; /* should we continue retrying? */;
 	}
 
-	for (i = 0; i < uris->len; i++) {
+	for (i = 0; i < cals->len; i++) {
+		ESource *source;
 		char *uri;
-		CORBA_Environment ev;
 
-		uri = uris->pdata[i];
-
-		CORBA_exception_init (&ev);
-		alarm_notify_add_calendar (alarm_notify_service, uri, FALSE, &ev);
-
-		if (ev._major == CORBA_USER_EXCEPTION) {
-			char *ex_id;
-			
-			ex_id = CORBA_exception_id (&ev);
-			if (strcmp (ex_id, ex_GNOME_Evolution_Calendar_AlarmNotify_InvalidURI) == 0)
-				g_message ("load_calendars(): Invalid URI `%s'; will not load "
-					   "that calendar.", uri);
-			else if (strcmp (ex_id,
-					 ex_GNOME_Evolution_Calendar_AlarmNotify_BackendContactError)
-				 == 0)
-				g_message ("load_calendars(): Could not contact the backend "
-					   "while trying to load `%s'", uri);
-		} else if (ev._major != CORBA_NO_EXCEPTION)
-			g_message ("load_calendars(): Exception while loading calendar `%s'", uri);
-
-		CORBA_exception_free (&ev);
+		source = cals->pdata[i];
 
+		uri = e_source_get_uri (source);
+		alarm_notify_add_calendar (alarm_notify_service, uri, FALSE);
 		g_free (uri);
 	}
 
-	g_ptr_array_free (uris, TRUE);
+	g_ptr_array_free (cals, TRUE);
 
 	return FALSE;
 }
@@ -188,12 +163,12 @@ main (int argc, char **argv)
 
 	gnome_sound_init ("localhost");
 
-	factory = bonobo_generic_factory_new ("OAFIID:GNOME_Evolution_Calendar_AlarmNotify_Factory",
+	factory = bonobo_generic_factory_new ("OAFIID:GNOME_Evolution_Calendar_AlarmNotify:" BASE_VERSION,
 					      (BonoboFactoryCallback) alarm_notify_factory_fn, NULL);
 	if (!factory)
 		g_error (_("Could not create the alarm notify service factory"));
 
-	init_session ();
+	set_session_parameters (argv);
 
 	g_idle_add ((GSourceFunc) load_calendars, NULL);
 
@@ -202,6 +177,8 @@ main (int argc, char **argv)
 	bonobo_object_unref (BONOBO_OBJECT (factory));
 	factory = NULL;
 
+	bonobo_object_unref (BONOBO_OBJECT (alarm_notify_service));
+
 	alarm_queue_done ();
 	alarm_done ();
 
