@@ -22,10 +22,6 @@
 #define SAVE_H
 
 #include <time.h>
-#include <bonobo-conf/bonobo-config-database.h>
-
-Bonobo_ConfigDatabase get_config_db (void);
-void discard_config_db (Bonobo_ConfigDatabase db);
 
 void save_notification_time (time_t t);
 time_t get_saved_notification_time (void);
@@ -33,4 +29,7 @@ time_t get_saved_notification_time (void);
 void save_calendars_to_load (GPtrArray *uris);
 GPtrArray *get_calendars_to_load (void);
 
+void save_blessed_program (const char *program);
+gboolean is_blessed_program (const char *program);
+
 #endif
