@@ -30,6 +30,7 @@
 #ifndef _CALENDAR_CONFIG_H_
 #define _CALENDAR_CONFIG_H_
 
+#include <gconf/gconf-client.h>
 #include <widgets/misc/e-calendar.h>
 #include <widgets/misc/e-dateedit.h>
 #include <widgets/misc/e-cell-date-edit.h>
@@ -61,56 +62,78 @@ typedef enum
 
 
 void	  calendar_config_init			(void);
-
+void calendar_config_remove_notification (guint id);
 
 /*
  * Calendar Settings.
  */
 
+/* The current list of calendars selected */
+GSList   *calendar_config_get_calendars_selected (void);
+void	  calendar_config_set_calendars_selected (GSList *selected);
+guint	  calendar_config_add_notification_calendars_selected (GConfClientNotifyFunc func, gpointer data);
+
+/* The primary calendar */
+char     *calendar_config_get_primary_calendar (void);
+void	  calendar_config_set_primary_calendar (const char *primary_uid);
+guint	  calendar_config_add_notification_primary_calendar (GConfClientNotifyFunc func, gpointer data);
+
 /* The current timezone, e.g. "Europe/London". */
 gchar*	  calendar_config_get_timezone		(void);
 void	  calendar_config_set_timezone		(gchar	     *timezone);
+guint calendar_config_add_notification_timezone (GConfClientNotifyFunc func, gpointer data);
 
 /* The working days of the week, a bit-wise combination of flags. */
 CalWeekdays calendar_config_get_working_days	(void);
 void	  calendar_config_set_working_days	(CalWeekdays  days);
+guint calendar_config_add_notification_working_days (GConfClientNotifyFunc func, gpointer data);
 
 /* The start day of the week (0 = Sun to 6 = Sat). */
 gint	  calendar_config_get_week_start_day	(void);
 void	  calendar_config_set_week_start_day	(gint	      week_start_day);
+guint calendar_config_add_notification_week_start_day (GConfClientNotifyFunc func, gpointer data);
 
 /* The start and end times of the work-day. */
 gint	  calendar_config_get_day_start_hour	(void);
 void	  calendar_config_set_day_start_hour	(gint	      day_start_hour);
+guint calendar_config_add_notification_day_start_hour (GConfClientNotifyFunc func, gpointer data);
 
 gint	  calendar_config_get_day_start_minute	(void);
 void	  calendar_config_set_day_start_minute	(gint	      day_start_min);
+guint calendar_config_add_notification_day_start_minute (GConfClientNotifyFunc func, gpointer data);
 
 gint	  calendar_config_get_day_end_hour	(void);
 void	  calendar_config_set_day_end_hour	(gint	      day_end_hour);
+guint calendar_config_add_notification_day_end_hour (GConfClientNotifyFunc func, gpointer data);
 
 gint	  calendar_config_get_day_end_minute	(void);
 void	  calendar_config_set_day_end_minute	(gint	      day_end_min);
+guint calendar_config_add_notification_day_end_minute (GConfClientNotifyFunc func, gpointer data);
 
 /* Whether we use 24-hour format or 12-hour format (AM/PM). */
 gboolean  calendar_config_get_24_hour_format	(void);
 void	  calendar_config_set_24_hour_format	(gboolean     use_24_hour);
+guint calendar_config_add_notification_24_hour_format (GConfClientNotifyFunc func, gpointer data);
 
 /* The time divisions in the Day/Work-Week view in minutes (5/10/15/30/60). */
 gint	  calendar_config_get_time_divisions	(void);
 void	  calendar_config_set_time_divisions	(gint	      divisions);
+guint calendar_config_add_notification_time_divisions (GConfClientNotifyFunc func, gpointer data);
 
 /* Whether we show event end times. */
 gboolean  calendar_config_get_show_event_end	(void);
 void	  calendar_config_set_show_event_end	(gboolean     show_end);
+guint calendar_config_add_notification_show_event_end (GConfClientNotifyFunc func, gpointer data);
 
 /* Whether we compress the weekend in the week/month views. */
 gboolean  calendar_config_get_compress_weekend	(void);
 void	  calendar_config_set_compress_weekend	(gboolean     compress);
+guint calendar_config_add_notification_compress_weekend (GConfClientNotifyFunc func, gpointer data);
 
 /* Whether we show week numbers in the Date Navigator. */
 gboolean  calendar_config_get_dnav_show_week_no	(void);
 void	  calendar_config_set_dnav_show_week_no	(gboolean     show_week_no);
+guint calendar_config_add_notification_dnav_show_week_no (GConfClientNotifyFunc func, gpointer data);
 
 /* The view to show on start-up, 0 = Day, 1 = WorkWeek, 2 = Week, 3 = Month. */
 gint	  calendar_config_get_default_view	(void);
@@ -129,6 +152,20 @@ void	  calendar_config_set_month_hpane_pos	(gint	      hpane_pos);
 gint      calendar_config_get_month_vpane_pos	(void);
 void	  calendar_config_set_month_vpane_pos	(gint	      vpane_pos);
 
+/* The current list of task lists selected */
+GSList   *calendar_config_get_tasks_selected (void);
+void	  calendar_config_set_tasks_selected (GSList *selected);
+guint	  calendar_config_add_notification_tasks_selected (GConfClientNotifyFunc func, gpointer data);
+
+/* The primary calendar */
+char     *calendar_config_get_primary_tasks (void);
+void	  calendar_config_set_primary_tasks (const char *primary_uid);
+guint	  calendar_config_add_notification_primary_tasks (GConfClientNotifyFunc func, gpointer data);
+
+/* The pane position */
+gint      calendar_config_get_task_vpane_pos    (void);
+void      calendar_config_set_task_vpane_pos    (gint         vpane_pos);
+
 /* Colors for the task list */
 const char *calendar_config_get_tasks_due_today_color	(void);
 void	    calendar_config_set_tasks_due_today_color	(const char *color);
@@ -152,8 +189,8 @@ char*	  calendar_config_get_hide_completed_tasks_sexp (void);
 gboolean  calendar_config_get_confirm_delete (void);
 void      calendar_config_set_confirm_delete (gboolean confirm);
 
-gboolean  calendar_config_get_confirm_expunge (void);
-void      calendar_config_set_confirm_expunge (gboolean confirm);
+gboolean  calendar_config_get_confirm_purge (void);
+void      calendar_config_set_confirm_purge (gboolean confirm);
 
 /* Default reminder options */
 gboolean calendar_config_get_use_default_reminder (void);
@@ -180,8 +217,4 @@ void	  calendar_config_check_timezone_set	(void);
    supports 12-hour time format. */
 gboolean  calendar_config_locale_supports_12_hour_format(void);
 
-/* Default folders, read-only */
-char *calendar_config_default_calendar_folder (void);
-char *calendar_config_default_tasks_folder (void);
-
 #endif /* _CALENDAR_CONFIG_H_ */
