@@ -21,6 +21,7 @@
  */
 
 #include <config.h>
+#include <string.h>
 #include <gtk/gtksignal.h>
 #include <glade/glade.h>
 #include <bonobo/bonobo-control.h>
@@ -29,10 +30,12 @@
 #include <bonobo/bonobo-context.h>
 #include <bonobo/bonobo-property-bag.h>
 #include <glade/glade.h>
+#include <libgnomeui/gnome-dialog-util.h>
 
-#include <cal-util/timeutil.h>
+#include <libecal/e-cal-time-util.h>
 #include <gui/gnome-cal.h>
 #include <gui/calendar-commands.h>
+#include <gui/calendar-config.h>
 
 #include "control-factory.h"
 
@@ -66,13 +69,16 @@ get_prop (BonoboPropertyBag *bag,
 	  CORBA_Environment *ev,
 	  gpointer           user_data)
 {
-	GnomeCalendar *gcal = user_data;
+	GnomeCalendar *gcal;
 	const char *uri;
+	BonoboControl *control = user_data;
+
+	gcal = (GnomeCalendar *) bonobo_control_get_widget (control);
 
 	switch (arg_id) {
 
 	case PROPERTY_CALENDAR_URI_IDX:
-		uri = cal_client_get_uri (gnome_calendar_get_cal_client (gcal));
+		uri = e_cal_get_uri (e_cal_model_get_default_client (gnome_calendar_get_calendar_model (gcal)));
 		BONOBO_ARG_SET_STRING (arg, uri);
 		break;
 
@@ -90,6 +96,10 @@ get_prop (BonoboPropertyBag *bag,
 		case GNOME_CAL_MONTH_VIEW:
 			BONOBO_ARG_SET_STRING (arg, "month");
 			break;
+		case GNOME_CAL_LIST_VIEW:
+			BONOBO_ARG_SET_STRING (arg, "list");
+			break;
+		default:
 		}
 		break;
 
@@ -98,7 +108,6 @@ get_prop (BonoboPropertyBag *bag,
 	}
 }
 
-
 static void
 set_prop (BonoboPropertyBag *bag,
 	  const BonoboArg   *arg,
@@ -106,14 +115,19 @@ set_prop (BonoboPropertyBag *bag,
 	  CORBA_Environment *ev,
 	  gpointer           user_data)
 {
-	GnomeCalendar *gcal = user_data;
+	GnomeCalendar *gcal;
 	char *string;
 	GnomeCalendarViewType view;
+	BonoboControl *control = user_data;
+
+	gcal = (GnomeCalendar *) bonobo_control_get_widget (control);
 
 	switch (arg_id) {
 	case PROPERTY_CALENDAR_URI_IDX:
 		string = BONOBO_ARG_GET_STRING (arg);
-		if (!gnome_calendar_open (gcal, string)) {
+		if (gnome_calendar_add_event_uri (gcal, string)) {
+			calendar_control_sensitize_calendar_commands (control, gcal, TRUE);
+		} else {
 			char *msg;
 
 			msg = g_strdup_printf (_("Could not open the folder in '%s'"), string);
@@ -126,14 +140,16 @@ set_prop (BonoboPropertyBag *bag,
 
 	case PROPERTY_CALENDAR_VIEW_IDX:
 		string = BONOBO_ARG_GET_STRING (arg);
-		if (!g_strcasecmp (string, "week"))
+		if (!strcmp (string, "week"))
 			view = GNOME_CAL_WEEK_VIEW;
-		else if (!g_strcasecmp (string, "workweek"))
+		else if (!strcmp (string, "workweek"))
 			view = GNOME_CAL_WORK_WEEK_VIEW;
-		else if (!g_strcasecmp (string, "month"))
+		else if (!strcmp (string, "month"))
 			view = GNOME_CAL_MONTH_VIEW;
-		else
+		else if (!strcmp (string, "day"))
 			view = GNOME_CAL_DAY_VIEW;
+		else
+			view = calendar_config_get_default_view ();
 
 		/* This doesn't actually work, because the GalView
 		 * comes along and resets the view. FIXME.
@@ -153,7 +169,7 @@ calendar_properties_init (GnomeCalendar *gcal, BonoboControl *control)
 {
 	BonoboPropertyBag *pbag;
 
-	pbag = bonobo_property_bag_new (get_prop, set_prop, gcal);
+	pbag = bonobo_property_bag_new (get_prop, set_prop, control);
 
 	bonobo_property_bag_add (pbag,
 				 PROPERTY_CALENDAR_URI,
@@ -180,7 +196,7 @@ control_factory_new_control (void)
 	BonoboControl *control;
 	GnomeCalendar *gcal;
 
-	gcal = new_calendar ();
+	gcal = GNOME_CALENDAR (gnome_calendar_new ());
 	if (!gcal)
 		return NULL;
 
