@@ -24,18 +24,19 @@
 #ifndef MEETING_PAGE_H
 #define MEETING_PAGE_H
 
-#include "../e-meeting-model.h"
+#include "../e-meeting-store.h"
+#include "../itip-utils.h"
 #include "comp-editor-page.h"
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 
 
 #define TYPE_MEETING_PAGE            (meeting_page_get_type ())
-#define MEETING_PAGE(obj)            (GTK_CHECK_CAST ((obj), TYPE_MEETING_PAGE, MeetingPage))
-#define MEETING_PAGE_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_MEETING_PAGE, MeetingPageClass))
-#define IS_MEETING_PAGE(obj)         (GTK_CHECK_TYPE ((obj), TYPE_MEETING_PAGE))
-#define IS_MEETING_PAGE_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((obj), TYPE_MEETING_PAGE))
+#define MEETING_PAGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEETING_PAGE, MeetingPage))
+#define MEETING_PAGE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEETING_PAGE, MeetingPageClass))
+#define IS_MEETING_PAGE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEETING_PAGE))
+#define IS_MEETING_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), TYPE_MEETING_PAGE))
 
 typedef struct _MeetingPagePrivate MeetingPagePrivate;
 
@@ -53,14 +54,14 @@ typedef struct {
 
 GtkType       meeting_page_get_type          (void);
 MeetingPage  *meeting_page_construct         (MeetingPage   *mpage,
-					      EMeetingModel *emm,
-					      CalClient     *client);
-MeetingPage  *meeting_page_new               (EMeetingModel *emm,
-					      CalClient     *client);
-CalComponent *meeting_page_get_cancel_comp   (MeetingPage   *mpage);
+					      EMeetingStore *ems,
+					      ECal     *client);
+MeetingPage  *meeting_page_new               (EMeetingStore *ems,
+					      ECal     *client);
+ECalComponent *meeting_page_get_cancel_comp   (MeetingPage   *mpage);
 
 
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
