@@ -29,7 +29,6 @@
 #include <gtk/gtktogglebutton.h>
 #include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
-#include <gal/widgets/e-unicode.h>
 #include <widgets/misc/e-dateedit.h>
 #include <widgets/misc/e-url-entry.h>
 #include "e-util/e-dialog-widgets.h"
@@ -52,8 +51,10 @@ struct _TaskDetailsPagePrivate {
 	GtkWidget *priority;
 	GtkWidget *percent_complete;
 
+	GtkWidget *date_completed_label;
 	GtkWidget *completed_date;
 
+	GtkWidget *url_label;
 	GtkWidget *url_entry;
 	GtkWidget *url;
 
@@ -92,8 +93,8 @@ static void task_details_page_finalize (GObject *object);
 
 static GtkWidget *task_details_page_get_widget (CompEditorPage *page);
 static void task_details_page_focus_main_widget (CompEditorPage *page);
-static void task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp);
-static gboolean task_details_page_fill_component (CompEditorPage *page, CalComponent *comp);
+static void task_details_page_fill_widgets (CompEditorPage *page, ECalComponent *comp);
+static gboolean task_details_page_fill_component (CompEditorPage *page, ECalComponent *comp);
 
 static CompEditorPageClass *parent_class = NULL;
 
@@ -148,8 +149,10 @@ task_details_page_init (TaskDetailsPage *tdpage)
 	priv->priority = NULL;
 	priv->percent_complete = NULL;
 	
+	priv->date_completed_label = NULL;
 	priv->completed_date = NULL;
 
+	priv->url_label = NULL;
 	priv->url_entry = NULL;
 	priv->url = NULL;
 
@@ -173,7 +176,7 @@ task_details_page_finalize (GObject *object)
 		gtk_widget_unref (priv->main);
 
 	if (priv->xml) {
-		g_object_unref((priv->xml));
+		g_object_unref (priv->xml);
 		priv->xml = NULL;
 	}
 
@@ -274,7 +277,7 @@ clear_widgets (TaskDetailsPage *tdpage)
 
 /* fill_widgets handler for the task page */
 static void
-task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
+task_details_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 {
 	TaskDetailsPage *tdpage;
 	TaskDetailsPagePrivate *priv;
@@ -293,7 +296,7 @@ task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
 	clear_widgets (tdpage);
 	
 	/* Percent Complete. */
-	cal_component_get_percent (comp, &percent);
+	e_cal_component_get_percent (comp, &percent);
 	if (percent) {
 		e_dialog_spin_set (priv->percent_complete, *percent);
 	} else {
@@ -302,7 +305,7 @@ task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
 	}
 
 	/* Status. */
-	cal_component_get_status (comp, &status);
+	e_cal_component_get_status (comp, &status);
 	if (status == ICAL_STATUS_NONE || status == ICAL_STATUS_NEEDSACTION) {
 		/* Try to use the percent value. */
 		if (percent) {
@@ -318,10 +321,10 @@ task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
 	e_dialog_option_menu_set (priv->status, status, status_map);
 
 	if (percent)
-		cal_component_free_percent (percent);
+		e_cal_component_free_percent (percent);
 
 	/* Completed Date. */
-	cal_component_get_completed (comp, &completed);
+	e_cal_component_get_completed (comp, &completed);
 	if (completed) {
 		icaltimezone *utc_zone, *zone;
 		char *location;
@@ -341,21 +344,21 @@ task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
 					     completed->hour,
 					     completed->minute);
 
-		cal_component_free_icaltimetype (completed);
+		e_cal_component_free_icaltimetype (completed);
 	}
 
 	/* Priority. */
-	cal_component_get_priority (comp, &priority_value);
+	e_cal_component_get_priority (comp, &priority_value);
 	if (priority_value) {
 		priority = priority_value_to_index (*priority_value);
-		cal_component_free_priority (priority_value);
+		e_cal_component_free_priority (priority_value);
 	} else {
 		priority = PRIORITY_UNDEFINED;
 	}
 	e_dialog_option_menu_set (priv->priority, priority, priority_map);
 
 	/* URL */
-	cal_component_get_url (comp, &url);
+	e_cal_component_get_url (comp, &url);
 	e_dialog_editable_set (priv->url, url);
 	
 	priv->updating = FALSE;
@@ -363,7 +366,7 @@ task_details_page_fill_widgets (CompEditorPage *page, CalComponent *comp)
 
 /* fill_component handler for the task page */
 static gboolean
-task_details_page_fill_component (CompEditorPage *page, CalComponent *comp)
+task_details_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 {
 	TaskDetailsPage *tdpage;
 	TaskDetailsPagePrivate *priv;
@@ -379,16 +382,16 @@ task_details_page_fill_component (CompEditorPage *page, CalComponent *comp)
 
 	/* Percent Complete. */
 	percent = e_dialog_spin_get_int (priv->percent_complete);
-	cal_component_set_percent (comp, &percent);
+	e_cal_component_set_percent (comp, &percent);
 
 	/* Status. */
 	status = e_dialog_option_menu_get (priv->status, status_map);
-	cal_component_set_status (comp, status);
+	e_cal_component_set_status (comp, status);
 
 	/* Priority. */
 	priority = e_dialog_option_menu_get (priv->priority, priority_map);
 	priority_value = priority_index_to_value (priority);
-	cal_component_set_priority (comp, &priority_value);
+	e_cal_component_set_priority (comp, &priority_value);
 
 	icaltime = icaltime_null_time ();
 
@@ -420,14 +423,14 @@ task_details_page_fill_component (CompEditorPage *page, CalComponent *comp)
 		icaltimezone *zone = icaltimezone_get_builtin_timezone (location);
 		icaltimezone_convert_time (&icaltime, zone,
 					   icaltimezone_get_utc_timezone ());
-		cal_component_set_completed (comp, &icaltime);
+		e_cal_component_set_completed (comp, &icaltime);
 	} else {
-		cal_component_set_completed (comp, NULL);
+		e_cal_component_set_completed (comp, NULL);
 	}
 
 	/* URL. */
 	url = e_dialog_editable_get (priv->url);
-	cal_component_set_url (comp, url);
+	e_cal_component_set_url (comp, url);
 	if (url)
 		g_free (url);
 
@@ -469,9 +472,13 @@ get_widgets (TaskDetailsPage *tdpage)
 	priv->priority = GW ("priority");
 	priv->percent_complete = GW ("percent-complete");
 
+	priv->date_completed_label = GW ("date_completed_label");
+
 	priv->completed_date = GW ("completed-date");
 	gtk_widget_show (priv->completed_date);
 
+	priv->url_label = GW ("url_label");
+
 	priv->url_entry = GW ("url_entry");
 	gtk_widget_show (priv->url_entry);
 	priv->url = e_url_entry_get_entry (E_URL_ENTRY (priv->url_entry));
@@ -481,7 +488,9 @@ get_widgets (TaskDetailsPage *tdpage)
 	return (priv->status
 		&& priv->priority
 		&& priv->percent_complete
+		&& priv->date_completed_label
 		&& priv->completed_date
+		&& priv->url_label
 		&& priv->url);
 }
 
@@ -669,6 +678,10 @@ init_widgets (TaskDetailsPage *tdpage)
 					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
 					   tdpage, NULL);
 
+	/* These are created by hand, so hook the mnemonics manually */
+	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->date_completed_label), priv->completed_date);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->url_label), priv->url_entry);
+
 	/* Connect signals. The Status, Percent Complete & Date Completed
 	   properties are closely related so whenever one changes we may need
 	   to update the other 2. */
@@ -746,7 +759,7 @@ task_details_page_new (void)
 
 	tdpage = g_object_new (TYPE_TASK_DETAILS_PAGE, NULL);
 	if (!task_details_page_construct (tdpage)) {
-		g_object_unref ((tdpage));
+		g_object_unref (tdpage);
 		return NULL;
 	}
 
