@@ -30,7 +30,7 @@
 #include <bonobo/bonobo-ui-component.h>
 #include <gal/widgets/e-popup-menu.h>
 #include <widgets/misc/e-calendar.h>
-#include <cal-client/cal-client.h>
+#include <libecal/e-cal.h>
 
 #include "e-calendar-table.h"
 
@@ -54,19 +54,20 @@ typedef enum {
 	GNOME_CAL_DAY_VIEW,
 	GNOME_CAL_WORK_WEEK_VIEW,
 	GNOME_CAL_WEEK_VIEW,
-	GNOME_CAL_MONTH_VIEW
+	GNOME_CAL_MONTH_VIEW,
+	GNOME_CAL_LIST_VIEW,
+	GNOME_CAL_LAST_VIEW
 } GnomeCalendarViewType;
 
-typedef enum
-{
-  GNOME_CAL_GOTO_TODAY,
-  GNOME_CAL_GOTO_DATE,
-  GNOME_CAL_GOTO_FIRST_DAY_OF_MONTH,
-  GNOME_CAL_GOTO_LAST_DAY_OF_MONTH,
-  GNOME_CAL_GOTO_FIRST_DAY_OF_WEEK,
-  GNOME_CAL_GOTO_LAST_DAY_OF_WEEK,
-  GNOME_CAL_GOTO_SAME_DAY_OF_PREVIOUS_WEEK,
-  GNOME_CAL_GOTO_SAME_DAY_OF_NEXT_WEEK
+typedef enum {
+	GNOME_CAL_GOTO_TODAY,
+	GNOME_CAL_GOTO_DATE,
+	GNOME_CAL_GOTO_FIRST_DAY_OF_MONTH,
+	GNOME_CAL_GOTO_LAST_DAY_OF_MONTH,
+	GNOME_CAL_GOTO_FIRST_DAY_OF_WEEK,
+	GNOME_CAL_GOTO_LAST_DAY_OF_WEEK,
+	GNOME_CAL_GOTO_SAME_DAY_OF_PREVIOUS_WEEK,
+	GNOME_CAL_GOTO_SAME_DAY_OF_NEXT_WEEK
 } GnomeCalendarGotoDateType;
 
 struct _GnomeCalendar {
@@ -87,7 +88,7 @@ struct _GnomeCalendarClass {
 
 	void (* calendar_focus_change)  (GnomeCalendar *gcal, gboolean in);
 	void (* taskpad_focus_change)   (GnomeCalendar *gcal, gboolean in);
-        void (* goto_date)         (GnomeCalendar *day_view,
+        void (* goto_date)         (GnomeCalendar *gcal,
 				    GnomeCalendarGotoDateType date);
 
 };
@@ -103,10 +104,13 @@ void gnome_calendar_set_ui_component (GnomeCalendar *cal,
 
 ECalendarTable *gnome_calendar_get_task_pad	(GnomeCalendar *gcal);
 
-CalClient *gnome_calendar_get_cal_client	(GnomeCalendar *gcal);
-CalClient *gnome_calendar_get_task_pad_cal_client(GnomeCalendar *gcal);
+ECalModel *gnome_calendar_get_calendar_model    (GnomeCalendar *gcal);
+ECal *gnome_calendar_get_default_client    (GnomeCalendar *gcal);
+ECal *gnome_calendar_get_task_pad_e_cal(GnomeCalendar *gcal);
 
-gboolean   gnome_calendar_open                  (GnomeCalendar *gcal, const char *str_uri);
+gboolean   gnome_calendar_add_event_uri         (GnomeCalendar *gcal, const char *str_uri);
+gboolean   gnome_calendar_remove_event_uri      (GnomeCalendar *gcal, const char *str_uri);
+gboolean   gnome_calendar_set_default_uri       (GnomeCalendar *gcal, const char *str_uri);
 
 void gnome_calendar_set_query (GnomeCalendar *gcal, const char *sexp);
 
@@ -124,6 +128,12 @@ void gnome_calendar_set_view (GnomeCalendar *gcal, GnomeCalendarViewType view_ty
 			      gboolean range_selected, gboolean grab_focus);
 
 GtkWidget *gnome_calendar_get_current_view_widget (GnomeCalendar *gcal);
+
+ECalendarTable *gnome_calendar_get_task_pad	(GnomeCalendar *gcal);
+GtkWidget *gnome_calendar_get_e_calendar_widget (GnomeCalendar *gcal); 
+GtkWidget *gnome_calendar_get_search_bar_widget (GnomeCalendar *gcal);
+GtkWidget *gnome_calendar_get_view_notebook_widget (GnomeCalendar *gcal);
+
 void gnome_calendar_setup_view_menus (GnomeCalendar *gcal, BonoboUIComponent *uic);
 void gnome_calendar_discard_view_menus (GnomeCalendar *gcal);
 
@@ -137,16 +147,6 @@ void	   gnome_calendar_get_selected_time_range (GnomeCalendar *gcal,
 						   time_t	 *start_time,
 						   time_t	 *end_time);
 
-void       gnome_calendar_edit_object           (GnomeCalendar *gcal,
-						 CalComponent  *comp,
-						 gboolean meeting);
-
-void       gnome_calendar_new_appointment       (GnomeCalendar *gcal);
-void       gnome_calendar_new_appointment_for   (GnomeCalendar *cal,
-						 time_t dtstart, time_t dtend,
-						 gboolean all_day,
-						 gboolean meeting);
-
 void       gnome_calendar_new_task		(GnomeCalendar *gcal);
 
 /* Returns the selected time range for the current view. Note that this may be
@@ -168,11 +168,6 @@ gint	   gnome_calendar_get_num_events_selected (GnomeCalendar *gcal);
 /* Returns the number of selected tasks */
 gint       gnome_calendar_get_num_tasks_selected (GnomeCalendar *gcal);
 
-/* Tells the calendar to reload all config settings. initializing should be
-   TRUE when we are setting the config settings for the first time. */
-void	   gnome_calendar_update_config_settings (GnomeCalendar *gcal,
-						  gboolean	 initializing);
-
 /* Get the current timezone. */
 icaltimezone *gnome_calendar_get_timezone	(GnomeCalendar	*gcal);
 
@@ -184,6 +179,8 @@ void       gnome_calendar_paste_clipboard       (GnomeCalendar  *gcal);
 
 void       gnome_calendar_delete_selection	(GnomeCalendar  *gcal);
 void       gnome_calendar_delete_selected_occurrence (GnomeCalendar *gcal);
+void       gnome_calendar_purge                 (GnomeCalendar  *gcal,
+						 time_t older_than);
 
 
 
