@@ -44,8 +44,7 @@
 #include <gal/util/e-util.h>
 #include <e-util/e-dialog-widgets.h>
 #include <e-util/e-time-utils.h>
-#include <gal/widgets/e-unicode.h>
-#include <cal-util/timeutil.h>
+#include <libecal/e-cal-time-util.h>
 #include "calendar-commands.h"
 #include "calendar-config.h"
 #include "e-day-view.h"
@@ -522,6 +521,16 @@ format_date(time_t time, int flags, char *buffer, int bufflen)
 	return buffer;
 }
 
+static gboolean 
+instance_cb (ECalComponent *comp, time_t instance_start, time_t instance_end, gpointer data)
+{
+	gboolean *found = data;
+	
+	*found = TRUE;
+	
+	return FALSE;
+}
+
 
 /*
   print out the month small, embolden any days with events.
@@ -533,7 +542,7 @@ print_month_small (GnomePrintContext *pc, GnomeCalendar *gcal, time_t month,
 		   int bordertitle)
 {
 	icaltimezone *zone = get_timezone ();
-	CalClient *client;
+	ECal *client;
 	GnomeFont *font, *font_bold, *font_normal;
 	time_t now, next;
 	int x, y;
@@ -561,7 +570,7 @@ print_month_small (GnomePrintContext *pc, GnomeCalendar *gcal, time_t month,
 
 	top -= header_size;
 
-	client = gnome_calendar_get_cal_client (gcal);
+	client = gnome_calendar_get_default_client (gcal);
 
 	col_width = (right - left) / 7;
 
@@ -625,16 +634,16 @@ print_month_small (GnomePrintContext *pc, GnomeCalendar *gcal, time_t month,
 
 			day = days[y * 7 + x];
 			if (day != 0) {
-				GList *uids;
+				gboolean found = FALSE;
 
 				sprintf (buf, "%d", day);
 
 				/* this is a slow messy way to do this ... but easy ... */
-				uids = cal_client_get_objects_in_range (client,
-									CALOBJ_TYPE_EVENT,
-									now, time_day_end_with_zone (now, zone));
-				font = uids ? font_bold : font_normal;
-				cal_obj_uid_list_free (uids);
+				e_cal_generate_instances (client, now, CALOBJ_TYPE_EVENT, 
+							       time_day_end_with_zone (now, zone),
+							       instance_cb, &found);
+				
+				font = found ? font_bold : font_normal;
 
 				next = time_add_day_with_zone (now, 1, zone);
 				if ((now >= greystart && now < greyend)
@@ -846,7 +855,7 @@ print_day_background (GnomePrintContext *pc, GnomeCalendar *gcal,
 
 /* This adds one event to the view, adding it to the appropriate array. */
 static gint
-print_day_add_event (CalComponent *comp,
+print_day_add_event (ECalComponent *comp,
 		     time_t	    start,
 		     time_t	    end,
 		     gint	    days_shown,
@@ -855,74 +864,74 @@ print_day_add_event (CalComponent *comp,
 		     GArray	  **events)
 
 {
-	icaltimezone *zone = get_timezone ();
-	EDayViewEvent event;
-	gint day, offset;
-	struct icaltimetype start_tt, end_tt;
+/* 	icaltimezone *zone = get_timezone (); */
+/* 	EDayViewEvent event; */
+/* 	gint day, offset; */
+/* 	struct icaltimetype start_tt, end_tt; */
 
-#if 0
-	g_print ("Day view lower: %s", ctime (&day_starts[0]));
-	g_print ("Day view upper: %s", ctime (&day_starts[days_shown]));
-	g_print ("Event start: %s", ctime (&start));
-	g_print ("Event end  : %s\n", ctime (&end));
-#endif
+/* #if 0 */
+/* 	g_print ("Day view lower: %s", ctime (&day_starts[0])); */
+/* 	g_print ("Day view upper: %s", ctime (&day_starts[days_shown])); */
+/* 	g_print ("Event start: %s", ctime (&start)); */
+/* 	g_print ("Event end  : %s\n", ctime (&end)); */
+/* #endif */
 
-	/* Check that the event times are valid. */
-	g_return_val_if_fail (start <= end, -1);
-	g_return_val_if_fail (start < day_starts[days_shown], -1);
-	g_return_val_if_fail (end > day_starts[0], -1);
+/* 	/\* Check that the event times are valid. *\/ */
+/* 	g_return_val_if_fail (start <= end, -1); */
+/* 	g_return_val_if_fail (start < day_starts[days_shown], -1); */
+/* 	g_return_val_if_fail (end > day_starts[0], -1); */
 
-	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone);
-	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone);
+/* 	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone); */
+/* 	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone); */
 
-	event.comp = comp;
-	g_object_ref (comp);
-	event.start = start;
-	event.end = end;
-	event.canvas_item = NULL;
+/* 	event.comp = comp; */
+/* 	g_object_ref (comp); */
+/* 	event.start = start; */
+/* 	event.end = end; */
+/* 	event.canvas_item = NULL; */
 
-	/* Calculate the start & end minute, relative to the top of the
-	   display. */
-	/*offset = day_view->first_hour_shown * 60
-	  + day_view->first_minute_shown;*/
-	offset = 0;
-	event.start_minute = start_tt.hour * 60 + start_tt.minute - offset;
-	event.end_minute = end_tt.hour * 60 + end_tt.minute - offset;
+/* 	/\* Calculate the start & end minute, relative to the top of the */
+/* 	   display. *\/ */
+/* 	/\*offset = day_view->first_hour_shown * 60 */
+/* 	  + day_view->first_minute_shown;*\/ */
+/* 	offset = 0; */
+/* 	event.start_minute = start_tt.hour * 60 + start_tt.minute - offset; */
+/* 	event.end_minute = end_tt.hour * 60 + end_tt.minute - offset; */
 
-	event.start_row_or_col = 0;
-	event.num_columns = 0;
+/* 	event.start_row_or_col = 0; */
+/* 	event.num_columns = 0; */
 
-	/* Find out which array to add the event to. */
-	for (day = 0; day < days_shown; day++) {
-		if (start >= day_starts[day] && end <= day_starts[day + 1]) {
+/* 	/\* Find out which array to add the event to. *\/ */
+/* 	for (day = 0; day < days_shown; day++) { */
+/* 		if (start >= day_starts[day] && end <= day_starts[day + 1]) { */
 
-			/* Special case for when the appointment ends at
-			   midnight, i.e. the start of the next day. */
-			if (end == day_starts[day + 1]) {
+/* 			/\* Special case for when the appointment ends at */
+/* 			   midnight, i.e. the start of the next day. *\/ */
+/* 			if (end == day_starts[day + 1]) { */
 
-				/* If the event last the entire day, then we
-				   skip it here so it gets added to the top
-				   canvas. */
-				if (start == day_starts[day])
-				    break;
+/* 				/\* If the event last the entire day, then we */
+/* 				   skip it here so it gets added to the top */
+/* 				   canvas. *\/ */
+/* 				if (start == day_starts[day]) */
+/* 				    break; */
 
-				event.end_minute = 24 * 60;
-			}
+/* 				event.end_minute = 24 * 60; */
+/* 			} */
 
-			g_array_append_val (events[day], event);
-			return day;
-		}
-	}
+/* 			g_array_append_val (events[day], event); */
+/* 			return day; */
+/* 		} */
+/* 	} */
 
-	/* The event wasn't within one day so it must be a long event,
-	   i.e. shown in the top canvas. */
-	g_array_append_val (long_events, event);
+/* 	/\* The event wasn't within one day so it must be a long event, */
+/* 	   i.e. shown in the top canvas. *\/ */
+/* 	g_array_append_val (long_events, event); */
 	return E_DAY_VIEW_LONG_EVENT;
 }
 
 
 static gboolean
-print_day_details_cb (CalComponent *comp, time_t istart, time_t iend,
+print_day_details_cb (ECalComponent *comp, time_t istart, time_t iend,
 		      gpointer data)
 {
 	struct pdinfo *pdi = (struct pdinfo *)data;
@@ -945,7 +954,6 @@ free_event_array (GArray *array)
 		event = &g_array_index (array, EDayViewEvent, event_num);
 		if (event->canvas_item)
 			gtk_object_destroy (GTK_OBJECT (event->canvas_item));
-		g_object_unref (event->comp);
 	}
 
 	g_array_set_size (array, 0);
@@ -958,7 +966,7 @@ print_day_long_event (GnomePrintContext *pc, GnomeFont *font,
 		      double row_height, EDayViewEvent *event,
 		      struct pdinfo *pdi)
 {
-	CalComponentText summary;
+	const gchar *summary;
 	double x1, x2, y1, y2;
 	double left_triangle_width = -1.0, right_triangle_width = -1.0;
 	char *text;
@@ -1023,8 +1031,8 @@ print_day_long_event (GnomePrintContext *pc, GnomeFont *font,
 	}
 
 	/* Print the text. */
-	cal_component_get_summary (event->comp, &summary);
-	text = summary.value ? (char*) summary.value : "";
+	summary = icalcomponent_get_summary (event->comp_data->icalcomp);
+	text = summary ? (char*) summary : "";
 
 	x1 += 4;
 	x2 -= 4;
@@ -1037,7 +1045,7 @@ print_day_event (GnomePrintContext *pc, GnomeFont *font,
 		 double left, double right, double top, double bottom,
 		 EDayViewEvent *event, struct pdinfo *pdi)
 {
-	CalComponentText summary;
+	const gchar *summary;
 	double x1, x2, y1, y2, col_width, row_height;
 	int start_offset, end_offset, start_row, end_row;
 	char *text, start_buffer[32], end_buffer[32];
@@ -1075,8 +1083,8 @@ print_day_event (GnomePrintContext *pc, GnomeFont *font,
 
 	print_border (pc, x1, x2, y1, y2, 1.0, 0.95);
 
-	cal_component_get_summary (event->comp, &summary);
-	text = summary.value ? (char*) summary.value : "";
+	summary = icalcomponent_get_summary (event->comp_data->icalcomp);
+	text = summary ? (char*) summary : "";
 
 
 	if (display_times) {
@@ -1115,7 +1123,7 @@ print_day_details (GnomePrintContext *pc, GnomeCalendar *gcal, time_t whence,
 		   double left, double right, double top, double bottom)
 {
 	icaltimezone *zone = get_timezone ();
-	CalClient *client;
+	ECal *client;
 	EDayViewEvent *event;
 	GnomeFont *font;
 	time_t start, end;
@@ -1142,8 +1150,8 @@ print_day_details (GnomePrintContext *pc, GnomeCalendar *gcal, time_t whence,
 	pdi.use_24_hour_format = calendar_config_get_24_hour_format ();
 
 	/* Get the events from the server. */
-	client = gnome_calendar_get_cal_client (gcal);
-	cal_client_generate_instances (client, CALOBJ_TYPE_EVENT, start, end,
+	client = gnome_calendar_get_default_client (gcal);
+	e_cal_generate_instances (client, CALOBJ_TYPE_EVENT, start, end,
 				       print_day_details_cb, &pdi);
 	qsort (pdi.long_events->data, pdi.long_events->len,
 	       sizeof (EDayViewEvent), e_day_view_event_sort_func);
@@ -1233,46 +1241,46 @@ print_day_details (GnomePrintContext *pc, GnomeCalendar *gcal, time_t whence,
 
 /* This adds one event to the view, adding it to the appropriate array. */
 static gboolean
-print_week_summary_cb (CalComponent *comp,
+print_week_summary_cb (ECalComponent *comp,
 		       time_t	  start,
 		       time_t	  end,
 		       gpointer	  data)
 
 {
-	icaltimezone *zone = get_timezone ();
-	EWeekViewEvent event;
-	struct icaltimetype start_tt, end_tt;
+/* 	icaltimezone *zone = get_timezone (); */
+/* 	EWeekViewEvent event; */
+/* 	struct icaltimetype start_tt, end_tt; */
 
-	struct psinfo *psi = (struct psinfo *)data;
+/* 	struct psinfo *psi = (struct psinfo *)data; */
 
-	/* Check that the event times are valid. */
+/* 	/\* Check that the event times are valid. *\/ */
 
-#if 0
-	g_print ("View start:%li end:%li  Event start:%li end:%li\n",
-		 psi->day_starts[0], psi->day_starts[psi->days_shown],
-		 start, end);
-#endif
+/* #if 0 */
+/* 	g_print ("View start:%li end:%li  Event start:%li end:%li\n", */
+/* 		 psi->day_starts[0], psi->day_starts[psi->days_shown], */
+/* 		 start, end); */
+/* #endif */
 
-	g_return_val_if_fail (start <= end, TRUE);
-	g_return_val_if_fail (start < psi->day_starts[psi->days_shown], TRUE);
-	g_return_val_if_fail (end > psi->day_starts[0], TRUE);
+/* 	g_return_val_if_fail (start <= end, TRUE); */
+/* 	g_return_val_if_fail (start < psi->day_starts[psi->days_shown], TRUE); */
+/* 	g_return_val_if_fail (end > psi->day_starts[0], TRUE); */
 
-	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone);
-	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone);
+/* 	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone); */
+/* 	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone); */
 
-	event.comp = comp;
-	g_object_ref (event.comp);
-	event.start = start;
-	event.end = end;
-	event.spans_index = 0;
-	event.num_spans = 0;
+/* 	event.comp = comp; */
+/* 	g_object_ref (event.comp); */
+/* 	event.start = start; */
+/* 	event.end = end; */
+/* 	event.spans_index = 0; */
+/* 	event.num_spans = 0; */
 
-	event.start_minute = start_tt.hour * 60 + start_tt.minute;
-	event.end_minute = end_tt.hour * 60 + end_tt.minute;
-	if (event.end_minute == 0 && start != end)
-		event.end_minute = 24 * 60;
+/* 	event.start_minute = start_tt.hour * 60 + start_tt.minute; */
+/* 	event.end_minute = end_tt.hour * 60 + end_tt.minute; */
+/* 	if (event.end_minute == 0 && start != end) */
+/* 		event.end_minute = 24 * 60; */
 
-	g_array_append_val (psi->events, event);
+/* 	g_array_append_val (psi->events, event); */
 
 	return TRUE;
 }
@@ -1404,13 +1412,13 @@ print_week_event (GnomePrintContext *pc, GnomeFont *font,
 {
 	EWeekViewEventSpan *span;
 	gint span_num;
-	CalComponentText summary;
+	const gchar *summary;
 	char *text;
 	int num_days, start_x, start_y, start_h, end_x, end_y, end_h;
 	double x1, x2, y1, y2;
 
-	cal_component_get_summary (event->comp, &summary);
-	text = summary.value ? (char*) summary.value : "";
+	summary = icalcomponent_get_summary (event->comp_data->icalcomp);
+	text = summary ? (char*) summary : "";
 
 	for (span_num = 0; span_num < event->num_spans; span_num++) {
 		span = &g_array_index (spans, EWeekViewEventSpan,
@@ -1541,7 +1549,7 @@ print_week_summary (GnomePrintContext *pc, GnomeCalendar *gcal,
 		    double left, double right, double top, double bottom)
 {
 	icaltimezone *zone = get_timezone ();
-	CalClient *client;
+	ECal *client;
 	EWeekViewEvent *event;
 	struct psinfo psi;
 	time_t day_start;
@@ -1578,8 +1586,8 @@ print_week_summary (GnomePrintContext *pc, GnomeCalendar *gcal,
 	}
 
 	/* Get the events from the server. */
-	client = gnome_calendar_get_cal_client (gcal);
-	cal_client_generate_instances (client, CALOBJ_TYPE_EVENT,
+	client = gnome_calendar_get_default_client (gcal);
+	e_cal_generate_instances (client, CALOBJ_TYPE_EVENT,
 				       psi.day_starts[0],
 				       psi.day_starts[psi.days_shown],
 				       print_week_summary_cb, &psi);
@@ -1632,7 +1640,6 @@ print_week_summary (GnomePrintContext *pc, GnomeCalendar *gcal,
 	/* Free everything. */
 	for (event_num = 0; event_num < psi.events->len; event_num++) {
 		event = &g_array_index (psi.events, EWeekViewEvent, event_num);
-		g_object_unref (event->comp);
 	}
 	g_array_free (psi.events, TRUE);
 	g_array_free (spans, TRUE);
@@ -1765,13 +1772,13 @@ print_todo_details (GnomePrintContext *pc, GnomeCalendar *gcal,
 		    time_t start, time_t end,
 		    double left, double right, double top, double bottom)
 {
-	CalClient *client;
+	ECal *client;
 	GnomeFont *font_summary;
 	double y, yend, x, xend;
 	struct icaltimetype *tt;
 	ECalendarTable *task_pad;
 	ETable *table;
-	CalendarModel *model;
+	ECalModel *model;
 	gint rows, row;
 
 	/* We get the tasks directly from the TaskPad ETable. This means we
@@ -1779,7 +1786,7 @@ print_todo_details (GnomePrintContext *pc, GnomeCalendar *gcal,
 	task_pad = gnome_calendar_get_task_pad (gcal);
 	table = e_calendar_table_get_table (task_pad);
 	model = e_calendar_table_get_model (task_pad);
-	client = gnome_calendar_get_task_pad_cal_client (gcal);
+	client = gnome_calendar_get_task_pad_e_cal (gcal);
 
 	font_summary = get_font_for_size (10, GNOME_FONT_BOOK, FALSE);
 
@@ -1794,18 +1801,25 @@ print_todo_details (GnomePrintContext *pc, GnomeCalendar *gcal,
 
 	rows = e_table_model_row_count (E_TABLE_MODEL (model));
 	for (row = 0; row < rows; row++) {
-		CalComponent *comp;
-		CalComponentText summary;
+		ECalModelComponent *comp_data;
+		ECalComponent *comp;
+		ECalComponentText summary;
 		int model_row;
 
 		model_row = e_table_view_to_model_row (table, row);
-		comp = calendar_model_get_component (model, model_row);
-
-		cal_component_get_summary (comp, &summary);
-
-		if (!summary.value)
+		comp_data = e_cal_model_get_component_at (model, model_row);
+		if (!comp_data)
 			continue;
 
+		comp = e_cal_component_new ();
+		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
+
+		e_cal_component_get_summary (comp, &summary);
+		if (!summary.value) {
+			g_object_unref (comp);
+			continue;
+		}
+
 		x = left;
 		xend = right - 2;
 
@@ -1816,9 +1830,9 @@ print_todo_details (GnomePrintContext *pc, GnomeCalendar *gcal,
 		print_border (pc, x + 2, x + 8, y - 3, y - 11, 0.1, -1.0);
 
 		/* If the task is complete, print a tick in the box. */
-		cal_component_get_completed (comp, &tt);
+		e_cal_component_get_completed (comp, &tt);
 		if (tt) {
-			cal_component_free_icaltimetype (tt);
+			e_cal_component_free_icaltimetype (tt);
 
 			gnome_print_setrgbcolor (pc, 0, 0, 0);
 			gnome_print_setlinewidth (pc, 1.0);
@@ -1835,6 +1849,8 @@ print_todo_details (GnomePrintContext *pc, GnomeCalendar *gcal,
 		gnome_print_lineto (pc, xend, y);
 		gnome_print_stroke (pc);
 		y -= 3;
+
+		g_object_unref (comp);
 	}
 
 	g_object_unref (font_summary);
@@ -2146,7 +2162,7 @@ write_label_piece (time_t t, char *buffer, int size, char *stext, char *etext)
 }
 
 static icaltimezone*
-get_zone_from_tzid (CalClient *client, const char *tzid)
+get_zone_from_tzid (ECal *client, const char *tzid)
 {
 	icaltimezone *zone;
 
@@ -2154,11 +2170,8 @@ get_zone_from_tzid (CalClient *client, const char *tzid)
 	   the builtin timezone with the TZID first. */
 	zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
 	if (!zone) {
-		CalClientGetStatus status;
-
-		status = cal_client_get_timezone (client, tzid, &zone);
-		/* FIXME: Handle error better. */
-		if (status != CAL_CLIENT_GET_SUCCESS)
+		if (!e_cal_get_timezone (client, tzid, &zone, NULL)) 
+			/* FIXME: Handle error better. */
 			g_warning ("Couldn't get timezone from server: %s",
 				   tzid ? tzid : "");
 	}
@@ -2167,44 +2180,44 @@ get_zone_from_tzid (CalClient *client, const char *tzid)
 }
 
 static void
-print_date_label (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
+print_date_label (GnomePrintContext *pc, ECalComponent *comp, ECal *client,
 		  double left, double right, double top, double bottom)
 {
 	icaltimezone *start_zone, *end_zone, *due_zone, *completed_zone;
-	CalComponentDateTime datetime;
+	ECalComponentDateTime datetime;
 	time_t start = 0, end = 0, complete = 0, due = 0;
 	static char buffer[1024];
 
-	cal_component_get_dtstart (comp, &datetime);
+	e_cal_component_get_dtstart (comp, &datetime);
 	if (datetime.value) {
 		start_zone = get_zone_from_tzid (client, datetime.tzid);
 		start = icaltime_as_timet_with_zone (*datetime.value,
 						     start_zone);
 	}
-	cal_component_free_datetime (&datetime);
+	e_cal_component_free_datetime (&datetime);
 
-	cal_component_get_dtend (comp, &datetime);
+	e_cal_component_get_dtend (comp, &datetime);
 	if (datetime.value) {
 		end_zone = get_zone_from_tzid (client, datetime.tzid);
 		end = icaltime_as_timet_with_zone (*datetime.value,
 						   end_zone);
 	}
-	cal_component_free_datetime (&datetime);
+	e_cal_component_free_datetime (&datetime);
 
-	cal_component_get_due (comp, &datetime);
+	e_cal_component_get_due (comp, &datetime);
 	if (datetime.value) {
 		due_zone = get_zone_from_tzid (client, datetime.tzid);
 		due = icaltime_as_timet_with_zone (*datetime.value,
 						   due_zone);
 	}
-	cal_component_free_datetime (&datetime);
+	e_cal_component_free_datetime (&datetime);
 
-	cal_component_get_completed (comp, &datetime.value);
+	e_cal_component_get_completed (comp, &datetime.value);
 	if (datetime.value) {
 		completed_zone = icaltimezone_get_utc_timezone ();
 		complete = icaltime_as_timet_with_zone (*datetime.value,
 							completed_zone);
-		cal_component_free_icaltimetype (datetime.value);
+		e_cal_component_free_icaltimetype (datetime.value);
 	}
 
 	buffer[0] = '\0';
@@ -2234,24 +2247,24 @@ print_date_label (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 }
 
 static void
-print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
+print_comp_item (GnomePrintContext *pc, ECalComponent *comp, ECal *client,
 		 double left, double right, double top, double bottom)
 {
 	GnomeFont *font;
-	CalComponentVType vtype;
-	CalComponentText text;
+	ECalComponentVType vtype;
+	ECalComponentText text;
 	GSList *desc, *l;
 	const char *title, *categories;
 	char *categories_string;
 	GSList *contact_list, *elem;
 	gint header_size;
 
-	vtype = cal_component_get_vtype (comp);
+	vtype = e_cal_component_get_vtype (comp);
 
 	/* We should only be asked to print VEVENTs or VTODOs. */
-	if (vtype == CAL_COMPONENT_EVENT)
+	if (vtype == E_CAL_COMPONENT_EVENT)
 		title = _("Appointment");
-	else if (vtype == CAL_COMPONENT_TODO)
+	else if (vtype == E_CAL_COMPONENT_TODO)
 		title = _("Task");
 	else
 		return;
@@ -2271,7 +2284,7 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 
 	/* Summary */
 	font = get_font_for_size (18, GNOME_FONT_BOLD, FALSE);
-	cal_component_get_summary (comp, &text);
+	e_cal_component_get_summary (comp, &text);
 	top = bound_text (pc, font, text.value, left, right,
 			  top - 3, bottom, 0);
 	g_object_unref (font);
@@ -2283,7 +2296,7 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 	font = get_font_for_size (12, GNOME_FONT_BOOK, FALSE);
 
 	/* For a VTODO we print the Status, Priority, % Complete and URL. */
-	if (vtype == CAL_COMPONENT_TODO) {
+	if (vtype == E_CAL_COMPONENT_TODO) {
 		icalproperty_status status;
 		const char *status_string = NULL;
 		int *percent;
@@ -2291,7 +2304,7 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 		const char *url;
 
 		/* Status */
-		cal_component_get_status (comp, &status);
+		e_cal_component_get_status (comp, &status);
 		if (status != ICAL_STATUS_NONE) {
 			switch (status) {
 			case ICAL_STATUS_NEEDSACTION:
@@ -2321,12 +2334,12 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 		}
 
 		/* Priority */
-		cal_component_get_priority (comp, &priority);
+		e_cal_component_get_priority (comp, &priority);
 		if (priority && *priority >= 0) {
 			char *priority_string, *text;
 
-			priority_string = cal_util_priority_to_string (*priority);
-			cal_component_free_priority (priority);
+			priority_string = e_cal_util_priority_to_string (*priority);
+			e_cal_component_free_priority (priority);
 
 			text = g_strdup_printf (_("Priority: %s"), priority_string);
 			top = bound_text (pc, font, text,
@@ -2336,12 +2349,12 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 		}
 
 		/* Percent Complete */
-		cal_component_get_percent (comp, &percent);
+		e_cal_component_get_percent (comp, &percent);
 		if (percent) {
 			char *percent_string;
 
 			percent_string = g_strdup_printf (_("Percent Complete: %i"), *percent);
-			cal_component_free_percent (percent);
+			e_cal_component_free_percent (percent);
 
 			top = bound_text (pc, font, percent_string,
 					  left, right, top, bottom, 0);
@@ -2350,7 +2363,7 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 
 
 		/* URL */
-		cal_component_get_url (comp, &url);
+		e_cal_component_get_url (comp, &url);
 		if (url && url[0]) {
 			char *url_string = g_strdup_printf (_("URL: %s"),
 							    url);
@@ -2364,7 +2377,7 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 	}
 
 	/* Categories */
-	cal_component_get_categories (comp, &categories);
+	e_cal_component_get_categories (comp, &categories);
 	if (categories && categories[0]) {
 		categories_string = g_strdup_printf (_("Categories: %s"),
 						     categories);
@@ -2375,17 +2388,17 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 	}
 
 	/* Contacts */
-	cal_component_get_contact_list (comp, &contact_list);
+	e_cal_component_get_contact_list (comp, &contact_list);
 	if (contact_list) {
 		GString *contacts = g_string_new (_("Contacts: "));
 		for (elem = contact_list; elem; elem = elem->next) {
-			CalComponentText *t = elem->data;
+			ECalComponentText *t = elem->data;
 			/* Put a comma between contacts. */
 			if (elem != contact_list)
 				g_string_append (contacts, ", ");
 			g_string_append (contacts, t->value);
 		}
-		cal_component_free_text_list (contact_list);
+		e_cal_component_free_text_list (contact_list);
 
 		top = bound_text (pc, font, contacts->str,
 				  left, right, top, bottom, 0);
@@ -2397,14 +2410,14 @@ print_comp_item (GnomePrintContext *pc, CalComponent *comp, CalClient *client,
 	top -= 16;
 
 	/* Description */
-	cal_component_get_description_list (comp, &desc);
+	e_cal_component_get_description_list (comp, &desc);
 	for (l = desc; l != NULL; l = l->next) {
-		CalComponentText *text = l->data;
+		ECalComponentText *text = l->data;
 
 		if (text->value != NULL)
 			top = bound_text (pc, font, text->value, left, right, top-3, bottom, 0);
 	}
-	cal_component_free_text_list (desc);
+	e_cal_component_free_text_list (desc);
 	g_object_unref (font);
 
 	gnome_print_showpage (pc);
@@ -2417,7 +2430,7 @@ print_calendar (GnomeCalendar *gcal, gboolean preview, time_t date,
 	GnomePrintJob *gpm;
 	GnomePrintContext *pc;
 	int copies, collate;
-	double l, r, t, b, temp_d;
+	double l, r, t, b;
 	gchar *old_orientation;
 
 	g_return_if_fail (gcal != NULL);
@@ -2528,15 +2541,15 @@ print_calendar (GnomeCalendar *gcal, gboolean preview, time_t date,
 
 
 void
-print_comp (CalComponent *comp, CalClient *client, gboolean preview)
+print_comp (ECalComponent *comp, ECal *client, gboolean preview)
 {
 	GnomePrintJob *gpm;
 	GnomePrintContext *pc;
 	int copies, collate;
-	double l, r, t, b, temp_d;
+	double l, r, t, b;
 
 	g_return_if_fail (comp != NULL);
-	g_return_if_fail (IS_CAL_COMPONENT (comp));
+	g_return_if_fail (E_IS_CAL_COMPONENT (comp));
 
 	if (!print_config)
 		print_config = gnome_print_config_default ();
