@@ -32,13 +32,11 @@
 #include <libgnome/gnome-i18n.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-exception.h>
-#include <cal-client.h>
+#include <libecal/e-cal.h>
 #include <importer/evolution-importer.h>
 #include <importer/evolution-intelligent-importer.h>
 #include <importer/GNOME_Evolution_Importer.h>
-#include <shell/e-shell.h>
-#include <shell/evolution-shell-client.h>
-#include "icalvcal.h"
+#include <libical/icalvcal.h>
 #include "evolution-calendar-importer.h"
 
 /* We timeout after 2 minutes, when opening the folders. */
@@ -46,8 +44,8 @@
 
 
 typedef struct {
-	CalClient *client;
-	CalClient *tasks_client;
+	ECal *client;
+	ECal *tasks_client;
 	EvolutionImporter *importer;
 	icalcomponent *icalcomp;
 	gboolean folder_contains_events;
@@ -127,25 +125,28 @@ read_file (const char *filename)
 static GList*
 prepare_events (icalcomponent *icalcomp)
 {
-	icalcomponent *subcomp, *next_subcomp;
+	icalcomponent *subcomp;
 	GList *vtodos = NULL;
+	icalcompiter iter;
 
-	subcomp = icalcomponent_get_first_component (icalcomp,
-						     ICAL_ANY_COMPONENT);
-	while (subcomp) {
+	iter = icalcomponent_begin_component (icalcomp, ICAL_ANY_COMPONENT);
+	while ((subcomp = icalcompiter_deref (&iter)) != NULL) {
 		icalcomponent_kind child_kind = icalcomponent_isa (subcomp);
-		next_subcomp = icalcomponent_get_next_component (icalcomp, ICAL_ANY_COMPONENT);
 		if (child_kind != ICAL_VEVENT_COMPONENT
 		    && child_kind != ICAL_VTIMEZONE_COMPONENT) {
 
-			icalcomponent_remove_component (icalcomp,
-							subcomp);
+			icalcompiter_next (&iter);
+
+			icalcomponent_remove_component (icalcomp, subcomp);
 			if (child_kind == ICAL_VTODO_COMPONENT)
 				vtodos = g_list_prepend (vtodos, subcomp);
 			else
 				icalcomponent_free (subcomp);
+
+			continue;
 		}
-		subcomp = next_subcomp;
+
+		icalcompiter_next (&iter);
 	}
 
 	return vtodos;
@@ -158,20 +159,23 @@ prepare_events (icalcomponent *icalcomp)
 static void
 prepare_tasks (icalcomponent *icalcomp, GList *vtodos)
 {
-	icalcomponent *subcomp, *next_subcomp;
+	icalcomponent *subcomp;
 	GList *elem;
+	icalcompiter iter;
 
-	subcomp = icalcomponent_get_first_component (icalcomp,
-						     ICAL_ANY_COMPONENT);
-	while (subcomp) {
+	iter = icalcomponent_begin_component (icalcomp, ICAL_ANY_COMPONENT);
+	while ((subcomp = icalcompiter_deref (&iter)) != NULL) {
 		icalcomponent_kind child_kind = icalcomponent_isa (subcomp);
-		next_subcomp = icalcomponent_get_next_component (icalcomp, ICAL_ANY_COMPONENT);
 		if (child_kind != ICAL_VTODO_COMPONENT
 		    && child_kind != ICAL_VTIMEZONE_COMPONENT) {
+			icalcompiter_next (&iter);
 			icalcomponent_remove_component (icalcomp, subcomp);
 			icalcomponent_free (subcomp);
+
+			continue;
 		}
-		subcomp = next_subcomp;
+
+		icalcompiter_next (&iter);
 	}
 
 	for (elem = vtodos; elem; elem = elem->next) {
@@ -180,6 +184,59 @@ prepare_tasks (icalcomponent *icalcomp, GList *vtodos)
 	g_list_free (vtodos);
 }
 
+static gboolean
+update_single_object (ECal *client, icalcomponent *icalcomp)
+{
+	char *uid;
+	icalcomponent *tmp_icalcomp;
+
+	uid = (char *) icalcomponent_get_uid (icalcomp);
+	
+	if (e_cal_get_object (client, uid, NULL, &tmp_icalcomp, NULL))
+		return e_cal_modify_object (client, icalcomp, CALOBJ_MOD_ALL, NULL);
+
+	return e_cal_create_object (client, icalcomp, &uid, NULL);	
+}
+
+static gboolean
+update_objects (ECal *client, icalcomponent *icalcomp)
+{
+	icalcomponent *subcomp;
+	icalcomponent_kind kind;
+
+	kind = icalcomponent_isa (icalcomp);
+	if (kind == ICAL_VTODO_COMPONENT || kind == ICAL_VEVENT_COMPONENT)
+		return update_single_object (client, icalcomp);
+	else if (kind != ICAL_VCALENDAR_COMPONENT)
+		return FALSE;
+
+	subcomp = icalcomponent_get_first_component (icalcomp, ICAL_ANY_COMPONENT);
+	while (subcomp) {
+		gboolean success;
+		
+		kind = icalcomponent_isa (subcomp);
+		if (kind == ICAL_VTIMEZONE_COMPONENT) {
+			icaltimezone *zone;
+
+			zone = icaltimezone_new ();
+			icaltimezone_set_component (zone, subcomp);
+
+			success = e_cal_add_timezone (client, zone, NULL);
+			icaltimezone_free (zone, 1);
+			if (!success)
+				return success;
+		} else if (kind == ICAL_VTODO_COMPONENT ||
+			   kind == ICAL_VEVENT_COMPONENT) {
+			success = update_single_object (client, subcomp);
+			if (!success)
+				return success;
+		}
+
+		subcomp = icalcomponent_get_next_component (icalcomp, ICAL_ANY_COMPONENT);
+	}
+
+	return TRUE;
+}
 
 static void
 process_item_fn (EvolutionImporter *importer,
@@ -187,27 +244,27 @@ process_item_fn (EvolutionImporter *importer,
 		 void *closure,
 		 CORBA_Environment *ev)
 {
-	CalClientLoadState state, tasks_state;
+	ECalLoadState state, tasks_state;
 	ICalImporter *ici = (ICalImporter *) closure;
 	GNOME_Evolution_ImporterListener_ImporterResult result;
 
 	result = GNOME_Evolution_ImporterListener_OK;
 
 	g_return_if_fail (ici != NULL);
-	g_return_if_fail (IS_CAL_CLIENT (ici->client));
+	g_return_if_fail (E_IS_CAL (ici->client));
 	g_return_if_fail (ici->icalcomp != NULL);
 
-	state = cal_client_get_load_state (ici->client);
-	tasks_state = cal_client_get_load_state (ici->tasks_client);
-	if (state == CAL_CLIENT_LOAD_LOADING
-	    || tasks_state == CAL_CLIENT_LOAD_LOADING) {
+	state = e_cal_get_load_state (ici->client);
+	tasks_state = e_cal_get_load_state (ici->tasks_client);
+	if (state == E_CAL_LOAD_LOADING
+	    || tasks_state == E_CAL_LOAD_LOADING) {
 		GNOME_Evolution_ImporterListener_notifyResult (
 			listener,
 			GNOME_Evolution_ImporterListener_BUSY,
 			TRUE, ev);
 		return;
-	} else if (state != CAL_CLIENT_LOAD_LOADED
-		   || tasks_state != CAL_CLIENT_LOAD_LOADED) {
+	} else if (state != E_CAL_LOAD_LOADED
+		   || tasks_state != E_CAL_LOAD_LOADED) {
 		GNOME_Evolution_ImporterListener_notifyResult (
 			listener,
 			GNOME_Evolution_ImporterListener_UNSUPPORTED_OPERATION,
@@ -221,20 +278,19 @@ process_item_fn (EvolutionImporter *importer,
 	   contains just tasks, we strip out the VEVENTs, which do not get
 	   imported at all. */
 	if (ici->folder_contains_events && ici->folder_contains_tasks) {
-		if (cal_client_update_objects (ici->client, ici->icalcomp) != CAL_CLIENT_RESULT_SUCCESS)
+		if (!update_objects (ici->client, ici->icalcomp))
 			result = GNOME_Evolution_ImporterListener_BAD_DATA;
 	} else if (ici->folder_contains_events) {
 		GList *vtodos = prepare_events (ici->icalcomp);
-		if (cal_client_update_objects (ici->client, ici->icalcomp) != CAL_CLIENT_RESULT_SUCCESS)
+		if (!update_objects (ici->client, ici->icalcomp))
 			result = GNOME_Evolution_ImporterListener_BAD_DATA;
 
 		prepare_tasks (ici->icalcomp, vtodos);
-		if (cal_client_update_objects (ici->tasks_client,
-					       ici->icalcomp) != CAL_CLIENT_RESULT_SUCCESS)
+		if (!update_objects (ici->tasks_client, ici->icalcomp))
 			result = GNOME_Evolution_ImporterListener_BAD_DATA;
 	} else {
 		prepare_tasks (ici->icalcomp, NULL);
-		if (cal_client_update_objects (ici->client, ici->icalcomp) != CAL_CLIENT_RESULT_SUCCESS)
+		if (!update_objects (ici->client, ici->icalcomp))
 			result = GNOME_Evolution_ImporterListener_BAD_DATA;
 	}
 
@@ -262,8 +318,11 @@ support_format_fn (EvolutionImporter *importer,
 	if (contents) {
 		icalcomp = icalparser_parse_string (contents);
 		if (icalcomp) {
+			if (icalcomponent_is_valid (icalcomp))
+				ret = TRUE;
+			else 
+				ret = FALSE;
 			icalcomponent_free (icalcomp);
-			ret = TRUE;
 		}
 	}
 
@@ -313,8 +372,14 @@ load_file_fn (EvolutionImporter *importer,
 			} else
 				real_uri = g_strdup (physical_uri);
 
-			if (cal_client_open_calendar (ici->client, real_uri, TRUE)
-			    && cal_client_open_default_tasks (ici->tasks_client, FALSE)) {
+			/* create ECal's */
+			if (!ici->client)
+				ici->client = e_cal_new_from_uri (real_uri, CALOBJ_TYPE_EVENT);
+			if (!ici->tasks_client)
+				ici->tasks_client = e_cal_new_from_uri ("", CALOBJ_TYPE_TODO); /* FIXME */
+
+			if (e_cal_open (ici->client, TRUE, NULL)
+			    && e_cal_open (ici->tasks_client, FALSE, NULL)) {
 				ici->icalcomp = icalcomp;
 				ret = TRUE;
 			}
@@ -335,8 +400,8 @@ ical_importer_new (void)
 	ICalImporter *ici;
 
 	ici = g_new0 (ICalImporter, 1);
-	ici->client = cal_client_new ();
-	ici->tasks_client = cal_client_new ();
+	ici->client = NULL;
+	ici->tasks_client = NULL;
 	ici->icalcomp = NULL;
 	ici->importer = evolution_importer_new (support_format_fn,
 						load_file_fn,
@@ -459,8 +524,14 @@ vcal_load_file_fn (EvolutionImporter *importer,
 		} else
 			real_uri = g_strdup (physical_uri);
 
-		if (cal_client_open_calendar (ici->client, real_uri, TRUE)
-		    && cal_client_open_default_tasks (ici->tasks_client, FALSE)) {
+		/* create ECal's */
+		if (!ici->client)
+			ici->client = e_cal_new_from_uri (real_uri, CALOBJ_TYPE_EVENT);
+		if (!ici->tasks_client)
+			ici->tasks_client = e_cal_new_from_uri ("", CALOBJ_TYPE_TODO);
+
+		if (e_cal_open (ici->client, TRUE, NULL)
+		    && e_cal_open (ici->tasks_client, FALSE, NULL)) {
 			ici->icalcomp = icalcomp;
 			ret = TRUE;
 		}
@@ -479,8 +550,8 @@ vcal_importer_new (void)
 	ICalImporter *ici;
 
 	ici = g_new0 (ICalImporter, 1);
-	ici->client = cal_client_new ();
-	ici->tasks_client = cal_client_new ();
+	ici->client = NULL;
+	ici->tasks_client = NULL;
 	ici->icalcomp = NULL;
 	ici->importer = evolution_importer_new (vcal_support_format_fn,
 						vcal_load_file_fn,
@@ -533,7 +604,7 @@ gnome_calendar_import_data_fn (EvolutionIntelligentImporter *ii,
 	icalcomponent *icalcomp = NULL;
 	char *filename;
 	GList *vtodos;
-	CalClient *calendar_client = NULL, *tasks_client = NULL;
+	ECal *calendar_client = NULL, *tasks_client = NULL;
 	int t;
 
 	/* If neither is selected, just return. */
@@ -543,14 +614,14 @@ gnome_calendar_import_data_fn (EvolutionIntelligentImporter *ii,
 
 	/* Try to open the default calendar & tasks folders. */
 	if (ici->do_calendar) {
-		calendar_client = cal_client_new ();
-		if (!cal_client_open_default_calendar (calendar_client, FALSE))
+		calendar_client = e_cal_new_from_uri ("", CALOBJ_TYPE_EVENT); /* FIXME: use default folder */
+		if (!e_cal_open (calendar_client, FALSE, NULL))
 			goto out;
 	}
 
 	if (ici->do_tasks) {
-		tasks_client = cal_client_new ();
-		if (!cal_client_open_default_tasks (tasks_client, FALSE))
+		tasks_client = e_cal_new_from_uri ("", CALOBJ_TYPE_TODO); /* FIXME: use default folder */
+		if (!e_cal_open (tasks_client, FALSE, NULL))
 			goto out;
 	}
 
@@ -570,23 +641,23 @@ gnome_calendar_import_data_fn (EvolutionIntelligentImporter *ii,
 
 	/* Wait for client to finish opening the calendar & tasks folders. */
 	for (t = 0; t < IMPORTER_TIMEOUT_SECONDS; t++) {
-		CalClientLoadState calendar_state, tasks_state;
+		ECalLoadState calendar_state, tasks_state;
 
-		calendar_state = tasks_state = CAL_CLIENT_LOAD_LOADED;
+		calendar_state = tasks_state = E_CAL_LOAD_LOADED;
 
-		/* We need this so the CalClient gets notified that the
+		/* We need this so the ECal gets notified that the
 		   folder is opened, via Corba. */
 		while (gtk_events_pending ())
 			gtk_main_iteration ();
 
 		if (ici->do_calendar)
-			calendar_state = cal_client_get_load_state (calendar_client);
+			calendar_state = e_cal_get_load_state (calendar_client);
 
 		if (ici->do_tasks)
-			tasks_state = cal_client_get_load_state (tasks_client);
+			tasks_state = e_cal_get_load_state (tasks_client);
 
-		if (calendar_state == CAL_CLIENT_LOAD_LOADED
-		    && tasks_state == CAL_CLIENT_LOAD_LOADED)
+		if (calendar_state == E_CAL_LOAD_LOADED
+		    && tasks_state == E_CAL_LOAD_LOADED)
 			break;
 
 		sleep (1);
@@ -599,7 +670,7 @@ gnome_calendar_import_data_fn (EvolutionIntelligentImporter *ii,
 	/* Import the calendar events. */
 	/* FIXME: What do intelligent importers do about errors? */
 	if (ici->do_calendar)
-		cal_client_update_objects (calendar_client, icalcomp);
+		update_objects (calendar_client, icalcomp);
 
 
 	/*
@@ -607,7 +678,7 @@ gnome_calendar_import_data_fn (EvolutionIntelligentImporter *ii,
 	 */
 	prepare_tasks (icalcomp, vtodos);
 	if (ici->do_tasks)
-		cal_client_update_objects (tasks_client, icalcomp);
+		update_objects (tasks_client, icalcomp);
 
  out:
 	if (icalcomp)
