@@ -48,7 +48,7 @@ struct _CamelMessageContentInfo {
 	struct _CamelMessageContentInfo *childs;
 	struct _CamelMessageContentInfo *parent;
 	
-	struct _header_content_type *type;
+	CamelContentType *type;
 	char *id;
 	char *description;
 	char *encoding;		/* this should be an enum?? */
@@ -64,6 +64,7 @@ enum _CamelMessageFlags {
 	CAMEL_MESSAGE_SEEN = 1<<4,
 	CAMEL_MESSAGE_ATTACHMENTS = 1<<5,
 	CAMEL_MESSAGE_ANSWERED_ALL = 1<<6,
+	CAMEL_MESSAGE_JUNK = 1<<7,
 
 	/* following flags are for the folder, and are not really permanent flags */
 	CAMEL_MESSAGE_FOLDER_FLAGGED = 1<<16, /* for use by the folder implementation */
@@ -191,7 +192,7 @@ struct _CamelFolderSummaryClass {
 	int (*summary_header_save)(CamelFolderSummary *, FILE *);
 
 	/* create/save/load an individual message info */
-	CamelMessageInfo * (*message_info_new)(CamelFolderSummary *, struct _header_raw *);
+	CamelMessageInfo * (*message_info_new)(CamelFolderSummary *, struct _camel_header_raw *);
 	CamelMessageInfo * (*message_info_new_from_parser)(CamelFolderSummary *, CamelMimeParser *);
 	CamelMessageInfo * (*message_info_new_from_message)(CamelFolderSummary *, CamelMimeMessage *);
 	CamelMessageInfo * (*message_info_load)(CamelFolderSummary *, FILE *);
@@ -199,7 +200,7 @@ struct _CamelFolderSummaryClass {
 	void		   (*message_info_free)(CamelFolderSummary *, CamelMessageInfo *);
 
 	/* save/load individual content info's */
-	CamelMessageContentInfo * (*content_info_new)(CamelFolderSummary *, struct _header_raw *);
+	CamelMessageContentInfo * (*content_info_new)(CamelFolderSummary *, struct _camel_header_raw *);
 	CamelMessageContentInfo * (*content_info_new_from_parser)(CamelFolderSummary *, CamelMimeParser *);
 	CamelMessageContentInfo * (*content_info_new_from_message)(CamelFolderSummary *, CamelMimePart *);
 	CamelMessageContentInfo * (*content_info_load)(CamelFolderSummary *, FILE *);
@@ -235,13 +236,13 @@ void camel_folder_summary_touch(CamelFolderSummary *s);
 void camel_folder_summary_add(CamelFolderSummary *, CamelMessageInfo *info);
 
 /* build/add raw summary items */
-CamelMessageInfo *camel_folder_summary_add_from_header(CamelFolderSummary *, struct _header_raw *);
+CamelMessageInfo *camel_folder_summary_add_from_header(CamelFolderSummary *, struct _camel_header_raw *);
 CamelMessageInfo *camel_folder_summary_add_from_parser(CamelFolderSummary *, CamelMimeParser *);
 CamelMessageInfo *camel_folder_summary_add_from_message(CamelFolderSummary *, CamelMimeMessage *);
 
 /* Just build raw summary items */
 CamelMessageInfo *camel_folder_summary_info_new(CamelFolderSummary *s);
-CamelMessageInfo *camel_folder_summary_info_new_from_header(CamelFolderSummary *, struct _header_raw *);
+CamelMessageInfo *camel_folder_summary_info_new_from_header(CamelFolderSummary *, struct _camel_header_raw *);
 CamelMessageInfo *camel_folder_summary_info_new_from_parser(CamelFolderSummary *, CamelMimeParser *);
 CamelMessageInfo *camel_folder_summary_info_new_from_message(CamelFolderSummary *, CamelMimeMessage *);
 
@@ -255,6 +256,7 @@ void camel_folder_summary_content_info_free(CamelFolderSummary *s, CamelMessageC
 void camel_folder_summary_remove(CamelFolderSummary *s, CamelMessageInfo *info);
 void camel_folder_summary_remove_uid(CamelFolderSummary *s, const char *uid);
 void camel_folder_summary_remove_index(CamelFolderSummary *s, int);
+void camel_folder_summary_remove_range(CamelFolderSummary *s, int start, int end);
 /* remove all items */
 void camel_folder_summary_clear(CamelFolderSummary *s);
 
@@ -266,8 +268,8 @@ GPtrArray *camel_folder_summary_array(CamelFolderSummary *s);
 void camel_folder_summary_array_free(CamelFolderSummary *s, GPtrArray *array);
 
 /* summary formatting utils */
-char *camel_folder_summary_format_address(struct _header_raw *h, const char *name);
-char *camel_folder_summary_format_string(struct _header_raw *h, const char *name);
+char *camel_folder_summary_format_address(struct _camel_header_raw *h, const char *name);
+char *camel_folder_summary_format_string(struct _camel_header_raw *h, const char *name);
 
 /* basically like strings, but certain keywords can be compressed and de-cased */
 int camel_folder_summary_encode_token(FILE *, const char *);
@@ -295,7 +297,7 @@ void		camel_tag_list_free(CamelTag **list);
    other external interfaces that use message info's */
 CamelMessageInfo *camel_message_info_new(void);
 void camel_message_info_ref(CamelMessageInfo *info);
-CamelMessageInfo *camel_message_info_new_from_header(struct _header_raw *header);
+CamelMessageInfo *camel_message_info_new_from_header(struct _camel_header_raw *header);
 void camel_message_info_dup_to(const CamelMessageInfo *from, CamelMessageInfo *to);
 void camel_message_info_free(CamelMessageInfo *mi);
 
