@@ -6,7 +6,7 @@
  * Author :
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -23,21 +23,18 @@
  * USA
  */
 
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <sys/types.h>
-#include <sys/time.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
+#include <pthread.h>
 #include <errno.h>
 
-#ifdef ENABLE_THREADS
-#include <pthread.h>
 #include "e-util/e-msgport.h"
-#endif
 
 #include "e-util/e-host-utils.h"
 
@@ -95,12 +92,10 @@ static void
 camel_service_init (void *o, void *k)
 {
 	CamelService *service = o;
-
+	
 	service->priv = g_malloc0(sizeof(*service->priv));
-#ifdef ENABLE_THREADS
 	service->priv->connect_lock = e_mutex_new(E_MUTEX_REC);
 	service->priv->connect_op_lock = e_mutex_new(E_MUTEX_SIMPLE);
-#endif
 }
 
 static void
@@ -123,12 +118,11 @@ camel_service_finalize (CamelObject *object)
 	if (service->url)
 		camel_url_free (service->url);
 	if (service->session)
-		camel_object_unref (CAMEL_OBJECT (service->session));
+		camel_object_unref (service->session);
 	
-#ifdef ENABLE_THREADS
 	e_mutex_destroy (service->priv->connect_lock);
 	e_mutex_destroy (service->priv->connect_op_lock);
-#endif
+	
 	g_free (service->priv);
 }
 
@@ -306,7 +300,7 @@ construct (CamelService *service, CamelSession *session,
 	service->provider = provider;
 	service->url = url;
 	service->session = session;
-	camel_object_ref (CAMEL_OBJECT (session));
+	camel_object_ref (session);
 	
 	service->status = CAMEL_SERVICE_DISCONNECTED;
 }
@@ -689,16 +683,9 @@ camel_service_gethost (CamelService *service, CamelException *ex)
 #define STRUCT_OFFSET(type, field)        ((gint) ((gchar*) &((type *) 0)->field))
 #endif
 
-enum {
-	LOOKUP_QUIT,
-	LOOKUP_HOSTBYNAME,
-	LOOKUP_HOSTBYADDR,
-};
-
 struct _lookup_msg {
 	EMsg msg;
 	unsigned int cancelled:1;
-	unsigned int op:2;
 	const char *name;
 	int len;
 	int type;
@@ -709,112 +696,67 @@ struct _lookup_msg {
 	char *hostbufmem;
 };
 
-static pthread_once_t gethostbyx_once = PTHREAD_ONCE_INIT;
-static EMsgPort *gethostbyx_port;
-static int gethostbyx_threaded = FALSE;
-
-static void
-run_gethostbyx_lookup(struct _lookup_msg *info)
-{
-	do {
-		if (info->op == LOOKUP_HOSTBYNAME)
-			info->result = e_gethostbyname_r(info->name, &info->hostbuf, info->hostbufmem, info->hostbuflen, &info->herr);
-		else
-			info->result = e_gethostbyaddr_r(info->name, info->len, info->type, &info->hostbuf, info->hostbufmem, info->hostbuflen, &info->herr);
-		
-		if (info->result == ERANGE) {
-			info->hostbuflen *= 2;
-			info->hostbufmem = g_realloc(info->hostbufmem, info->hostbuflen);
-		}
-	} while (info->result == ERANGE && !info->cancelled);
-}
-
 static void *
-run_gethostbyx(void *data)
+get_hostbyname(void *data)
 {
-	int more = TRUE;
+	struct _lookup_msg *info = data;
 
-	/* This never quits actually ... */
-	do {
-		struct _lookup_msg *msg;
-
-		e_msgport_wait(gethostbyx_port);
-		msg = (struct _lookup_msg *)e_msgport_get(gethostbyx_port);
-		if (msg == NULL)
-			continue;
-
-		if (!msg->cancelled)
-			run_gethostbyx_lookup(msg);
-
-		if (msg->cancelled) {
-			g_free(msg->hostbufmem);
-			g_free(msg);
-		} else {
-			e_msgport_reply((EMsg *)msg);
-		}
-	} while (more);
+	while ((info->result = e_gethostbyname_r(info->name, &info->hostbuf, info->hostbufmem, info->hostbuflen, &info->herr)) == ERANGE) {
+		d(printf("gethostbyname fialed?\n"));
+		pthread_testcancel();
+                info->hostbuflen *= 2;
+                info->hostbufmem = g_realloc(info->hostbufmem, info->hostbuflen);
+	}
 
+	d(printf("gethostbyname ok?\n"));
+	
+	/* If we got cancelled, dont reply, just free it */
+	if (info->cancelled) {
+		g_free(info->hostbufmem);
+		g_free(info);
+	} else {
+		e_msgport_reply((EMsg *)info);
+	}
+	
 	return NULL;
 }
 
-static void
-init_gethostbyx(void)
-{
-	pthread_t id;
-	int count = 3, i;
-	char *tmp;
-
-	gethostbyx_port = e_msgport_new();
-
-	tmp = getenv("CAMEL_DNS_THREADS");
-	if (tmp && tmp[0]) {
-		count = MAX(atoi(tmp), 1);
-		g_warning("Overriding CAMEL_DNS_THREADS: %d threads for dns lookups", count);
-	}
-
-	/* We could create as many threads as we want here, they're auto-setup as consumers by e_msgport */
-	for (i=0;i<count;i++) {
-		if (pthread_create(&id, NULL, run_gethostbyx, NULL) != 0 && i == 0) {
-			g_warning("Could not create async dns thread, host lookups will block");
-			return;
-		}
-	}
-
-	gethostbyx_threaded = TRUE;
-}
-
-static struct hostent *
-get_hostbyx(struct _lookup_msg *msg, CamelException *exout)
+struct hostent *
+camel_gethostbyname (const char *name, CamelException *exout)
 {
+	int fdmax, status, fd, cancel_fd;
+	struct _lookup_msg *msg;
 	CamelException ex;
-
-	/* This routine is used to serialise name lookups, and make them 'cancellable', in practice,
-	   we can't cancel, but we just throw away the result.  The problem is that if one name lookup
-	   is taking an inordinate amount of time, any new lookups will have to wait till that
-	   one times out.  A sort of workaround is to setup more than one lookup thread ... */
-
-	pthread_once(&gethostbyx_once, init_gethostbyx);
 	
+	g_return_val_if_fail(name != NULL, NULL);
+	
+	if (camel_operation_cancel_check(NULL)) {
+		camel_exception_set (exout, CAMEL_EXCEPTION_USER_CANCEL, _("Cancelled"));
+		return NULL;
+	}
+
 	camel_exception_init(&ex);
+	camel_operation_start_transient(NULL, _("Resolving: %s"), name);
 
-	if (msg->op == LOOKUP_HOSTBYNAME)
-		camel_operation_start_transient(NULL, _("Resolving: %s"), msg->name);
-	else
-		camel_operation_start_transient(NULL, _("Resolving address"));
-
-	if (gethostbyx_threaded) {
-		int fdmax, status, fd, cancel_fd;
+	msg = g_malloc0(sizeof(*msg));
+	msg->hostbuflen = 1024;
+	msg->hostbufmem = g_malloc(msg->hostbuflen);
+	msg->name = name;
+	msg->result = -1;
+	
+	cancel_fd = camel_operation_cancel_fd(NULL);
+	if (cancel_fd == -1) {
+		get_hostbyname(msg);
+	} else {
 		EMsgPort *reply_port;
+		pthread_t id;
 		fd_set rdset;
+		int err;
 
 		reply_port = msg->msg.reply_port = e_msgport_new();
-		cancel_fd = camel_operation_cancel_fd(NULL);
-		if (cancel_fd != -1)
-			fd = e_msgport_fd(msg->msg.reply_port);
-
-		e_msgport_put(gethostbyx_port, (EMsg *)msg);
-
-		if (cancel_fd != -1) {
+		fd = e_msgport_fd(msg->msg.reply_port);
+		if ((err = pthread_create(&id, NULL, get_hostbyname, msg)) == 0) {
+			d(printf("waiting for name return/cancellation in main process\n"));
 			do {
 				FD_ZERO(&rdset);
 				FD_SET(cancel_fd, &rdset);
@@ -829,28 +771,156 @@ get_hostbyx(struct _lookup_msg *msg, CamelException *exout)
 				else
 					camel_exception_setv(&ex, CAMEL_EXCEPTION_USER_CANCEL, _("Cancelled"));
 
+				/* We cancel so if the thread impl is decent it causes immediate exit.
+				   We detach so we dont need to wait for it to exit if it isn't.
+				   We check the reply port incase we had a reply in the mean time, which we free later */
+				d(printf("Cancelling lookup thread and leaving it\n"));
 				msg->cancelled = 1;
-				/* we could leak the message here, but its not very likely, and only small and harmless */
+				pthread_detach(id);
+				pthread_cancel(id);
 				msg = (struct _lookup_msg *)e_msgport_get(reply_port);
 			} else {
 				struct _lookup_msg *reply = (struct _lookup_msg *)e_msgport_get(reply_port);
 
 				g_assert(reply == msg);
+				d(printf("waiting for child to exit\n"));
+				pthread_join(id, NULL);
+				d(printf("child done\n"));
 			}
 		} else {
-			struct _lookup_msg *reply;
-
-			e_msgport_wait(reply_port);
-			reply = (struct _lookup_msg *)e_msgport_get(reply_port);
-			g_assert(reply == msg);
+			camel_exception_setv(&ex, CAMEL_EXCEPTION_SYSTEM, _("Host lookup failed: cannot create thread: %s"), g_strerror(err));
 		}
 		e_msgport_destroy(reply_port);
-	} else {
-		run_gethostbyx_lookup(msg);
 	}
-
+	
 	camel_operation_end(NULL);
 
+	if (!camel_exception_is_set(&ex)) {
+		if (msg->result == 0)
+			return &msg->hostbuf;
+
+		if (msg->herr == HOST_NOT_FOUND || msg->herr == NO_DATA)
+			camel_exception_setv (&ex, CAMEL_EXCEPTION_SYSTEM,
+					      _("Host lookup failed: %s: host not found"), name);
+		else
+			camel_exception_setv (&ex, CAMEL_EXCEPTION_SYSTEM,
+					      _("Host lookup failed: %s: unknown reason"), name);
+	}
+
+	if (msg) {
+		g_free(msg->hostbufmem);
+		g_free(msg);
+	}
+
+	camel_exception_xfer(exout, &ex);
+
+	return NULL;
+}
+
+static void *
+get_hostbyaddr (void *data)
+{
+	struct _lookup_msg *info = data;
+	
+	while ((info->result = e_gethostbyaddr_r (info->name, info->len, info->type, &info->hostbuf,
+						  info->hostbufmem, info->hostbuflen, &info->herr)) == ERANGE) {
+		d(printf ("gethostbyaddr fialed?\n"));
+		pthread_testcancel ();
+                info->hostbuflen *= 2;
+                info->hostbufmem = g_realloc (info->hostbufmem, info->hostbuflen);
+	}
+	
+	d(printf ("gethostbyaddr ok?\n"));
+	
+	if (info->cancelled) {
+		g_free(info->hostbufmem);
+		g_free(info);
+	} else {
+		e_msgport_reply((EMsg *)info);
+	}
+	
+	return NULL;
+}
+
+
+struct hostent *
+camel_gethostbyaddr (const char *addr, int len, int type, CamelException *exout)
+{
+	int fdmax, status, fd, cancel_fd;
+	struct _lookup_msg *msg;
+	CamelException ex;
+
+	g_return_val_if_fail (addr != NULL, NULL);
+	
+	if (camel_operation_cancel_check (NULL)) {
+		camel_exception_set (exout, CAMEL_EXCEPTION_USER_CANCEL, _("Cancelled"));
+		return NULL;
+	}
+
+	camel_exception_init(&ex);
+	camel_operation_start_transient (NULL, _("Resolving address"));
+	
+	msg = g_malloc0 (sizeof (struct _lookup_msg));
+	msg->hostbuflen = 1024;
+	msg->hostbufmem = g_malloc (msg->hostbuflen);
+	msg->name = addr;
+	msg->len = len;
+	msg->type = type;
+	msg->result = -1;
+	
+	cancel_fd = camel_operation_cancel_fd (NULL);
+	if (cancel_fd == -1) {
+		get_hostbyaddr (msg);
+	} else {
+		EMsgPort *reply_port;
+		pthread_t id;
+		fd_set rdset;
+		int err;
+
+		reply_port = msg->msg.reply_port = e_msgport_new ();
+		fd = e_msgport_fd (msg->msg.reply_port);
+		if ((err = pthread_create (&id, NULL, get_hostbyaddr, msg)) == 0) {
+			d(printf("waiting for name return/cancellation in main process\n"));
+			do {
+				FD_ZERO(&rdset);
+				FD_SET(cancel_fd, &rdset);
+				FD_SET(fd, &rdset);
+				fdmax = MAX(fd, cancel_fd) + 1;
+				status = select (fdmax, &rdset, NULL, 0, NULL);
+			} while (status == -1 && errno == EINTR);
+			
+			if (status == -1 || FD_ISSET(cancel_fd, &rdset)) {
+				if (status == -1)
+					camel_exception_setv(&ex, CAMEL_EXCEPTION_SYSTEM, _("Failure in name lookup: %s"), g_strerror(errno));
+				else
+					camel_exception_setv(&ex, CAMEL_EXCEPTION_USER_CANCEL, _("Cancelled"));
+
+				/* We cancel so if the thread impl is decent it causes immediate exit.
+				   We detach so we dont need to wait for it to exit if it isn't.
+				   We check the reply port incase we had a reply in the mean time, which we free later */
+				d(printf("Cancelling lookup thread and leaving it\n"));
+				msg->cancelled = 1;
+				pthread_detach(id);
+				pthread_cancel(id);
+				msg = (struct _lookup_msg *)e_msgport_get(reply_port);
+			} else {
+				struct _lookup_msg *reply = (struct _lookup_msg *)e_msgport_get(reply_port);
+
+				g_assert(reply == msg);
+				d(printf("waiting for child to exit\n"));
+				pthread_join(id, NULL);
+				d(printf("child done\n"));
+			}
+		} else {
+			camel_exception_setv(&ex, CAMEL_EXCEPTION_SYSTEM, _("Host lookup failed: cannot create thread: %s"), g_strerror(err));
+		}
+
+		
+		e_msgport_destroy (reply_port);
+	}
+	
+	camel_operation_end (NULL);
+	
 	if (!camel_exception_is_set(&ex)) {
 		if (msg->result == 0)
 			return &msg->hostbuf;
@@ -873,52 +943,6 @@ get_hostbyx(struct _lookup_msg *msg, CamelException *exout)
 	return NULL;
 }
 
-struct hostent *
-camel_gethostbyname (const char *name, CamelException *exout)
-{
-	struct _lookup_msg *msg;
-	
-	g_return_val_if_fail(name != NULL, NULL);
-	
-	if (camel_operation_cancel_check(NULL)) {
-		camel_exception_set(exout, CAMEL_EXCEPTION_USER_CANCEL, _("Cancelled"));
-		return NULL;
-	}
-
-	msg = g_malloc0(sizeof(*msg));
-	msg->hostbuflen = 1024;
-	msg->hostbufmem = g_malloc(msg->hostbuflen);
-	msg->name = name;
-	msg->result = -1;
-	msg->op = LOOKUP_HOSTBYNAME;
-
-	return get_hostbyx(msg, exout);
-}
-
-struct hostent *
-camel_gethostbyaddr (const char *addr, int len, int type, CamelException *exout)
-{
-	struct _lookup_msg *msg;
-
-	g_return_val_if_fail (addr != NULL, NULL);
-	
-	if (camel_operation_cancel_check(NULL)) {
-		camel_exception_set(exout, CAMEL_EXCEPTION_USER_CANCEL, _("Cancelled"));
-		return NULL;
-	}
-
-	msg = g_malloc0(sizeof(struct _lookup_msg));
-	msg->hostbuflen = 1024;
-	msg->hostbufmem = g_malloc(msg->hostbuflen);
-	msg->name = addr;
-	msg->len = len;
-	msg->type = type;
-	msg->result = -1;
-	msg->op = LOOKUP_HOSTBYADDR;
-
-	return get_hostbyx(msg, exout);
-}
-
 void camel_free_host(struct hostent *h)
 {
 	struct _lookup_msg *msg;
