@@ -7,7 +7,7 @@
  *  Jeffrey Stedfast <fejj@ximian.com>
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
- * Copyright 1999 - 2001 Ximian, Inc.
+ * Copyright 1999 - 2003 Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -28,17 +28,18 @@
 #include <config.h>
 #endif
 
-#include <errno.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <errno.h>
 
 #include "camel-session.h"
 #include "camel-store.h"
 #include "camel-transport.h"
 #include "camel-exception.h"
-#include "string-utils.h"
+#include "camel-file-utils.h"
+#include "camel-string-utils.h"
 #include "camel-url.h"
 #include "camel-vee-store.h"
 
@@ -62,12 +63,11 @@ static char *get_storage_path (CamelSession *session,
 			       CamelService *service,
 			       CamelException *ex);
 
-#ifdef ENABLE_THREADS
 static void *session_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size);
 static void session_thread_msg_free(CamelSession *session, CamelSessionThreadMsg *msg);
 static int session_thread_queue(CamelSession *session, CamelSessionThreadMsg *msg, int flags);
 static void session_thread_wait(CamelSession *session, int id);
-#endif
+static void session_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc);
 
 /* The vfolder provider is always available */
 static CamelProvider vee_provider = {
@@ -90,17 +90,18 @@ camel_session_init (CamelSession *session)
 {
 	session->online = TRUE;
 	session->modules = camel_provider_init ();
-	session->providers = g_hash_table_new (g_strcase_hash, g_strcase_equal);
+	session->providers = g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
 	session->priv = g_malloc0(sizeof(*session->priv));
-#ifdef ENABLE_THREADS
+	
 	session->priv->lock = g_mutex_new();
 	session->priv->thread_lock = g_mutex_new();
 	session->priv->thread_id = 1;
 	session->priv->thread_active = g_hash_table_new(NULL, NULL);
 	session->priv->thread_queue = NULL;
-#endif
 }
 
+#if 0
+/* NOTE: this code ruins all chance of ever having more than 1 session object */
 static gboolean
 camel_session_destroy_provider (gpointer key, gpointer value, gpointer user_data)
 {
@@ -113,27 +114,24 @@ camel_session_destroy_provider (gpointer key, gpointer value, gpointer user_data
 	}
 	return TRUE;
 }
+#endif
 
 static void
 camel_session_finalise (CamelObject *o)
 {
 	CamelSession *session = (CamelSession *)o;
-
-#ifdef ENABLE_THREADS
+	
 	g_hash_table_destroy(session->priv->thread_active);
 	if (session->priv->thread_queue)
 		e_thread_destroy(session->priv->thread_queue);
-#endif
 
 	g_free(session->storage_path);
-	g_hash_table_foreach_remove (session->providers,
-				     camel_session_destroy_provider, NULL);
+	/*g_hash_table_foreach_remove (session->providers, camel_session_destroy_provider, NULL);*/
 	g_hash_table_destroy (session->providers);
-
-#ifdef ENABLE_THREADS
+	
 	g_mutex_free(session->priv->lock);
 	g_mutex_free(session->priv->thread_lock);
-#endif
+	
 	g_free(session->priv);
 }
 
@@ -146,13 +144,12 @@ camel_session_class_init (CamelSessionClass *camel_session_class)
 	camel_session_class->get_provider = get_provider;
 	camel_session_class->get_service = get_service;
 	camel_session_class->get_storage_path = get_storage_path;
-
-#ifdef ENABLE_THREADS
+	
 	camel_session_class->thread_msg_new = session_thread_msg_new;
 	camel_session_class->thread_msg_free = session_thread_msg_free;
 	camel_session_class->thread_queue = session_thread_queue;
 	camel_session_class->thread_wait = session_thread_wait;
-#endif
+	camel_session_class->thread_status = session_thread_status;
 	
 	vee_provider.object_types[CAMEL_PROVIDER_STORE] = camel_vee_store_get_type ();
 	vee_provider.url_hash = camel_url_hash;
@@ -502,7 +499,7 @@ camel_session_get_service_connected (CamelSession *session,
 
 	if (svc->status != CAMEL_SERVICE_CONNECTED) {
 		if (camel_service_connect (svc, ex) == FALSE) {
-			camel_object_unref (CAMEL_OBJECT (svc));
+			camel_object_unref (svc);
 			return NULL;
 		}
 	}
@@ -523,7 +520,7 @@ get_storage_path (CamelSession *session, CamelService *service, CamelException *
 	if (access (path, F_OK) == 0)
 		return path;
 
-	if (camel_mkdir_hier (path, S_IRWXU) == -1) {
+	if (camel_mkdir (path, S_IRWXU) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Could not create directory %s:\n%s"),
 				      path, g_strerror (errno));
@@ -695,7 +692,13 @@ camel_session_get_filter_driver (CamelSession *session,
 	return CS_CLASS (session)->get_filter_driver (session, type, ex);
 }
 
-#ifdef ENABLE_THREADS
+static void
+cs_thread_status(CamelOperation *op, const char *what, int pc, void *data)
+{
+	CamelSessionThreadMsg *m = data;
+
+	CS_CLASS(m->session)->thread_status(m->session, m, what, pc);
+}
 
 static void *session_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size)
 {
@@ -705,7 +708,10 @@ static void *session_thread_msg_new(CamelSession *session, CamelSessionThreadOps
 
 	m = g_malloc0(size);
 	m->ops = ops;
-
+	m->session = session;
+	camel_object_ref(session);
+	m->op = camel_operation_new(cs_thread_status, m);
+	camel_exception_init(&m->ex);
 	CAMEL_SESSION_LOCK(session, thread_lock);
 	m->id = session->priv->thread_id++;
 	g_hash_table_insert(session->priv->thread_active, GINT_TO_POINTER(m->id), m);
@@ -728,20 +734,29 @@ static void session_thread_msg_free(CamelSession *session, CamelSessionThreadMsg
 	
 	if (msg->ops->free)
 		msg->ops->free(session, msg);
+	if (msg->op)
+		camel_operation_unref(msg->op);
+	camel_exception_clear(&msg->ex);
+	camel_object_unref(msg->session);
 	g_free(msg);
 }
 
 static void session_thread_destroy(EThread *thread, CamelSessionThreadMsg *msg, CamelSession *session)
 {
 	d(printf("destroy message %p session %p\n", msg, session));
-	session_thread_msg_free(session, msg);
+	camel_session_thread_msg_free(session, msg);
 }
 
 static void session_thread_received(EThread *thread, CamelSessionThreadMsg *msg, CamelSession *session)
 {
 	d(printf("receive message %p session %p\n", msg, session));
-	if (msg->ops->receive)
+	if (msg->ops->receive) {
+		CamelOperation *oldop;
+
+		oldop = camel_operation_register(msg->op);
 		msg->ops->receive(session, msg);
+		camel_operation_register(oldop);
+	}
 }
 
 static int session_thread_queue(CamelSession *session, CamelSessionThreadMsg *msg, int flags)
@@ -777,6 +792,10 @@ static void session_thread_wait(CamelSession *session, int id)
 	} while (wait);
 }
 
+static void session_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc)
+{
+}
+
 /**
  * camel_session_thread_msg_new:
  * @session: 
@@ -852,4 +871,31 @@ void camel_session_thread_wait(CamelSession *session, int id)
 	CS_CLASS (session)->thread_wait(session, id);
 }
 
-#endif
+/**
+ * camel_session_check_junk:
+ * @session: 
+ * 
+ * Do we have to check incoming messages to be junk?
+ **/
+gboolean
+camel_session_check_junk (CamelSession *session)
+{
+	g_assert(CAMEL_IS_SESSION(session));
+
+	return session->check_junk;
+}
+
+/**
+ * camel_session_set_check_junk:
+ * @session: 
+ * @check_junk: 
+ * 
+ * Set check_junk flag, if set, incoming mail will be checked for being junk.
+ **/
+void
+camel_session_set_check_junk (CamelSession *session, gboolean check_junk)
+{
+	g_assert(CAMEL_IS_SESSION(session));
+
+	session->check_junk = check_junk;
+}
