@@ -35,6 +35,7 @@ extern "C" {
 
 #include <camel/camel-object.h>
 #include <camel/camel-provider.h>
+#include <camel/camel-junk-plugin.h>
 
 #include <e-util/e-msgport.h>
 
@@ -59,6 +60,9 @@ struct _CamelSession
 	char *storage_path;
 	GHashTable *providers, *modules;
 	gboolean online;
+
+	CamelJunkPlugin *junk_plugin;
+	gboolean check_junk;
 };
 
 #ifdef ENABLE_THREADS
@@ -110,6 +114,7 @@ typedef struct {
 	void (*thread_msg_free)(CamelSession *session, CamelSessionThreadMsg *msg);
 	int (*thread_queue)(CamelSession *session, CamelSessionThreadMsg *msg, int flags);
 	void (*thread_wait)(CamelSession *session, int id);
+	void (*thread_status)(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc);
 #endif
 	
 } CamelSessionClass;
@@ -175,6 +180,9 @@ CamelFilterDriver *camel_session_get_filter_driver  (CamelSession *session,
 						     const char *type,
 						     CamelException *ex);
 
+gboolean           camel_session_check_junk         (CamelSession *session);
+void               camel_session_set_check_junk     (CamelSession *session, gboolean check_junk);
+
 #ifdef ENABLE_THREADS
 struct _CamelSessionThreadOps {
 	void (*receive)(CamelSession *session, struct _CamelSessionThreadMsg *m);
@@ -184,8 +192,14 @@ struct _CamelSessionThreadOps {
 struct _CamelSessionThreadMsg {
 	EMsg msg;
 
-	CamelSessionThreadOps *ops;
 	int id;
+
+	CamelException ex;
+	CamelSessionThreadOps *ops;
+	struct _CamelOperation *op;
+	CamelSession *session;
+
+	void *data; /* free for implementation to define, not used by camel, do not use in client code */
 	/* user fields follow */
 };
 
@@ -193,6 +207,7 @@ void *camel_session_thread_msg_new(CamelSession *session, CamelSessionThreadOps
 void camel_session_thread_msg_free(CamelSession *session, CamelSessionThreadMsg *msg);
 int camel_session_thread_queue(CamelSession *session, CamelSessionThreadMsg *msg, int flags);
 void camel_session_thread_wait(CamelSession *session, int id);
+
 #endif
 
 #ifdef __cplusplus
