@@ -4,8 +4,10 @@
 /* 
  *
  * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
+ *          Michael Zucchi <NotZed@ximian.com>
+ *          Jeffrey Stedfast <fejj@ximian.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright 1999, 2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of version 2 of the GNU General Public 
@@ -30,7 +32,7 @@
 #ifdef __cplusplus
 extern "C" {
 #pragma }
-#endif /* __cplusplus }*/
+#endif /* __cplusplus */
 
 /* for mode_t */
 #include <sys/types.h>
@@ -81,6 +83,7 @@ typedef struct _CamelRenameInfo {
 #define CAMEL_STORE_SUBSCRIPTIONS	(1 << 0)
 #define CAMEL_STORE_VTRASH		(1 << 1)
 #define CAMEL_STORE_FILTER_INBOX	(1 << 2)
+#define CAMEL_STORE_VJUNK		(1 << 3)
 
 struct _CamelStore
 {
@@ -88,6 +91,7 @@ struct _CamelStore
 	struct _CamelStorePrivate *priv;
 	
 	CamelFolder *vtrash;
+	CamelFolder *vjunk;
 	
 	CamelObjectBag *folders;
 
@@ -125,6 +129,9 @@ typedef struct {
 	void            (*init_trash)               (CamelStore *store);
 	CamelFolder *   (*get_trash)                (CamelStore *store,
 						     CamelException *ex);
+	void            (*init_junk)                (CamelStore *store);
+	CamelFolder *   (*get_junk)                 (CamelStore *store,
+						     CamelException *ex);
 	
 	CamelFolderInfo *(*create_folder)           (CamelStore *store,
 						     const char *parent_name,
@@ -173,6 +180,8 @@ CamelFolder *    camel_store_get_inbox          (CamelStore *store,
 						 CamelException *ex);
 CamelFolder *    camel_store_get_trash          (CamelStore *store,
 						 CamelException *ex);
+CamelFolder *    camel_store_get_junk           (CamelStore *store,
+						 CamelException *ex);
 
 CamelFolderInfo *camel_store_create_folder      (CamelStore *store,
 						 const char *parent_name,
@@ -226,9 +235,6 @@ void             camel_store_noop                     (CamelStore *store,
 
 gboolean	 camel_store_uri_cmp		      (CamelStore *store, const char *uria, const char *urib);
 
-/* utility needed by some stores */
-int camel_mkdir_hier (const char *path, mode_t mode);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
