@@ -8,9 +8,8 @@
  * Copyright 2000 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of version 2 of the GNU General Public 
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,12 +30,18 @@ extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
-#include <stdio.h>
 #include <glib.h>
 
+#include <stdio.h>
+#include <sys/types.h>
+
 typedef struct {
-	int fd, level;
+	char *filename;
 	GHashTable *uids;
+	unsigned int level;
+	size_t expired;
+	size_t size;
+	int fd;
 } CamelUIDCache;
 
 CamelUIDCache *camel_uid_cache_new (const char *filename);
