@@ -1,7 +1,37 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ *  Authors: Michael Zucchi <notzed@ximian.com>
+ *
+ *  Copyright 2003 Ximian, Inc. (www.ximian.com)
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *
+ */
+
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <string.h>
 
 #include <glib.h>
 #include "camel-utf8.h"
 
+#include <netinet/in.h>
+
 /**
  * camel_utf8_putc:
  * @ptr: 
@@ -311,3 +341,60 @@ camel_utf8_utf7(const char *ptr)
 
 	return ret;
 }
+
+/**
+ * camel_utf8_ucs2:
+ * @ptr: 
+ * 
+ * Convert a utf8 string into a ucs2 one.  The ucs string will be in
+ * network byte order, and terminated with a 16 bit NULL.
+ * 
+ * Return value: 
+ **/
+char *
+camel_utf8_ucs2(const char *ptr)
+{
+	GByteArray *work = g_byte_array_new();
+	guint32 c;
+	char *out;
+
+	/* what if c is > 0xffff ? */
+
+	while ( (c = camel_utf8_getc((const unsigned char **)&ptr)) ) {
+		guint16 s = htons(c);
+
+		g_byte_array_append(work, (char *)&s, 2);
+	}
+
+	g_byte_array_append(work, "\000\000", 2);
+	out = g_malloc(work->len);
+	memcpy(out, work->data, work->len);
+	g_byte_array_free(work, TRUE);
+
+	return out;
+}
+
+/**
+ * camel_ucs2_utf8:
+ * @ptr: 
+ * 
+ * Convert a ucs2 string into a utf8 one.  The ucs2 string is treated
+ * as network byte ordered, and terminated with a 16 bit NUL.
+ * 
+ * Return value: 
+ **/
+char *camel_ucs2_utf8(const char *ptr)
+{
+	guint16 *ucs = (guint16 *)ptr;
+	guint32 c;
+	GString *work = g_string_new("");
+	char *out;
+
+	while ( (c = *ucs++) )
+		g_string_append_u(work, ntohs(c));
+
+	out = g_strdup(work->str);
+	g_string_free(work, TRUE);
+
+	return out;
+}
