@@ -24,10 +24,16 @@
 #ifndef _CAMEL_VTRASH_FOLDER_H
 #define _CAMEL_VTRASH_FOLDER_H
 
+#ifdef __cplusplus
+extern "C" {
+#pragma }
+#endif /* __cplusplus */
+
 #include <camel/camel-folder.h>
 #include <camel/camel-vee-folder.h>
 
 #define CAMEL_VTRASH_NAME "Trash"
+#define CAMEL_VJUNK_NAME "Junk"
 
 #define CAMEL_VTRASH_FOLDER(obj)         CAMEL_CHECK_CAST (obj, camel_vtrash_folder_get_type (), CamelVTrashFolder)
 #define CAMEL_VTRASH_FOLDER_CLASS(klass) CAMEL_CHECK_CLASS_CAST (klass, camel_vtrash_folder_get_type (), CamelVTrashFolderClass)
@@ -50,4 +56,8 @@ CamelType       camel_vtrash_folder_get_type    (void);
 
 CamelFolder    *camel_vtrash_folder_new		(CamelStore *parent_store, const char *name);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* ! _CAMEL_VTRASH_FOLDER_H */
