@@ -42,11 +42,9 @@ enum {
 
 struct _CamelLocalSummary {
 	CamelFolderSummary parent;
-
-	struct _CamelLocalSummaryPrivate *priv;
-
+	
 	char *folder_path;	/* name of matching folder */
-
+	
 	CamelIndex *index;
 	unsigned int index_force:1; /* do we force index during creation? */
 	unsigned int check_force:1; /* does a check force a full check? */
@@ -84,7 +82,7 @@ char *camel_local_summary_encode_x_evolution(CamelLocalSummary *cls, const Camel
 int camel_local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev, CamelMessageInfo *info);
 
 /* utility functions - write headers to a file with optional X-Evolution header and/or status header */
-int camel_local_summary_write_headers(int fd, struct _header_raw *header, const char *xevline, const char *status, const char *xstatus);
+int camel_local_summary_write_headers(int fd, struct _camel_header_raw *header, const char *xevline, const char *status, const char *xstatus);
 
 #endif /* ! _CAMEL_LOCAL_SUMMARY_H */
 
