@@ -2,7 +2,7 @@
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
- * Copyright (C) 1999, 2000 Ximian Inc.
+ * Copyright (C) 1999, 2003 Ximian Inc.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of version 2 of the GNU General Public 
@@ -34,7 +34,6 @@
 
 #include "camel-maildir-folder.h"
 #include "camel-maildir-store.h"
-#include "string-utils.h"
 #include "camel-stream-fs.h"
 #include "camel-maildir-summary.h"
 #include "camel-data-wrapper.h"
@@ -221,8 +220,9 @@ static CamelMimeMessage *maildir_get_message(CamelFolder * folder, const gchar *
 	camel_folder_summary_info_free(folder->summary, info);
 
 	if ((message_stream = camel_stream_fs_new_with_name(name, O_RDONLY, 0)) == NULL) {
-		camel_exception_setv(ex, CAMEL_EXCEPTION_FOLDER_INVALID_UID, _("Cannot get message: %s\n  %s"),
-				     name, g_strerror(errno));
+		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID_UID,
+				      _("Cannot get message: %s\n  %s"),
+				      name, g_strerror (errno));
 		g_free(name);
 		return NULL;
 	}
