@@ -161,20 +161,30 @@ connect_to_server (CamelService *service, int ssl_mode, int try_starttls, CamelE
 	
 	port = service->url->port ? service->url->port : 110;
 	
+	if (ssl_mode != USE_SSL_NEVER) {
 #ifdef HAVE_SSL
-	if (camel_url_get_param (service->url, "use_ssl")) {
 		if (try_starttls) {
-			tcp_stream = camel_tcp_stream_ssl_new_raw (service, service->url->host, STARTTLS_FLAGS);
+			tcp_stream = camel_tcp_stream_ssl_new_raw (service->session, service->url->host, STARTTLS_FLAGS);
 		} else {
 			port = service->url->port ? service->url->port : 995;
-			tcp_stream = camel_tcp_stream_ssl_new (service, service->url->host, SSL_PORT_FLAGS);
+			tcp_stream = camel_tcp_stream_ssl_new (service->session, service->url->host, SSL_PORT_FLAGS);
 		}
+#else
+		if (!try_starttls)
+			port = service->url->port ? service->url->port : 995;
+		
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
+				      _("Could not connect to %s (port %d): %s"),
+				      service->url->host, port,
+				      _("SSL unavailable"));
+		
+		camel_free_host (h);
+		
+		return FALSE;
+#endif /* HAVE_SSL */
 	} else {
 		tcp_stream = camel_tcp_stream_raw_new ();
 	}
-#else
-	tcp_stream = camel_tcp_stream_raw_new ();
-#endif /* HAVE_SSL */
 	
 	ret = camel_tcp_stream_connect (CAMEL_TCP_STREAM (tcp_stream), h, port);
 	camel_free_host (h);
@@ -530,7 +540,7 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 				      _("Unable to connect to POP server %s.\n"
 					"Error sending password: %s"),
 				      CAMEL_SERVICE (store)->url->host,
-				      store->engine->line ? store->engine->line : _("Unknown error"));
+				      store->engine->line ? (char *)store->engine->line : _("Unknown error"));
 	
 	camel_pop3_engine_command_free(store->engine, pcp);
 	
