@@ -44,12 +44,12 @@
 
 #include <gal/util/e-iconv.h>
 
-#include "camel/camel-data-wrapper.h"
-#include "camel/camel-stream-fs.h"
-#include "camel/camel-stream-null.h"
-#include "camel/camel-stream-filter.h"
-#include "camel/camel-mime-filter-bestenc.h"
-#include "camel/camel-mime-part.h"
+#include <camel/camel-data-wrapper.h>
+#include <camel/camel-stream-fs.h>
+#include <camel/camel-stream-null.h>
+#include <camel/camel-stream-filter.h>
+#include <camel/camel-mime-filter-bestenc.h>
+#include <camel/camel-mime-part.h>
 
 #include "e-util/e-gui-utils.h"
 
@@ -238,46 +238,27 @@ update (EMsgComposerAttachmentBar *bar)
 		content_type = camel_mime_part_get_content_type (attachment->body);
 		/* Get the image out of the attachment 
 		   and create a thumbnail for it */
-		image = header_content_type_is (content_type, "image", "*");
+		image = camel_content_type_is (content_type, "image", "*");
 		
 		if (image && attachment->pixbuf_cache == NULL) {
 			CamelDataWrapper *wrapper;
-			CamelStream *mstream;
+			CamelStreamMem *mstream;
 			GdkPixbufLoader *loader;
 			gboolean error = TRUE;
-			char tmp[4096];
-			int t;
 			
 			wrapper = camel_medium_get_content_object (CAMEL_MEDIUM (attachment->body));
-			mstream = camel_stream_mem_new ();
+			mstream = (CamelStreamMem *) camel_stream_mem_new ();
 			
-			camel_data_wrapper_write_to_stream (wrapper, mstream);
-			
-			camel_stream_reset (mstream);
+			camel_data_wrapper_decode_to_stream (wrapper, (CamelStream *) mstream);
 			
 			/* Stream image into pixbuf loader */
 			loader = gdk_pixbuf_loader_new ();
-			do {
-				t = camel_stream_read (mstream, tmp, 4096);
-				if (t > 0) {
-					error = !gdk_pixbuf_loader_write (loader, tmp, t, NULL);
-					if (error) {
-						break;
-					}
-				} else {
-					if (camel_stream_eos (mstream))
-						break;
-					error = TRUE;
-					break;
-				}
-				
-			} while (!camel_stream_eos (mstream));
+			error = !gdk_pixbuf_loader_write (loader, mstream->buffer->data, mstream->buffer->len, NULL);
+			gdk_pixbuf_loader_close (loader, NULL);
 			
 			if (!error) {
 				int ratio, width, height;
-
-				gdk_pixbuf_loader_close (loader, NULL);
-
+				
 				/* Shrink pixbuf */
 				pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 				width = gdk_pixbuf_get_width (pixbuf);
@@ -307,9 +288,8 @@ update (EMsgComposerAttachmentBar *bar)
 			}
 			
 			/* Destroy everything */
-			gdk_pixbuf_loader_close (loader, NULL);
 			g_object_unref (loader);
-			camel_stream_close (mstream);
+			camel_object_unref (mstream);
 		}
 		
 		desc = camel_mime_part_get_description (attachment->body);
@@ -331,7 +311,7 @@ update (EMsgComposerAttachmentBar *bar)
 		} else {
 			char *mime_type;
 			
-			mime_type = header_content_type_simple (content_type);
+			mime_type = camel_content_type_simple (content_type);
 			pixbuf = e_icon_for_mime_type (mime_type, 48);
 			g_free (mime_type);
 			gnome_icon_list_append_pixbuf (icon_list, pixbuf, NULL, label);
@@ -543,13 +523,14 @@ destroy (GtkObject *object)
 
 /* GtkWidget methods.  */
 
+
 static void
 popup_menu_placement_callback (GtkMenu *menu, int *x, int *y, gboolean *push_in, gpointer user_data)
 {
 	EMsgComposerAttachmentBar *bar;
 	GnomeIconList *icon_list;
-	GnomeCanvasPixbuf *image;
 	GList *selection;
+	GnomeCanvasPixbuf *image;
 	
 	bar = E_MSG_COMPOSER_ATTACHMENT_BAR (user_data);
 	icon_list = GNOME_ICON_LIST (user_data);
@@ -567,7 +548,6 @@ popup_menu_placement_callback (GtkMenu *menu, int *x, int *y, gboolean *push_in,
 	/* Put menu to the center of icon. */
 	*x += (int)(image->item.x1 + image->item.x2) / 2;
 	*y += (int)(image->item.y1 + image->item.y2) / 2;
-
 }
 
 static gboolean 
@@ -589,7 +569,8 @@ popup_menu_event (GtkWidget *widget)
 	return TRUE;
 }
 
-static gint
+
+static int
 button_press_event (GtkWidget *widget,
 		    GdkEventButton *event)
 {
@@ -763,36 +744,29 @@ attach_to_multipart (CamelMultipart *multipart,
 	content = camel_medium_get_content_object (CAMEL_MEDIUM (attachment->body));
 	
 	if (!CAMEL_IS_MULTIPART (content)) {
-		if (header_content_type_is (content_type, "text", "*")) {
-			CamelMimePartEncodingType encoding;
-			CamelStreamFilter *filtered_stream;
+		if (camel_content_type_is (content_type, "text", "*")) {
+			CamelTransferEncoding encoding;
+			CamelStreamFilter *filter_stream;
 			CamelMimeFilterBestenc *bestenc;
 			CamelStream *stream;
 			const char *charset;
 			char *type;
 			
-			/* assume that if a charset is set, that the content is in UTF-8
-			 * or else already has rawtext set to TRUE */
-			if (!(charset = header_content_type_param (content_type, "charset"))) {
-				/* Let camel know that this text part was read in raw and thus is not in
-				 * UTF-8 format so that when it writes this part out, it doesn't try to
-				 * convert it from UTF-8 into the @default_charset charset. */
-				content->rawtext = TRUE;
-			}
+			charset = camel_content_type_param (content_type, "charset");
 			
 			stream = camel_stream_null_new ();
-			filtered_stream = camel_stream_filter_new_with_stream (stream);
+			filter_stream = camel_stream_filter_new_with_stream (stream);
 			bestenc = camel_mime_filter_bestenc_new (CAMEL_BESTENC_GET_ENCODING);
-			camel_stream_filter_add (filtered_stream, CAMEL_MIME_FILTER (bestenc));
-			camel_object_unref (CAMEL_OBJECT (stream));
+			camel_stream_filter_add (filter_stream, CAMEL_MIME_FILTER (bestenc));
+			camel_object_unref (stream);
 			
-			camel_data_wrapper_write_to_stream (content, CAMEL_STREAM (filtered_stream));
-			camel_object_unref (CAMEL_OBJECT (filtered_stream));
+			camel_data_wrapper_decode_to_stream (content, CAMEL_STREAM (filter_stream));
+			camel_object_unref (filter_stream);
 			
 			encoding = camel_mime_filter_bestenc_get_best_encoding (bestenc, CAMEL_BESTENC_8BIT);
 			camel_mime_part_set_encoding (attachment->body, encoding);
 			
-			if (encoding == CAMEL_MIME_PART_ENCODING_7BIT) {
+			if (encoding == CAMEL_TRANSFER_ENCODING_7BIT) {
 				/* the text fits within us-ascii so this is safe */
 				/* FIXME: check that this isn't iso-2022-jp? */
 				default_charset = "us-ascii";
@@ -807,16 +781,15 @@ attach_to_multipart (CamelMultipart *multipart,
 			
 			if (!charset) {
 				/* looks kinda nasty, but this is how ya have to do it */
-				header_content_type_set_param (content_type, "charset", default_charset);
-				type = header_content_type_format (content_type);
+				camel_content_type_set_param (content_type, "charset", default_charset);
+				type = camel_content_type_format (content_type);
 				camel_mime_part_set_content_type (attachment->body, type);
 				g_free (type);
 			}
 			
-			camel_object_unref (CAMEL_OBJECT (bestenc));
+			camel_object_unref (bestenc);
 		} else if (!CAMEL_IS_MIME_MESSAGE (content)) {
-			camel_mime_part_set_encoding (attachment->body,
-						      CAMEL_MIME_PART_ENCODING_BASE64);
+			camel_mime_part_set_encoding (attachment->body, CAMEL_TRANSFER_ENCODING_BASE64);
 		}
 	}
 	
