@@ -29,9 +29,9 @@
 
 #include <bonobo/bonobo-ui-component.h>
 
+#include <e-util/e-account.h>
 #include <camel/camel-mime-message.h>
-#include <addressbook/backend/ebook/e-destination.h>
-#include <mail/mail-config.h>
+#include <addressbook/util/eab-destination.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -39,13 +39,13 @@ extern "C" {
 #endif /* __cplusplus */
 
 #define E_TYPE_MSG_COMPOSER_HDRS		(e_msg_composer_hdrs_get_type ())
-#define E_MSG_COMPOSER_HDRS(obj)		(GTK_CHECK_CAST ((obj), E_TYPE_MSG_COMPOSER_HDRS, EMsgComposerHdrs))
-#define E_MSG_COMPOSER_HDRS_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), E_TYPE_MSG_COMPOSER_HDRS, EMsgComposerHdrsClass))
-#define E_IS_MSG_COMPOSER_HDRS(obj)		(GTK_CHECK_TYPE ((obj), E_TYPE_MSG_COMPOSER_HDRS))
-#define E_IS_MSG_COMPOSER_HDRS_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((obj), E_TYPE_MSG_COMPOSER_HDRS))
+#define E_MSG_COMPOSER_HDRS(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_MSG_COMPOSER_HDRS, EMsgComposerHdrs))
+#define E_MSG_COMPOSER_HDRS_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), E_TYPE_MSG_COMPOSER_HDRS, EMsgComposerHdrsClass))
+#define E_IS_MSG_COMPOSER_HDRS(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_MSG_COMPOSER_HDRS))
+#define E_IS_MSG_COMPOSER_HDRS_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), E_TYPE_MSG_COMPOSER_HDRS))
 
 
-#define SELECT_NAMES_OAFIID "OAFIID:GNOME_Evolution_Addressbook_SelectNames"
+#define SELECT_NAMES_OAFIID "OAFIID:GNOME_Evolution_Addressbook_SelectNames:" BASE_VERSION
 
 typedef struct _EMsgComposerHdrs        EMsgComposerHdrs;
 typedef struct _EMsgComposerHdrsClass   EMsgComposerHdrsClass;
@@ -53,10 +53,10 @@ typedef struct _EMsgComposerHdrsPrivate EMsgComposerHdrsPrivate;
 
 struct _EMsgComposerHdrs {
 	GtkTable parent;
-
+	
 	EMsgComposerHdrsPrivate *priv;
 	
-	const MailConfigAccount *account;
+	EAccount *account;
 	
 	guint32 visible_mask;
 	
@@ -110,11 +110,11 @@ void        e_msg_composer_hdrs_set_from_account   (EMsgComposerHdrs *hdrs,
 void        e_msg_composer_hdrs_set_reply_to       (EMsgComposerHdrs *hdrs,
 						    const char *reply_to);
 void        e_msg_composer_hdrs_set_to             (EMsgComposerHdrs *hdrs,
-						    EDestination    **to_destv);
+						    EABDestination    **to_destv);
 void        e_msg_composer_hdrs_set_cc             (EMsgComposerHdrs *hdrs,
-						    EDestination    **cc_destv);
+						    EABDestination    **cc_destv);
 void        e_msg_composer_hdrs_set_bcc            (EMsgComposerHdrs *hdrs,
-						    EDestination    **bcc_destv);
+						    EABDestination    **bcc_destv);
 void        e_msg_composer_hdrs_set_post_to        (EMsgComposerHdrs *hdrs,
 						    const char       *post_to);
 void        e_msg_composer_hdrs_set_subject        (EMsgComposerHdrs *hdrs,
@@ -123,12 +123,12 @@ void        e_msg_composer_hdrs_set_subject        (EMsgComposerHdrs *hdrs,
 CamelInternetAddress *e_msg_composer_hdrs_get_from (EMsgComposerHdrs *hdrs);
 CamelInternetAddress *e_msg_composer_hdrs_get_reply_to (EMsgComposerHdrs *hdrs);
 
-EDestination **e_msg_composer_hdrs_get_to          (EMsgComposerHdrs *hdrs);
-EDestination **e_msg_composer_hdrs_get_cc          (EMsgComposerHdrs *hdrs);
-EDestination **e_msg_composer_hdrs_get_bcc         (EMsgComposerHdrs *hdrs);
-EDestination **e_msg_composer_hdrs_get_recipients  (EMsgComposerHdrs *hdrs);
+EABDestination **e_msg_composer_hdrs_get_to         (EMsgComposerHdrs *hdrs);
+EABDestination **e_msg_composer_hdrs_get_cc         (EMsgComposerHdrs *hdrs);
+EABDestination **e_msg_composer_hdrs_get_bcc        (EMsgComposerHdrs *hdrs);
+EABDestination **e_msg_composer_hdrs_get_recipients (EMsgComposerHdrs *hdrs);
 char          *e_msg_composer_hdrs_get_post_to     (EMsgComposerHdrs *hdrs);
-char          *e_msg_composer_hdrs_get_subject     (EMsgComposerHdrs *hdrs);
+const char    *e_msg_composer_hdrs_get_subject     (EMsgComposerHdrs *hdrs);
 
 GtkWidget  *e_msg_composer_hdrs_get_from_hbox      (EMsgComposerHdrs *hdrs);
 GtkWidget  *e_msg_composer_hdrs_get_from_omenu     (EMsgComposerHdrs *hdrs);
