@@ -50,10 +50,6 @@ CamelFolder *mail_tool_get_trash (const char *url, int connect, CamelException *
  * and returns the path to the new movemail folder that was created. which shoudl be freed later */
 char *mail_tool_do_movemail (const char *source_url, CamelException *ex);
 
-/* Transfers all the messages from source into dest;
- * source is emptied and synced. */
-void mail_tool_move_folder_contents (CamelFolder *source, CamelFolder *dest, gboolean use_cache, CamelException *ex);
-
 XEvolution *mail_tool_remove_xevolution_headers (CamelMimeMessage *message);
 void mail_tool_restore_xevolution_headers (CamelMimeMessage *message, XEvolution *xev);
 void mail_tool_destroy_xevolution (XEvolution *xev);
@@ -69,10 +65,6 @@ CamelFolder *mail_tool_uri_to_folder (const char *uri, guint32 flags, CamelExcep
 
 GHashTable *mail_lookup_url_table (CamelMimeMessage *mime_message);
 
-gchar *mail_tool_quote_message (CamelMimeMessage *message, const char *fmt, ...);
-
-gchar *mail_tool_forward_message (CamelMimeMessage *message, gboolean quoted);
-
 CamelFolder *mail_tools_x_evolution_message_parse (char *in, unsigned int inlen, GPtrArray **uids);
 
 char *mail_tools_folder_to_url (CamelFolder *folder);
