@@ -149,7 +149,7 @@ get_tag_list (MessageTagEditor *editor)
 	
 	date = e_date_edit_get_time (followup->target_date);
 	if (date != (time_t) -1) {
-		text = header_format_date (date, 0);
+		text = camel_header_format_date (date, 0);
 		camel_tag_set (&tags, "due-by", text);
 		g_free (text);
 	} else {
@@ -157,7 +157,7 @@ get_tag_list (MessageTagEditor *editor)
 	}
 	
 	if (gtk_toggle_button_get_active (followup->completed)) {
-		text = header_format_date (followup->completed_date, 0);
+		text = camel_header_format_date (followup->completed_date, 0);
 		camel_tag_set (&tags, "completed-on", text);
 		g_free (text);
 	} else {
@@ -180,7 +180,7 @@ set_tag_list (MessageTagEditor *editor, CamelTag *tags)
 	
 	text = camel_tag_get (&tags, "due-by");
 	if (text && *text) {
-		date = header_decode_date (text, NULL);
+		date = camel_header_decode_date (text, NULL);
 		e_date_edit_set_time (followup->target_date, date);
 	} else {
 		e_date_edit_set_time (followup->target_date, (time_t) -1);
@@ -188,7 +188,7 @@ set_tag_list (MessageTagEditor *editor, CamelTag *tags)
 	
 	text = camel_tag_get (&tags, "completed-on");
 	if (text && *text) {
-		date = header_decode_date (text, NULL);
+		date = camel_header_decode_date (text, NULL);
 		if (date != (time_t) 0) {
 			gtk_toggle_button_set_active (followup->completed, TRUE);
 			followup->completed_date = date;
@@ -221,10 +221,9 @@ completed_toggled (GtkToggleButton *button, gpointer user_data)
 static int
 get_week_start_day (void)
 {
-	/* FIXME: make sure the gconf key is correct? */
 	GConfClient *gconf;
 	
-	gconf = gconf_client_get_default ();
+	gconf = mail_config_get_gconf_client ();
 	return gconf_client_get_int (gconf, "/apps/evolution/calendar/display/week_start_day", NULL);
 }
 
@@ -255,9 +254,8 @@ target_date_new (const char *s1, const char *s2, int i1, int i2)
 	/* Note that this is 0 (Sun) to 6 (Sat), conver to 0 (mon) to 6 (sun) */
 	start = (get_week_start_day () + 6) % 7;
 	
-	/* FIXME: make sure the calendar gconf key is correct */
 	if (locale_supports_12_hour_format ()) {
-		gconf = gconf_client_get_default ();
+		gconf = mail_config_get_gconf_client ();
 		time_24hour = gconf_client_get_bool (gconf, "/apps/evolution/calendar/display/use_24hour_format", NULL);
 	}
 	
