@@ -7,9 +7,8 @@
  * Copyright 2001, Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,19 +26,27 @@
  * window to edit it.
  */
 
+
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include "e-cell-date-edit.h"
 
 #include <string.h>
 #include <time.h>
 #include <glib.h>
+
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+
 #include <gal/util/e-util.h>
 #include <gal/e-table/e-table-item.h>
+#include <gal/e-table/e-cell-text.h>
+
 #include <libgnomeui/gnome-messagebox.h>
-#include <libgnomeui/gnome-stock.h>
 #include <libgnome/gnome-i18n.h>
+
 #include "e-util/e-time-utils.h"
 /* This depends on ECalendar which is why I didn't put it in gal. */
 #include "e-calendar.h"
@@ -55,12 +62,18 @@ static void e_cell_date_edit_set_arg		(GtkObject	*o,
 						 guint		 arg_id);
 
 static gint e_cell_date_edit_do_popup		(ECellPopup	*ecp,
-						 GdkEvent	*event);
+						 GdkEvent	*event,
+						 int             row,
+						 int             view_col);
 static void e_cell_date_edit_set_popup_values	(ECellDateEdit	*ecde);
 static void e_cell_date_edit_select_matching_time(ECellDateEdit	*ecde,
 						  char		*time);
-static void e_cell_date_edit_show_popup		(ECellDateEdit	*ecde);
+static void e_cell_date_edit_show_popup		(ECellDateEdit	*ecde,
+						 int             row,
+						 int             view_col);
 static void e_cell_date_edit_get_popup_pos	(ECellDateEdit	*ecde,
+						 int             row,
+						 int             view_col,
 						 gint		*x,
 						 gint		*y,
 						 gint		*height,
@@ -71,6 +84,9 @@ static void e_cell_date_edit_rebuild_time_list	(ECellDateEdit	*ecde);
 static int e_cell_date_edit_key_press		(GtkWidget	*popup_window,
 						 GdkEventKey	*event,
 						 ECellDateEdit	*ecde);
+static int  e_cell_date_edit_button_press	(GtkWidget	*popup_window,
+						 GdkEventButton	*event,
+						 ECellDateEdit	*ecde);
 static void e_cell_date_edit_on_ok_clicked	(GtkWidget	*button,
 						 ECellDateEdit	*ecde);
 static void e_cell_date_edit_show_time_invalid_warning	(ECellDateEdit	*ecde);
@@ -86,6 +102,7 @@ static void e_cell_date_edit_on_time_selected	(GtkList	*list,
 						 ECellDateEdit	*ecde);
 static void e_cell_date_edit_hide_popup		(ECellDateEdit	*ecde);
 
+
 /* Our arguments. */
 enum {
 	ARG_0,
@@ -139,7 +156,7 @@ e_cell_date_edit_class_init		(GtkObjectClass	*object_class)
 
 	ecpc->popup = e_cell_date_edit_do_popup;
 
-	parent_class = gtk_type_class (e_cell_popup_get_type ());
+	parent_class = g_type_class_ref(e_cell_popup_get_type ());
 }
 
 
@@ -191,7 +208,7 @@ e_cell_date_edit_init			(ECellDateEdit	*ecde)
         gtk_widget_show (vbox2);
 
 	ecde->time_entry = gtk_entry_new ();
-	gtk_widget_set_usize (ecde->time_entry, 50, -1);
+	gtk_widget_set_size_request (ecde->time_entry, 50, -1);
 	gtk_box_pack_start (GTK_BOX (vbox2), ecde->time_entry,
 			    FALSE, FALSE, 0);
 	gtk_widget_show (ecde->time_entry);
@@ -209,8 +226,8 @@ e_cell_date_edit_init			(ECellDateEdit	*ecde)
 					     gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (scrolled_window)));
 	gtk_widget_show (list);
 	ecde->time_list = list;
-	gtk_signal_connect (GTK_OBJECT (list), "selection-changed",
-			    GTK_SIGNAL_FUNC (e_cell_date_edit_on_time_selected),
+	g_signal_connect((list), "selection-changed",
+			    G_CALLBACK (e_cell_date_edit_on_time_selected),
 			    ecde);
 
 	bbox = gtk_hbutton_box_new ();
@@ -224,38 +241,42 @@ e_cell_date_edit_init			(ECellDateEdit	*ecde)
 	now_button = gtk_button_new_with_label (_("Now"));
 	gtk_container_add (GTK_CONTAINER (bbox), now_button);
         gtk_widget_show (now_button);
-	gtk_signal_connect (GTK_OBJECT (now_button), "clicked",
-			    GTK_SIGNAL_FUNC (e_cell_date_edit_on_now_clicked),
+	g_signal_connect((now_button), "clicked",
+			    G_CALLBACK (e_cell_date_edit_on_now_clicked),
 			    ecde);
 	ecde->now_button = now_button;
 
 	today_button = gtk_button_new_with_label (_("Today"));
 	gtk_container_add (GTK_CONTAINER (bbox), today_button);
         gtk_widget_show (today_button);
-	gtk_signal_connect (GTK_OBJECT (today_button), "clicked",
-			    GTK_SIGNAL_FUNC (e_cell_date_edit_on_today_clicked),
+	g_signal_connect((today_button), "clicked",
+			    G_CALLBACK (e_cell_date_edit_on_today_clicked),
 			    ecde);
 	ecde->today_button = today_button;
 
 	none_button = gtk_button_new_with_label (_("None"));
 	gtk_container_add (GTK_CONTAINER (bbox), none_button);
         gtk_widget_show (none_button);
-	gtk_signal_connect (GTK_OBJECT (none_button), "clicked",
-			    GTK_SIGNAL_FUNC (e_cell_date_edit_on_none_clicked),
+	g_signal_connect((none_button), "clicked",
+			    G_CALLBACK (e_cell_date_edit_on_none_clicked),
 			    ecde);
 	ecde->none_button = none_button;
 
 	ok_button = gtk_button_new_with_label (_("OK"));
 	gtk_container_add (GTK_CONTAINER (bbox), ok_button);
         gtk_widget_show (ok_button);
-	gtk_signal_connect (GTK_OBJECT (ok_button), "clicked",
-			    GTK_SIGNAL_FUNC (e_cell_date_edit_on_ok_clicked),
+	g_signal_connect((ok_button), "clicked",
+			    G_CALLBACK (e_cell_date_edit_on_ok_clicked),
 			    ecde);
 
 
-	gtk_signal_connect (GTK_OBJECT (ecde->popup_window),
+	g_signal_connect((ecde->popup_window),
 			    "key_press_event",
-			    GTK_SIGNAL_FUNC (e_cell_date_edit_key_press),
+			    G_CALLBACK (e_cell_date_edit_key_press),
+			    ecde);
+	g_signal_connect((ecde->popup_window),
+			    "button_press_event",
+			    G_CALLBACK (e_cell_date_edit_button_press),
 			    ecde);
 }
 
@@ -413,12 +434,14 @@ e_cell_date_edit_set_arg		(GtkObject	*o,
 
 static gint
 e_cell_date_edit_do_popup		(ECellPopup	*ecp,
-					 GdkEvent	*event)
+					 GdkEvent	*event,
+					 int             row,
+					 int             view_col)
 {
 	ECellDateEdit *ecde = E_CELL_DATE_EDIT (ecp);
 	guint32 time;
 
-	e_cell_date_edit_show_popup (ecde);
+	e_cell_date_edit_show_popup (ecde, row, view_col);
 	e_cell_date_edit_set_popup_values (ecde);
 
 	if (event->type == GDK_BUTTON_PRESS) {
@@ -427,8 +450,12 @@ e_cell_date_edit_do_popup		(ECellPopup	*ecp,
 		time = event->key.time;
 	}
 
+	gdk_keyboard_grab (ecde->popup_window->window, TRUE, time);
 	gtk_grab_add (ecde->popup_window);
 
+	/* Set the focus to the first widget. */
+	gtk_widget_grab_focus (ecde->time_entry);
+
 	return TRUE;
 }
 
@@ -437,6 +464,7 @@ static void
 e_cell_date_edit_set_popup_values	(ECellDateEdit	*ecde)
 {
 	ECellPopup *ecp = E_CELL_POPUP (ecde);
+	ECellText *ecell_text = E_CELL_TEXT (ecp->child);
 	ECellView *ecv = (ECellView*) ecp->popup_cell_view;
 	ETableItem *eti = E_TABLE_ITEM (ecp->popup_cell_view->cell_view.e_table_item_view);
 	ETableCol *ecol;
@@ -446,12 +474,19 @@ e_cell_date_edit_set_popup_values	(ECellDateEdit	*ecde)
 	GDate date;
 	ECalendarItem *calitem;
 	char buffer[64];
+	gboolean is_date = TRUE;
 
 	ecol = e_table_header_get_column (eti->header, ecp->popup_view_col);
-	cell_text = e_table_model_value_at (ecv->e_table_model,
-					    ecol->col_idx, ecp->popup_row);
+	cell_text = e_cell_text_get_text (ecell_text, ecv->e_table_model,
+					  ecol->col_idx, ecp->popup_row);
 
-	status = e_time_parse_date_and_time (cell_text, &date_tm);
+	/* Try to parse just a date first. If the value is only a date, we
+	   use a DATE value. */
+	status = e_time_parse_date (cell_text, &date_tm);
+	if (status == E_TIME_PARSE_INVALID) {
+		is_date = FALSE;
+		status = e_time_parse_date_and_time (cell_text, &date_tm);
+	}
 
 	/* If there is no date and time set, or the date is invalid, we clear
 	   the selections, else we select the appropriate date & time. */
@@ -461,8 +496,12 @@ e_cell_date_edit_set_popup_values	(ECellDateEdit	*ecde)
 		e_calendar_item_set_selection (calitem, NULL, NULL);
 		gtk_list_unselect_all (GTK_LIST (ecde->time_list));
 	} else {
-		e_time_format_time (&date_tm, ecde->use_24_hour_format, FALSE,
-				    buffer, sizeof (buffer));
+		if (is_date) {
+			buffer[0] = '\0';
+		} else {
+			e_time_format_time (&date_tm, ecde->use_24_hour_format,
+					    FALSE, buffer, sizeof (buffer));
+		}
 		gtk_entry_set_text (GTK_ENTRY (ecde->time_entry), buffer);
 
 		g_date_clear (&date, 1);
@@ -470,8 +509,14 @@ e_cell_date_edit_set_popup_values	(ECellDateEdit	*ecde)
 				date_tm.tm_year + 1900);
 		e_calendar_item_set_selection (calitem, &date, &date);
 
-		e_cell_date_edit_select_matching_time (ecde, buffer);
+		if (is_date) {
+			gtk_list_unselect_all (GTK_LIST (ecde->time_list));
+		} else {
+			e_cell_date_edit_select_matching_time (ecde, buffer);
+		}
 	}
+
+	e_cell_text_free_text (ecell_text, cell_text);
 }
 
 
@@ -507,7 +552,9 @@ e_cell_date_edit_select_matching_time	(ECellDateEdit	*ecde,
 
 
 static void
-e_cell_date_edit_show_popup		(ECellDateEdit	*ecde)
+e_cell_date_edit_show_popup		(ECellDateEdit	*ecde,
+					 int             row,
+					 int             view_col)
 {
 	gint x, y, width, height, old_width, old_height;
 
@@ -518,24 +565,23 @@ e_cell_date_edit_show_popup		(ECellDateEdit	*ecde)
 	old_width = ecde->popup_window->allocation.width;
 	old_height  = ecde->popup_window->allocation.height;
 
-	e_cell_date_edit_get_popup_pos (ecde, &x, &y, &height, &width);
+	e_cell_date_edit_get_popup_pos (ecde, row, view_col, &x, &y, &height, &width);
 
 	gtk_widget_set_uposition (ecde->popup_window, x, y);
-	gtk_widget_set_usize (ecde->popup_window, width, height);
+	gtk_widget_set_size_request (ecde->popup_window, width, height);
 	gtk_widget_realize (ecde->popup_window);
 	gdk_window_resize (ecde->popup_window->window, width, height);
 	gtk_widget_show (ecde->popup_window);
 
-	/* Set the focus to the first widget. */
-	gtk_widget_grab_focus (ecde->time_entry);
-
-	E_CELL_POPUP (ecde)->popup_shown = TRUE;
+	e_cell_popup_set_shown (E_CELL_POPUP (ecde), TRUE);
 }
 
 
 /* Calculates the size and position of the popup window (like GtkCombo). */
 static void
 e_cell_date_edit_get_popup_pos		(ECellDateEdit	*ecde,
+					 int             row,
+					 int             view_col,
 					 gint		*x,
 					 gint		*y,
 					 gint		*height,
@@ -546,22 +592,28 @@ e_cell_date_edit_get_popup_pos		(ECellDateEdit	*ecde,
 	GtkWidget *canvas = GTK_WIDGET (GNOME_CANVAS_ITEM (eti)->canvas);
 	GtkRequisition popup_requisition;
 	gint avail_height, screen_width, column_width, row_height;
-	double x1, y1;
+	double x1, y1, wx, wy;
   
 	gdk_window_get_origin (canvas->window, x, y);
 
-	x1 = e_table_header_col_diff (eti->header, 0, eti->editing_col + 1);
-	y1 = e_table_item_row_diff (eti, 0, eti->editing_row + 1);
-	column_width = e_table_header_col_diff (eti->header, eti->editing_col,
-						eti->editing_col + 1);
-	row_height = e_table_item_row_diff (eti, eti->editing_row,
-					    eti->editing_row + 1);
+	x1 = e_table_header_col_diff (eti->header, 0, view_col + 1);
+	y1 = e_table_item_row_diff (eti, 0, row + 1);
+	column_width = e_table_header_col_diff (eti->header, view_col,
+						view_col + 1);
+	row_height = e_table_item_row_diff (eti, row,
+					    row + 1);
 	gnome_canvas_item_i2w (GNOME_CANVAS_ITEM (eti), &x1, &y1);
 
-	*x += x1;
+	gnome_canvas_world_to_window (GNOME_CANVAS (canvas),
+				      x1,
+				      y1,
+				      &wx,
+				      &wy);
+
+	*x += wx;
 	/* The ETable positions don't include the grid lines, I think, so we
 	   add 1. */
-	*y += y1 + 1;
+	*y += wy + 1;
 
 	avail_height = gdk_screen_height () - *y;
 
@@ -611,8 +663,6 @@ e_cell_date_edit_key_press		(GtkWidget	*popup_window,
 					 GdkEventKey	*event,
 					 ECellDateEdit	*ecde)
 {
-	g_print ("In e_cell_date_edit_key_press\n");
-
 	/* If the Escape key is pressed we hide the popup. */
 	if (event->keyval != GDK_Escape)
 		return FALSE;
@@ -623,6 +673,25 @@ e_cell_date_edit_key_press		(GtkWidget	*popup_window,
 }
 
 
+/* This handles button press events in the popup window. If the button is
+   pressed outside the popup, we hide it and do not change the cell contents.
+*/
+static int
+e_cell_date_edit_button_press		(GtkWidget	*popup_window,
+					 GdkEventButton	*event,
+					 ECellDateEdit	*ecde)
+{
+	GtkWidget *event_widget;
+
+	event_widget = gtk_get_event_widget ((GdkEvent*) event);
+	if (gtk_widget_get_toplevel (event_widget) != popup_window) {
+		e_cell_date_edit_hide_popup (ecde);
+	}
+
+	return TRUE;
+}
+
+
 /* Clears the time list and rebuilds it using the lower_hour, upper_hour
    and use_24_hour_format settings. */
 static void
@@ -678,8 +747,10 @@ e_cell_date_edit_on_ok_clicked		(GtkWidget	*button,
 	GDate start_date, end_date;
 	gboolean day_selected;
 	struct tm date_tm;
-	char buffer[64], *text;
+	char buffer[64];
+	const char *text;
 	ETimeParseStatus status;
+	gboolean is_date = FALSE;
 
 	calitem = E_CALENDAR_ITEM (E_CALENDAR (ecde->calendar)->calitem);
 	day_selected = e_calendar_item_get_selection (calitem, &start_date,
@@ -690,17 +761,19 @@ e_cell_date_edit_on_ok_clicked		(GtkWidget	*button,
 	if (status == E_TIME_PARSE_INVALID) {
 		e_cell_date_edit_show_time_invalid_warning (ecde);
 		return;
+	} else if (status == E_TIME_PARSE_NONE) {
+		is_date = TRUE;
 	}
 
 	if (day_selected) {
-		date_tm.tm_year = g_date_year (&start_date) - 1900;
-		date_tm.tm_mon = g_date_month (&start_date) - 1;
-		date_tm.tm_mday = g_date_day (&start_date);
+		date_tm.tm_year = g_date_get_year (&start_date) - 1900;
+		date_tm.tm_mon = g_date_get_month (&start_date) - 1;
+		date_tm.tm_mday = g_date_get_day (&start_date);
 		/* We need to call this to set the weekday. */
 		mktime (&date_tm);
 		e_time_format_date_and_time (&date_tm,
 					     ecde->use_24_hour_format,
-					     TRUE, FALSE,
+					     !is_date, FALSE,
 					     buffer, sizeof (buffer));
 	} else {
 		buffer[0] = '\0';
@@ -752,8 +825,6 @@ e_cell_date_edit_on_now_clicked		(GtkWidget	*button,
 	time_t t;
 	char buffer[64];
 
-	g_print ("In e_cell_date_edit_on_now_clicked\n");
-
 	if (ecde->time_callback) {
 		tmp_tm = (*ecde->time_callback) (ecde, ecde->time_callback_data);
 	} else {
@@ -774,8 +845,6 @@ static void
 e_cell_date_edit_on_none_clicked	(GtkWidget	*button,
 					 ECellDateEdit	*ecde)
 {
-	g_print ("In e_cell_date_edit_on_none_clicked\n");
-
 	e_cell_date_edit_update_cell (ecde, "");
 	e_cell_date_edit_hide_popup (ecde);
 }
@@ -789,8 +858,6 @@ e_cell_date_edit_on_today_clicked	(GtkWidget	*button,
 	time_t t;
 	char buffer[64];
 
-	g_print ("In e_cell_date_edit_on_today_clicked\n");
-
 	if (ecde->time_callback) {
 		tmp_tm = (*ecde->time_callback) (ecde, ecde->time_callback_data);
 	} else {
@@ -816,6 +883,7 @@ e_cell_date_edit_update_cell		(ECellDateEdit	*ecde,
 					 char		*text)
 {
 	ECellPopup *ecp = E_CELL_POPUP (ecde);
+	ECellText *ecell_text = E_CELL_TEXT (ecp->child);
 	ECellView *ecv = (ECellView*) ecp->popup_cell_view;
 	ETableItem *eti = E_TABLE_ITEM (ecv->e_table_item_view);
 	ETableCol *ecol;
@@ -823,15 +891,17 @@ e_cell_date_edit_update_cell		(ECellDateEdit	*ecde,
 
 	/* Compare the new text with the existing cell contents. */
 	ecol = e_table_header_get_column (eti->header, ecp->popup_view_col);
-	old_text = e_table_model_value_at (ecv->e_table_model,
-					   ecol->col_idx, ecp->popup_row);
+
+	old_text = e_cell_text_get_text (ecell_text, ecv->e_table_model,
+					 ecol->col_idx, ecp->popup_row);
 
 	/* If they are different, update the cell contents. */
 	if (strcmp (old_text, text)) {
-		e_table_model_set_value_at (ecv->e_table_model,
-					    ecol->col_idx, ecp->popup_row,
-					    text);
+		e_cell_text_set_value (ecell_text, ecv->e_table_model,
+				       ecol->col_idx, ecp->popup_row, text);
 	}
+
+	e_cell_text_free_text (ecell_text, old_text);
 }
 
 
@@ -842,8 +912,6 @@ e_cell_date_edit_on_time_selected	(GtkList	*list,
 	GtkWidget *listitem, *label;
 	char *list_item_text;
 
-	g_print ("In e_cell_date_edit_on_time_selected\n");
-
 	if (!list->selection)
 		return;
 
@@ -859,7 +927,7 @@ e_cell_date_edit_hide_popup		(ECellDateEdit	*ecde)
 {
 	gtk_grab_remove (ecde->popup_window);
 	gtk_widget_hide (ecde->popup_window);
-	E_CELL_POPUP (ecde)->popup_shown = FALSE;
+	e_cell_popup_set_shown (E_CELL_POPUP (ecde), FALSE);
 }
 
 
@@ -907,5 +975,3 @@ e_cell_date_edit_set_get_time_callback (ECellDateEdit	*ecde,
 	ecde->time_callback_data = data;
 	ecde->time_callback_destroy = destroy;
 }
-
-
