@@ -138,6 +138,8 @@ static void e_date_edit_class_init		(EDateEditClass	*class);
 static void e_date_edit_init			(EDateEdit	*dedit);
 static void create_children			(EDateEdit	*dedit);
 static void e_date_edit_dispose			(GObject	*object);
+static gboolean e_date_edit_mnemonic_activate	(GtkWidget	*widget,
+						 gboolean	 group_cycling);
 static void e_date_edit_grab_focus		(GtkWidget	*widget);
 
 static gint on_date_entry_key_press		(GtkWidget	*widget,
@@ -252,6 +254,7 @@ e_date_edit_class_init		(EDateEditClass	*class)
 
 	object_class->dispose = e_date_edit_dispose;
 
+	widget_class->mnemonic_activate = e_date_edit_mnemonic_activate;
 	widget_class->grab_focus = e_date_edit_grab_focus;
 
 	class->changed = NULL;
@@ -470,6 +473,14 @@ e_date_edit_dispose		(GObject	*object)
 }
 
 
+/* GtkWidget::mnemonic_activate() handler for the EDateEdit */
+static gboolean
+e_date_edit_mnemonic_activate (GtkWidget *widget, gboolean group_cycling)
+{
+	e_date_edit_grab_focus (widget);
+	return TRUE;
+}
+
 /* Grab_focus handler for the EDateEdit. If the date field is being shown, we
    grab the focus to that, otherwise we grab it to the time field. */
 static void
@@ -1176,6 +1187,7 @@ e_date_edit_show_date_popup	(EDateEdit	*dedit)
 			   | GDK_BUTTON_RELEASE_MASK
 			   | GDK_POINTER_MOTION_MASK),
 			  NULL, NULL, GDK_CURRENT_TIME);
+	gdk_window_focus (priv->cal_popup->window, GDK_CURRENT_TIME);
 }
 
 
